CREATE TABLE table_absence (
  absence_id BIGINT NOT NULL IDENTITY,
  user_id BIGINT NOT NULL,
  type TINYINT DEFAULT '10' NOT NULL,
  start_date DATETIME,
  stop_date DATETIME,
  comments TEXT,
  status TINYINT DEFAULT '10' NOT NULL);
ALTER TABLE table_absence ADD CONSTRAINT PRIMARY_0 PRIMARY KEY (
  absence_id);
CREATE INDEX absence_IK_1 ON table_absence (user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_absence TO PUBLIC;



CREATE TABLE table_absence_type (
  absence_type_id TINYINT NOT NULL IDENTITY,
  absence_type_name VARCHAR(64) NOT NULL);
ALTER TABLE table_absence_type ADD CONSTRAINT PRIMARY_1 PRIMARY KEY (
  absence_type_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_absence_type TO PUBLIC;



CREATE TABLE table_agent (
  agent_id BIGINT NOT NULL IDENTITY,
  agent_name VARCHAR(128) NOT NULL,
  agent_os VARCHAR(64) NOT NULL,
  agent_description TEXT,
  folder_id BIGINT NOT NULL);
ALTER TABLE table_agent ADD CONSTRAINT PRIMARY_2 PRIMARY KEY (
  agent_id);
CREATE INDEX agent_IK_1 ON table_agent (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_agent TO PUBLIC;



CREATE TABLE table_attr_boolean (
  attr_boolean_id BIGINT NOT NULL IDENTITY,
  attr_boolean_name VARCHAR(60) NOT NULL,
  dynamic TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_attr_boolean ADD CONSTRAINT PRIMARY_3 PRIMARY KEY (
  attr_boolean_id);
CREATE UNIQUE INDEX attr_boolean_UK_1 ON table_attr_boolean (
  attr_boolean_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_attr_boolean TO PUBLIC;



CREATE TABLE table_attr_integer (
  attr_integer_id BIGINT NOT NULL IDENTITY,
  attr_integer_name VARCHAR(60) NOT NULL,
  dynamic TINYINT DEFAULT '0' NOT NULL,
  attr_integer_normal_values TEXT);
ALTER TABLE table_attr_integer ADD CONSTRAINT PRIMARY_4 PRIMARY KEY (
  attr_integer_id);
CREATE UNIQUE INDEX attr_integer_UK_1 ON table_attr_integer (
  attr_integer_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_attr_integer TO PUBLIC;



CREATE TABLE table_attr_string (
  attr_string_id BIGINT NOT NULL IDENTITY,
  attr_string_name VARCHAR(60) NOT NULL,
  dynamic TINYINT DEFAULT '0' NOT NULL,
  attr_string_normal_values TEXT);
ALTER TABLE table_attr_string ADD CONSTRAINT PRIMARY_5 PRIMARY KEY (
  attr_string_id);
CREATE UNIQUE INDEX attr_string_UK_1 ON table_attr_string (
  attr_string_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_attr_string TO PUBLIC;



CREATE TABLE table_camp (
  campaign_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  campaign_name VARCHAR(128) NOT NULL,
  campaign_description TEXT,
  parallel_execution TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_camp ADD CONSTRAINT PRIMARY_6 PRIMARY KEY (
  campaign_id);
CREATE INDEX camp_IK_1 ON table_camp (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_camp TO PUBLIC;



CREATE TABLE table_camp_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  campaign_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_camp_attach ADD CONSTRAINT PRIMARY_7 PRIMARY KEY (
  attachment_id);
CREATE INDEX camp_attach_IK_1 ON table_camp_attach (
  locked_by);
CREATE INDEX camp_attach_IK_2 ON table_camp_attach (
  campaign_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_camp_attach TO PUBLIC;



CREATE TABLE table_camp_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_camp_attach_data ADD CONSTRAINT PRIMARY_8 PRIMARY KEY (
  data_id);
CREATE INDEX camp_attach_data_IK_1 ON table_camp_attach_data (
  attachment_id);
CREATE INDEX camp_attach_data_IK_2 ON table_camp_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_camp_attach_data TO PUBLIC;



CREATE TABLE table_case (
  case_id BIGINT NOT NULL IDENTITY,
  test_id BIGINT NOT NULL,
  testcase_index BIGINT NOT NULL,
  testcase_name VARCHAR(128) NOT NULL,
  testcase_dev_completed TINYINT DEFAULT '0' NOT NULL,
  testcase_auth_completed TINYINT DEFAULT '1' NOT NULL);
ALTER TABLE table_case ADD CONSTRAINT PRIMARY_9 PRIMARY KEY (
  case_id);
CREATE UNIQUE INDEX case_UK_1 ON table_case (
  test_id,
  testcase_index,
  testcase_name);
CREATE INDEX case_IK_1 ON table_case (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case TO PUBLIC;



CREATE TABLE table_case_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  case_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_case_attach ADD CONSTRAINT PRIMARY_10 PRIMARY KEY (
  attachment_id);
CREATE INDEX case_attach_IK_1 ON table_case_attach (
  locked_by);
CREATE INDEX case_attach_IK_2 ON table_case_attach (
  case_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_attach TO PUBLIC;



CREATE TABLE table_case_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_case_attach_data ADD CONSTRAINT PRIMARY_11 PRIMARY KEY (
  data_id);
CREATE INDEX case_attach_data_IK_1 ON table_case_attach_data (
  attachment_id);
CREATE INDEX case_attach_data_IK_2 ON table_case_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_attach_data TO PUBLIC;




CREATE TABLE table_case_case_data (
  case_id BIGINT NOT NULL,
  data_id BIGINT NOT NULL);
CREATE UNIQUE INDEX case_case_data_UK_1 ON table_case_case_data (
  case_id,
  data_id);
CREATE INDEX case_case_data_IK_1 ON table_case_case_data (
  case_id);
CREATE INDEX case_case_data_IK_2 ON table_case_case_data (
  data_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_case_data TO PUBLIC;




CREATE TABLE table_case_data (
  data_id BIGINT NOT NULL IDENTITY,
  testcase_steps TEXT,
  testcase_description TEXT,
  testcase_useDescAsTestplan TINYINT DEFAULT '0' NOT NULL,
  additional_info TEXT,
  date_submitted DATETIME,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_case_data ADD CONSTRAINT PRIMARY_12 PRIMARY KEY (
  data_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_data TO PUBLIC;




CREATE TABLE table_case_exec (
  testcase_exec_id BIGINT NOT NULL IDENTITY,
  campaign_session_id BIGINT NOT NULL,
  case_id BIGINT NOT NULL,
  testcase_exec_result BIGINT NOT NULL,
  testcase_exec_message TEXT,
  timestamp BIGINT DEFAULT '0' NOT NULL,
  instance_id BIGINT NOT NULL);
ALTER TABLE table_case_exec ADD CONSTRAINT PRIMARY_13 PRIMARY KEY (
  testcase_exec_id);
CREATE UNIQUE INDEX case_exec_UK_1 ON table_case_exec (
  campaign_session_id,
  case_id,
  instance_id);
CREATE INDEX case_exec_IK_1 ON table_case_exec (
  case_id);
CREATE INDEX case_exec_IK_2 ON table_case_exec (
  campaign_session_id);
CREATE INDEX case_exec_IK_3 ON table_case_exec (
  instance_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_exec TO PUBLIC;




CREATE TABLE table_case_exec_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  testcase_exec_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_case_exec_attach ADD CONSTRAINT PRIMARY_14 PRIMARY KEY (
  attachment_id);
CREATE INDEX case_exec_attach_IK_1 ON table_case_exec_attach (
  locked_by);
CREATE INDEX case_exec_attach_IK_2 ON table_case_exec_attach (
  testcase_exec_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_exec_attach TO PUBLIC;




CREATE TABLE table_case_exec_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_case_exec_attach_data ADD CONSTRAINT PRIMARY_15 PRIMARY KEY (
  data_id);
CREATE INDEX case_exec_attach_data_IK_1 ON table_case_exec_attach_data (
  attachment_id);
CREATE INDEX case_exec_attach_data_IK_2 ON table_case_exec_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_exec_attach_data TO PUBLIC;




CREATE TABLE table_case_param_boolean (
  case_id BIGINT NOT NULL,
  param_boolean_id BIGINT NOT NULL,
  param_boolean_value TINYINT DEFAULT '0' NOT NULL);
CREATE UNIQUE INDEX case_param_boolean_UK_1 ON table_case_param_boolean (
  case_id,
  param_boolean_id);
CREATE INDEX case_param_boolean_IK_1 ON table_case_param_boolean (
  case_id);
CREATE INDEX case_param_boolean_IK_2 ON table_case_param_boolean (
  param_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_param_boolean TO PUBLIC;




CREATE TABLE table_case_param_integer (
  case_id BIGINT NOT NULL,
  param_integer_id BIGINT NOT NULL,
  param_integer_value VARCHAR(16) NOT NULL);
CREATE UNIQUE INDEX case_param_integer_UK_1 ON table_case_param_integer (
  case_id,
  param_integer_id);
CREATE INDEX case_param_integer_IK_1 ON table_case_param_integer (
  case_id);
CREATE INDEX case_param_integer_IK_2 ON table_case_param_integer (
  param_integer_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_param_integer TO PUBLIC;




CREATE TABLE table_case_param_string (
  case_id BIGINT NOT NULL,
  param_string_id BIGINT NOT NULL,
  param_string_value VARCHAR(256));
CREATE UNIQUE INDEX case_param_string_UK_1 ON table_case_param_string (
  case_id,
  param_string_id);
CREATE INDEX case_param_string_IK_1 ON table_case_param_string (
  case_id);
CREATE INDEX case_param_string_IK_2 ON table_case_param_string (
  param_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_case_param_string TO PUBLIC;




CREATE TABLE table_category (
  category_id BIGINT NOT NULL IDENTITY,
  category_name VARCHAR(128) NOT NULL,
  category_envDesc TEXT,
  category_jarName VARCHAR(64));
ALTER TABLE table_category ADD CONSTRAINT PRIMARY_16 PRIMARY KEY (
  category_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_category TO PUBLIC;



SET IDENTITY_INSERT table_category ON;
INSERT INTO table_category(category_id, category_name, category_envDesc, category_jarName) VALUES (1, 'na', 'na', 'na');
INSERT INTO table_category(category_id, category_name, category_envDesc, category_jarName) VALUES (10, 'Manual Tests', 'This is a category dedicated to manual tests (launcher set to [b]tabular_manual.jar[/b])', 'tabular_manual.jar');
INSERT INTO table_category(category_id, category_name, category_envDesc, category_jarName) VALUES (11, 'Automated Tests (i.e. JUnit)', 'This is a category dedicated to automated tests (i.e. JUnit tests in this case as the launcher is set to [b]junit.jar[/b])', 'junit.jar');
SET IDENTITY_INSERT table_category OFF;






CREATE TABLE table_category_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  category_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_category_attach ADD CONSTRAINT PRIMARY_17 PRIMARY KEY (
  attachment_id);
CREATE INDEX category_attach_IK_1 ON table_category_attach (
  locked_by);
CREATE INDEX category_attach_IK_2 ON table_category_attach (
  category_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_category_attach TO PUBLIC;




CREATE TABLE table_category_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_category_attach_data ADD CONSTRAINT PRIMARY_18 PRIMARY KEY (
  data_id);
CREATE INDEX category_attach_data_IK_1 ON table_category_attach_data (
  attachment_id);
CREATE INDEX category_attach_data_IK_2 ON table_category_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_category_attach_data TO PUBLIC;




CREATE TABLE table_category_stat (
  category_id BIGINT NOT NULL,
  date_submitted DATETIME,
  nb_tests BIGINT DEFAULT '0' NOT NULL,
  nb_tests_developed BIGINT DEFAULT '0' NOT NULL,
  nb_tests_authored BIGINT DEFAULT '0' NOT NULL,
  nb_cases BIGINT DEFAULT '0' NOT NULL,
  nb_cases_developed BIGINT DEFAULT '0' NOT NULL,
  nb_cases_authored BIGINT DEFAULT '0' NOT NULL);
CREATE INDEX category_stat_IK_1 ON table_category_stat (
  category_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_category_stat TO PUBLIC;




CREATE TABLE table_change (
  type TINYINT NOT NULL,
  id BIGINT NOT NULL,
  date_submitted DATETIME NOT NULL,
  user_id BIGINT NOT NULL,
  action TINYINT NOT NULL,
  information VARCHAR(255));
CREATE INDEX change_IK_1 ON table_change (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_change TO PUBLIC;




CREATE TABLE table_company (
  company_id BIGINT NOT NULL IDENTITY,
  company_name VARCHAR(128) NOT NULL);
ALTER TABLE table_company ADD CONSTRAINT PRIMARY_19 PRIMARY KEY (
  company_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_company TO PUBLIC;

SET IDENTITY_INSERT table_company ON;
INSERT INTO table_company(company_id, company_name) VALUES (1, 'na');
INSERT INTO table_company(company_id, company_name) VALUES (10, 'XQual');
INSERT INTO table_company(company_id, company_name) VALUES (11, 'My Company');
SET IDENTITY_INSERT table_company OFF;








CREATE TABLE table_company_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  company_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_company_attach ADD CONSTRAINT PRIMARY_20 PRIMARY KEY (
  attachment_id);
CREATE INDEX company_attach_IK_1 ON table_company_attach (
  locked_by);
CREATE INDEX company_attach_IK_2 ON table_company_attach (
  company_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_company_attach TO PUBLIC;




CREATE TABLE table_company_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_company_attach_data ADD CONSTRAINT PRIMARY_21 PRIMARY KEY (
  data_id);
CREATE INDEX company_attach_data_IK_1 ON table_company_attach_data (
  attachment_id);
CREATE INDEX company_attach_data_IK_2 ON table_company_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_company_attach_data TO PUBLIC;




CREATE TABLE table_conf (
  conf_id BIGINT NOT NULL IDENTITY,
  jar_name VARCHAR(64) NOT NULL,
  conf_name VARCHAR(64) NOT NULL,
  conf_data TEXT);
ALTER TABLE table_conf ADD CONSTRAINT PRIMARY_22 PRIMARY KEY (
  conf_id);
CREATE UNIQUE INDEX conf_UK_1 ON table_conf (
  jar_name,
  conf_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_conf TO PUBLIC;




CREATE TABLE table_country (
  country_id CHAR(2) NOT NULL,
  country_name VARCHAR(80) NOT NULL);
ALTER TABLE table_country ADD CONSTRAINT PRIMARY_23 PRIMARY KEY (
  country_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_country TO PUBLIC;


INSERT INTO table_country VALUES ('US','United States');





CREATE TABLE table_cust_boolean (
  cust_boolean_id BIGINT NOT NULL IDENTITY,
  cust_boolean_source_type SMALLINT DEFAULT '0' NOT NULL,
  cust_boolean_name VARCHAR(64) NOT NULL,
  cust_boolean_default_value TINYINT DEFAULT '0' NOT NULL,
  position SMALLINT DEFAULT '1' NOT NULL);
ALTER TABLE table_cust_boolean ADD CONSTRAINT PRIMARY_24 PRIMARY KEY (
  cust_boolean_id);
CREATE UNIQUE INDEX cust_boolean_UK_1 ON table_cust_boolean (
  cust_boolean_source_type,
  cust_boolean_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_boolean TO PUBLIC;




CREATE TABLE table_cust_boolean_value (
  cust_boolean_id BIGINT NOT NULL,
  source_id BIGINT NOT NULL,
  value TINYINT NOT NULL);
CREATE UNIQUE INDEX cust_boolean_value_UK_1 ON table_cust_boolean_value (
  cust_boolean_id,
  source_id);
CREATE INDEX cust_boolean_value_IK_1 ON table_cust_boolean_value (
  cust_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_boolean_value TO PUBLIC;




CREATE TABLE table_cust_choice (
  cust_choice_id BIGINT NOT NULL IDENTITY,
  cust_choice_source_type SMALLINT DEFAULT '0' NOT NULL,
  cust_choice_name VARCHAR(64) NOT NULL,
  cust_choice_possible_values TEXT NOT NULL,
  cust_choice_default_value TEXT NOT NULL,
  cust_choice_multiple_choices TINYINT DEFAULT '0' NOT NULL,
  position SMALLINT DEFAULT '1' NOT NULL);
ALTER TABLE table_cust_choice ADD CONSTRAINT PRIMARY_25 PRIMARY KEY (
  cust_choice_id);
CREATE UNIQUE INDEX cust_choice_UK_1 ON table_cust_choice (
  cust_choice_source_type,
  cust_choice_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_choice TO PUBLIC;




CREATE TABLE table_cust_choice_value (
  cust_choice_id BIGINT NOT NULL,
  source_id BIGINT NOT NULL,
  value VARCHAR(64));
CREATE UNIQUE INDEX cust_choice_value_UK_1 ON table_cust_choice_value (
  cust_choice_id,
  source_id);
CREATE INDEX cust_choice_value_IK_1 ON table_cust_choice_value (
  cust_choice_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_choice_value TO PUBLIC;



CREATE TABLE table_cust_html (
  cust_html_id BIGINT NOT NULL IDENTITY,
  cust_html_source_type SMALLINT DEFAULT '0' NOT NULL,
  cust_html_name VARCHAR(64) NOT NULL,
  cust_html_mandatory TINYINT DEFAULT '0' NOT NULL,
  cust_html_default_value TEXT,
  position SMALLINT DEFAULT '1' NOT NULL);
ALTER TABLE table_cust_html ADD CONSTRAINT PRIMARY_26 PRIMARY KEY (
  cust_html_id);
CREATE UNIQUE INDEX cust_html_UK_1 ON table_cust_html (
  cust_html_source_type,
  cust_html_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_html TO PUBLIC;




CREATE TABLE table_cust_html_value (
  cust_html_id BIGINT NOT NULL,
  source_id BIGINT NOT NULL,
  value TEXT);
CREATE UNIQUE INDEX cust_html_value_UK_1 ON table_cust_html_value (
  cust_html_id,
  source_id);
CREATE INDEX cust_html_value_IK_1 ON table_cust_html_value (
  cust_html_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_html_value TO PUBLIC;




CREATE TABLE table_cust_integer (
  cust_integer_id BIGINT NOT NULL IDENTITY,
  cust_integer_source_type SMALLINT DEFAULT '0' NOT NULL,
  cust_integer_name VARCHAR(64) NOT NULL,
  cust_integer_mandatory TINYINT DEFAULT '0' NOT NULL,
  cust_integer_default_value BIGINT DEFAULT '0' NOT NULL,
  position SMALLINT DEFAULT '1' NOT NULL);
ALTER TABLE table_cust_integer ADD CONSTRAINT PRIMARY_27 PRIMARY KEY (
  cust_integer_id);
CREATE UNIQUE INDEX cust_integer_UK_1 ON table_cust_integer (
  cust_integer_source_type,
  cust_integer_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_integer TO PUBLIC;




CREATE TABLE table_cust_integer_value (
  cust_integer_id BIGINT NOT NULL,
  source_id BIGINT NOT NULL,
  value BIGINT NOT NULL);
CREATE UNIQUE INDEX cust_integer_value_UK_1 ON table_cust_integer_value (
  cust_integer_id,
  source_id);
CREATE INDEX cust_integer_value_IK_1 ON table_cust_integer_value (
  cust_integer_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_integer_value TO PUBLIC;




CREATE TABLE table_cust_string (
  cust_string_id BIGINT NOT NULL IDENTITY,
  cust_string_source_type SMALLINT DEFAULT '0' NOT NULL,
  cust_string_name VARCHAR(64) NOT NULL,
  cust_string_mandatory TINYINT DEFAULT '0' NOT NULL,
  cust_string_default_value VARCHAR(512),
  position SMALLINT DEFAULT '1' NOT NULL);
ALTER TABLE table_cust_string ADD CONSTRAINT PRIMARY_28 PRIMARY KEY (
  cust_string_id);
CREATE UNIQUE INDEX cust_string_UK_1 ON table_cust_string (
  cust_string_source_type,
  cust_string_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_string TO PUBLIC;




CREATE TABLE table_cust_string_value (
  cust_string_id BIGINT NOT NULL,
  source_id BIGINT NOT NULL,
  value VARCHAR(512));
CREATE UNIQUE INDEX cust_string_value_UK_1 ON table_cust_string_value (
  cust_string_id,
  source_id);
CREATE INDEX cust_string_value_IK_1 ON table_cust_string_value (
  cust_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_cust_string_value TO PUBLIC;




CREATE TABLE table_def_generic (
  defect_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  external_id BIGINT);
ALTER TABLE table_def_generic ADD CONSTRAINT PRIMARY_29 PRIMARY KEY (
  defect_id);
CREATE INDEX def_generic_IK_1 ON table_def_generic (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_generic TO PUBLIC;




CREATE TABLE table_def_int (
  defect_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  defect_name VARCHAR(128) NOT NULL,
  reporter BIGINT NOT NULL);
ALTER TABLE table_def_int ADD CONSTRAINT PRIMARY_30 PRIMARY KEY (
  defect_id);
CREATE INDEX def_int_IK_1 ON table_def_int (
  folder_id);
CREATE INDEX def_int_IK_2 ON table_def_int (
  reporter);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int TO PUBLIC;




CREATE TABLE table_def_int_assigned_to (
  defect_id BIGINT NOT NULL,
  assigned_to BIGINT NOT NULL);
CREATE UNIQUE INDEX def_int_assigned_to_UK_1 ON table_def_int_assigned_to (
  defect_id,
  assigned_to);
CREATE INDEX def_int_assigned_to_IK_1 ON table_def_int_assigned_to (
  defect_id);
CREATE INDEX def_int_assigned_to_IK_2 ON table_def_int_assigned_to (
  assigned_to);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int_assigned_to TO PUBLIC;




CREATE TABLE table_def_int_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  defect_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_def_int_attach ADD CONSTRAINT PRIMARY_31 PRIMARY KEY (
  attachment_id);
CREATE INDEX def_int_attach_IK_1 ON table_def_int_attach (
  locked_by);
CREATE INDEX def_int_attach_IK_2 ON table_def_int_attach (
  defect_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int_attach TO PUBLIC;




CREATE TABLE table_def_int_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_def_int_attach_data ADD CONSTRAINT PRIMARY_32 PRIMARY KEY (
  data_id);
CREATE INDEX def_int_attach_data_IK_1 ON table_def_int_attach_data (
  attachment_id);
CREATE INDEX def_int_attach_data_IK_2 ON table_def_int_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int_attach_data TO PUBLIC;




CREATE TABLE table_def_int_ccemails (
  defect_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL);
CREATE INDEX def_int_ccemails_IK_1 ON table_def_int_ccemails (
  defect_id);
CREATE INDEX def_int_ccemails_IK_2 ON table_def_int_ccemails (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int_ccemails TO PUBLIC;




CREATE TABLE table_def_int_data (
  data_id BIGINT NOT NULL IDENTITY,
  defect_id BIGINT NOT NULL,
  defect_description TEXT,
  priority TINYINT NOT NULL,
  severity TINYINT NOT NULL,
  status TINYINT NOT NULL,
  step_to_reproduce TEXT,
  reproducibility TINYINT DEFAULT '1',
  platform_id BIGINT DEFAULT '999' NOT NULL,
  os_id BIGINT DEFAULT '999' NOT NULL,
  fix_target_date DATETIME,
  fix_target_version VARCHAR(32),
  completion_percentage TINYINT DEFAULT '0' NOT NULL,
  fix_type TINYINT,
  fix_description TEXT,
  fix_patches VARCHAR(64),
  date_submitted DATETIME,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_def_int_data ADD CONSTRAINT PRIMARY_33 PRIMARY KEY (
  data_id);
CREATE UNIQUE INDEX def_int_data_UK_1 ON table_def_int_data (
  defect_id,
  revision);
CREATE INDEX def_int_data_IK_1 ON table_def_int_data (
  defect_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int_data TO PUBLIC;




CREATE TABLE table_def_int_sut (
  type TINYINT NOT NULL,
  defect_id BIGINT NOT NULL,
  sut_id BIGINT NOT NULL);
CREATE UNIQUE INDEX def_int_sut_UK_1 ON table_def_int_sut (
  type,
  defect_id,
  sut_id);
CREATE INDEX def_int_sut_IK_1 ON table_def_int_sut (
  defect_id);
CREATE INDEX def_int_sut_IK_2 ON table_def_int_sut (
  sut_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_int_sut TO PUBLIC;




CREATE TABLE table_def_stat (
  entry_id BIGINT NOT NULL IDENTITY,
  database_type TINYINT NOT NULL,
  container_type TINYINT NOT NULL,
  type TINYINT NOT NULL,
  container VARCHAR(255),
  date_submitted DATETIME,
  stat TEXT NOT NULL);
ALTER TABLE table_def_stat ADD CONSTRAINT PRIMARY_34 PRIMARY KEY (
  entry_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_def_stat TO PUBLIC;




CREATE TABLE table_filter (
  filter_id BIGINT NOT NULL IDENTITY,
  filter_description TEXT,
  filter_data TEXT);
ALTER TABLE table_filter ADD CONSTRAINT PRIMARY_35 PRIMARY KEY (
  filter_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_filter TO PUBLIC;




CREATE TABLE table_folder (
  folder_id BIGINT NOT NULL IDENTITY,
  folder_id_2 BIGINT,
  folder_name VARCHAR(128) NOT NULL,
  category_id BIGINT NOT NULL,
  company_id BIGINT NOT NULL,
  project_id BIGINT DEFAULT '1' NOT NULL,
  folder_description TEXT);
ALTER TABLE table_folder ADD CONSTRAINT PRIMARY_36 PRIMARY KEY (
  folder_id);
CREATE INDEX folder_IK_1 ON table_folder (
  folder_id_2);
CREATE INDEX folder_IK_2 ON table_folder (
  category_id);
CREATE INDEX folder_IK_3 ON table_folder (
  company_id);
CREATE INDEX folder_IK_4 ON table_folder (
  project_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_folder TO PUBLIC;


SET IDENTITY_INSERT table_folder ON;
-- users;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (1,   1, 'na', 1, 1, 1, NULL);
-- suts;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (2,   2, 'na', 1, 1, 1, NULL);
-- reqs;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (3,   3, 'na', 1, 1, 1, NULL);
-- specs;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (4,   4, 'na', 1, 1, 1, NULL);
-- tests;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (5,   5, 'na', 1, 1, 1, NULL);
-- campaigns;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (6,   6, 'na', 1, 1, 1, NULL);
-- defects;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (7,   7, 'na', 1, 1, 1, NULL);
-- agents;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (8,   8, 'na', 1, 1, 1, NULL);
-- projects;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (9,   9, 'na', 1, 1, 1, NULL);
-- tasks;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (10, 10, 'na', 1, 1, 1, NULL);
-- documents;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (11, 11, 'na', 1, 1, 1, NULL);

-- sub folders;
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (29, 1, 'Administration',     1,  10, 1, 'This is a folder containing some administrative users');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (30, 6, 'Manual',             1,  10, 1, 'This is a folder containing only manual campaigns (when the test operator run a test directly from the test tree)');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (31, 1, 'My Users',           1,  11, 1, 'This is a folder containing some users');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (32, 2, 'My SUTs',            1,  11, 1, 'This is a folder containing some SUTs');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (33, 3, 'My Requirements',    1,  10, 1, 'This is a folder containing some requirements');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (34, 4, 'My Specifications',  1,  10, 1, 'This is a folder containing some specifications');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (35, 5, 'My Manual Tests',    10, 10, 1, 'This is a folder containing some manual tests');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (36, 5, 'My Automated Tests', 11, 10, 1, 'This is a folder containing some automated tests');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (37, 7, 'My Issues',          1,  10, 1, 'This is a folder containing some issues');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (38, 9, 'My Projects',        1,  10, 1, 'This is a folder containing some projects');
INSERT INTO table_folder(folder_id, folder_id_2, folder_name, category_id, company_id, project_id, folder_description) VALUES (39, 11, 'My Documents',      1,  10, 1, 'This is a folder containing some documents');
SET IDENTITY_INSERT table_folder OFF;







CREATE TABLE table_folder_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_folder_attach ADD CONSTRAINT PRIMARY_37 PRIMARY KEY (
  attachment_id);
CREATE INDEX folder_attach_IK_1 ON table_folder_attach (
  locked_by);
CREATE INDEX folder_attach_IK_2 ON table_folder_attach (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_folder_attach TO PUBLIC;




CREATE TABLE table_folder_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_folder_attach_data ADD CONSTRAINT PRIMARY_38 PRIMARY KEY (
  data_id);
CREATE INDEX folder_attach_data_IK_1 ON table_folder_attach_data (
  attachment_id);
CREATE INDEX folder_attach_data_IK_2 ON table_folder_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_folder_attach_data TO PUBLIC;




CREATE TABLE table_holiday (
  holiday_id BIGINT NOT NULL IDENTITY,
  country_id CHAR(2) NOT NULL,
  start_date DATETIME,
  stop_date DATETIME,
  comments TEXT);
ALTER TABLE table_holiday ADD CONSTRAINT PRIMARY_39 PRIMARY KEY (
  holiday_id);
CREATE INDEX holiday_IK_1 ON table_holiday (
  country_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_holiday TO PUBLIC;




CREATE TABLE table_instance (
  instance_id BIGINT NOT NULL IDENTITY,
  campaign_session_id BIGINT NOT NULL,
  agent_id BIGINT NOT NULL,
  instance_index BIGINT DEFAULT '0' NOT NULL,
  sync_type TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_instance ADD CONSTRAINT PRIMARY_53 PRIMARY KEY (
  instance_id);
CREATE UNIQUE INDEX instance_UK_1 ON table_instance (
  campaign_session_id,
  agent_id,
  instance_index);
CREATE INDEX instance_IK_1 ON table_instance (
  campaign_session_id);
CREATE INDEX instance_IK_2 ON table_instance (
  agent_id);
CREATE INDEX instance_IK_3 ON table_instance (
  instance_index);
CREATE INDEX instance_IK_4 ON table_instance (
  sync_type);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_instance TO PUBLIC;




CREATE TABLE table_monitor (
  monitor_id BIGINT NOT NULL IDENTITY,
  campaign_session_id BIGINT NOT NULL,
  monitored_id BIGINT NOT NULL);
ALTER TABLE table_monitor ADD CONSTRAINT PRIMARY_54 PRIMARY KEY (
  monitor_id);
CREATE UNIQUE INDEX monitor_UK_1 ON table_monitor (
  campaign_session_id,
  monitored_id);
CREATE INDEX monitor_IK_1 ON table_monitor (
  campaign_session_id);
CREATE INDEX monitor_IK_2 ON table_monitor (
  monitored_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_monitor TO PUBLIC;




CREATE TABLE table_monitored_results (
  monitor_id BIGINT NOT NULL IDENTITY,
  timestamp BIGINT DEFAULT '0' NOT NULL,
  class VARCHAR(128) NOT NULL,
  subclass VARCHAR(128),
  value BIGINT DEFAULT '0' NOT NULL);
CREATE INDEX monitored_results_IK_1 ON table_monitored_results (
  monitor_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_monitored_results TO PUBLIC;




CREATE TABLE table_monitoring_conf (
  monitoring_conf_id BIGINT NOT NULL IDENTITY,
  monitoring_conf_name VARCHAR(64) NOT NULL,
  monitoring_conf_data TEXT);
ALTER TABLE table_monitoring_conf ADD CONSTRAINT PRIMARY_55 PRIMARY KEY (
  monitoring_conf_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_monitoring_conf TO PUBLIC;




CREATE TABLE table_os (
  os_id BIGINT NOT NULL IDENTITY,
  os_name VARCHAR(32) NOT NULL);
ALTER TABLE table_os ADD CONSTRAINT PRIMARY_56 PRIMARY KEY (
  os_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_os TO PUBLIC;




CREATE TABLE table_param_boolean (
  param_boolean_id BIGINT NOT NULL IDENTITY,
  param_boolean_name VARCHAR(64) NOT NULL);
ALTER TABLE table_param_boolean ADD CONSTRAINT PRIMARY_57 PRIMARY KEY (
  param_boolean_id);
CREATE UNIQUE INDEX param_boolean_UK_1 ON table_param_boolean (
  param_boolean_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_param_boolean TO PUBLIC;




CREATE TABLE table_param_integer (
  param_integer_id BIGINT NOT NULL IDENTITY,
  param_integer_name VARCHAR(64) NOT NULL,
  param_integer_normal_values TEXT,
  param_integer_invalid_values TEXT);
ALTER TABLE table_param_integer ADD CONSTRAINT PRIMARY_58 PRIMARY KEY (
  param_integer_id);
CREATE UNIQUE INDEX param_integer_UK_1 ON table_param_integer (
  param_integer_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_param_integer TO PUBLIC;




CREATE TABLE table_param_string (
  param_string_id BIGINT NOT NULL IDENTITY,
  param_string_name VARCHAR(64) NOT NULL,
  param_string_normal_values TEXT,
  param_string_invalid_values TEXT);
ALTER TABLE table_param_string ADD CONSTRAINT PRIMARY_59 PRIMARY KEY (
  param_string_id);
CREATE UNIQUE INDEX param_string_UK_1 ON table_param_string (
  param_string_name);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_param_string TO PUBLIC;




CREATE TABLE table_platform (
  platform_id BIGINT NOT NULL IDENTITY,
  platform_name VARCHAR(32) NOT NULL);
ALTER TABLE table_platform ADD CONSTRAINT PRIMARY_60 PRIMARY KEY (
  platform_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_platform TO PUBLIC;




CREATE TABLE table_project (
  project_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  project_name VARCHAR(128) NOT NULL,
  project_description TEXT,
  focus_ratio TINYINT DEFAULT '80' NOT NULL);
ALTER TABLE table_project ADD CONSTRAINT PRIMARY_61 PRIMARY KEY (
  project_id);
CREATE INDEX project_IK_1 ON table_project (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_project TO PUBLIC;


SET IDENTITY_INSERT table_project ON;
INSERT INTO table_project(project_id, folder_id, project_name, project_description, focus_ratio) VALUES (1, 1, 'na', 'na', 80);
SET IDENTITY_INSERT table_project OFF;




CREATE TABLE table_project_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  project_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_project_attach ADD CONSTRAINT PRIMARY_62 PRIMARY KEY (
  attachment_id);
CREATE INDEX project_attach_IK_1 ON table_project_attach (
  locked_by);
CREATE INDEX project_attach_IK_2 ON table_project_attach (
  project_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_project_attach TO PUBLIC;




CREATE TABLE table_project_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_project_attach_data ADD CONSTRAINT PRIMARY_63 PRIMARY KEY (
  data_id);
CREATE INDEX project_attach_data_IK_1 ON table_project_attach_data (
  attachment_id);
CREATE INDEX project_attach_data_IK_2 ON table_project_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_project_attach_data TO PUBLIC;




CREATE TABLE table_project_manager (
  project_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL);
CREATE UNIQUE INDEX project_manager_UK_1 ON table_project_manager (
  project_id,
  user_id);
CREATE INDEX project_manager_IK_1 ON table_project_manager (
  project_id);
CREATE INDEX project_manager_IK_2 ON table_project_manager (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_project_manager TO PUBLIC;




CREATE TABLE table_req_generic (
  requirement_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  external_id BIGINT);
ALTER TABLE table_req_generic ADD CONSTRAINT PRIMARY_64 PRIMARY KEY (
  requirement_id);
CREATE INDEX req_generic_IK_1 ON table_req_generic (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_generic TO PUBLIC;




CREATE TABLE table_req_int (
  requirement_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  requirement_name VARCHAR(128) NOT NULL);
ALTER TABLE table_req_int ADD CONSTRAINT PRIMARY_65 PRIMARY KEY (
  requirement_id);
CREATE INDEX req_int_IK_1 ON table_req_int (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_int TO PUBLIC;




CREATE TABLE table_req_int_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  requirement_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_req_int_attach ADD CONSTRAINT PRIMARY_66 PRIMARY KEY (
  attachment_id);
CREATE INDEX req_int_attach_IK_1 ON table_req_int_attach (
  locked_by);
CREATE INDEX req_int_attach_IK_2 ON table_req_int_attach (
  requirement_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_int_attach TO PUBLIC;




CREATE TABLE table_req_int_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_req_int_attach_data ADD CONSTRAINT PRIMARY_67 PRIMARY KEY (
  data_id);
CREATE INDEX req_int_attach_data_IK_1 ON table_req_int_attach_data (
  attachment_id);
CREATE INDEX req_int_attach_data_IK_2 ON table_req_int_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_int_attach_data TO PUBLIC;




CREATE TABLE table_req_int_data (
  data_id BIGINT NOT NULL IDENTITY,
  requirement_id BIGINT NOT NULL,
  requirement_description TEXT,
  type SMALLINT DEFAULT '10' NOT NULL,
  priority TINYINT DEFAULT '20' NOT NULL,
  status TINYINT DEFAULT '30' NOT NULL,
  date_submitted DATETIME,
  revision BIGINT DEFAULT '1' NOT NULL,
  coverage TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_req_int_data ADD CONSTRAINT PRIMARY_68 PRIMARY KEY (
  data_id);
CREATE UNIQUE INDEX req_int_data_UK_1 ON table_req_int_data (
  requirement_id,
  revision);
CREATE INDEX req_int_data_IK_1 ON table_req_int_data (
  requirement_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_int_data TO PUBLIC;




CREATE TABLE table_req_spec (
  requirement_id BIGINT NOT NULL,
  specification_id BIGINT NOT NULL);
CREATE INDEX req_spec_IK_1 ON table_req_spec (
  requirement_id);
CREATE INDEX req_spec_IK_2 ON table_req_spec (
  specification_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_spec TO PUBLIC;




CREATE TABLE table_req_test (
  requirement_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL);
CREATE INDEX req_test_IK_1 ON table_req_test (
  requirement_id);
CREATE INDEX req_test_IK_2 ON table_req_test (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_req_test TO PUBLIC;




CREATE TABLE table_sch (
  schedule_id BIGINT NOT NULL IDENTITY,
  schedule_name VARCHAR(128) NOT NULL,
  schedule_description TEXT,
  schedule_nextStartDate DATETIME,
  campaign_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL,
  schedule_enabled TINYINT DEFAULT '1' NOT NULL,
  schedule_every TEXT NOT NULL,
  schedule_at TEXT,
  sut_id BIGINT NOT NULL,
  on_parent_failed TINYINT DEFAULT '3' NOT NULL,
  on_parent_unknown TINYINT DEFAULT '1' NOT NULL,
  monitoring_id BIGINT,
  monitoring_conf_id BIGINT,
  pick TINYINT DEFAULT '1' NOT NULL);
ALTER TABLE table_sch ADD CONSTRAINT PRIMARY_69 PRIMARY KEY (
  schedule_id);
CREATE INDEX sch_IK_1 ON table_sch (
  campaign_id);
CREATE INDEX sch_IK_2 ON table_sch (
  user_id);
CREATE INDEX sch_IK_3 ON table_sch (
  sut_id);
CREATE INDEX sch_IK_4 ON table_sch (
  monitoring_id);
CREATE INDEX sch_IK_5 ON table_sch (
  monitoring_conf_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch TO PUBLIC;




CREATE TABLE table_sch_agent (
  schedule_id BIGINT NOT NULL,
  agent_id BIGINT NOT NULL,
  nb_instance BIGINT DEFAULT '1' NOT NULL,
  sync_type TINYINT DEFAULT '0' NOT NULL);
CREATE UNIQUE INDEX sch_agent_UK_1 ON table_sch_agent (
  schedule_id,
  agent_id);
CREATE INDEX sch_agent_IK_1 ON table_sch_agent (
  schedule_id);
CREATE INDEX sch_agent_IK_2 ON table_sch_agent (
  agent_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_agent TO PUBLIC;





CREATE TABLE table_sch_attr_boolean (
  schedule_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  attr_boolean_id BIGINT NOT NULL,
  value TINYINT DEFAULT '0' NOT NULL);
CREATE INDEX sch_attr_boolean_IK_1 ON table_sch_attr_boolean (
  schedule_id);
CREATE INDEX sch_attr_boolean_IK_2 ON table_sch_attr_boolean (
  test_id);
CREATE INDEX sch_attr_boolean_IK_3 ON table_sch_attr_boolean (
  attr_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_attr_boolean TO PUBLIC;


CREATE TABLE table_sch_attr_integer (
  schedule_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  attr_integer_id BIGINT NOT NULL,
  value TEXT NOT NULL);

CREATE INDEX sch_attr_integer_IK_2 ON table_sch_attr_integer (
  test_id);
CREATE INDEX sch_attr_integer_IK_3 ON table_sch_attr_integer (
  attr_integer_id);
CREATE INDEX sch_attr_integer_IK_1 ON table_sch_attr_integer (
  schedule_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_attr_integer TO PUBLIC;


CREATE TABLE table_sch_attr_string (
  schedule_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  attr_string_id BIGINT NOT NULL,
  value TEXT);

CREATE INDEX sch_attr_string_IK_1 ON table_sch_attr_string (
  schedule_id);
CREATE INDEX sch_attr_string_IK_2 ON table_sch_attr_string (
  test_id);
CREATE INDEX sch_attr_string_IK_3 ON table_sch_attr_string (
  attr_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_attr_string TO PUBLIC;




CREATE TABLE table_sch_param_boolean (
  schedule_id BIGINT NOT NULL,
  param_boolean_id BIGINT NOT NULL,
  value TINYINT DEFAULT '0' NOT NULL);

CREATE INDEX sch_param_boolean_IK_1 ON table_sch_param_boolean (
  schedule_id);
CREATE INDEX sch_param_boolean_IK_2 ON table_sch_param_boolean (
  param_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_param_boolean TO PUBLIC;


CREATE TABLE table_sch_param_integer (
  schedule_id BIGINT NOT NULL,
  param_integer_id BIGINT NOT NULL,
  value TEXT NOT NULL);

CREATE INDEX sch_param_integer_IK_1 ON table_sch_param_integer (
  schedule_id);
CREATE INDEX sch_param_integer_IK_2 ON table_sch_param_integer (
  param_integer_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_param_integer TO PUBLIC;


CREATE TABLE table_sch_param_string (
  schedule_id BIGINT NOT NULL,
  param_string_id BIGINT NOT NULL,
  value TEXT);

CREATE INDEX sch_param_string_IK_1 ON table_sch_param_string (
  schedule_id);
CREATE INDEX sch_param_string_IK_3 ON table_sch_param_string (
  param_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_param_string TO PUBLIC;



CREATE TABLE table_sch_ccemails (
  schedule_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL);
CREATE INDEX sch_ccemails_IK_1 ON table_sch_ccemails (
  schedule_id);
CREATE INDEX sch_ccemails_IK_2 ON table_sch_ccemails (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_ccemails TO PUBLIC;




CREATE TABLE table_sch_conf (
  schedule_id BIGINT NOT NULL,
  conf_id BIGINT NOT NULL,
  category_id BIGINT NOT NULL);
CREATE INDEX sch_conf_IK_1 ON table_sch_conf (
  schedule_id);
CREATE INDEX sch_conf_IK_2 ON table_sch_conf (
  conf_id);
CREATE INDEX sch_conf_IK_3 ON table_sch_conf (
  category_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_conf TO PUBLIC;




CREATE TABLE table_sch_monitored (
  schedule_id BIGINT NOT NULL,
  monitored_id BIGINT NOT NULL);
CREATE UNIQUE INDEX sch_monitored_UK_1 ON table_sch_monitored (
  schedule_id,
  monitored_id);
CREATE INDEX sch_monitored_IK_1 ON table_sch_monitored (
  schedule_id);
CREATE INDEX sch_monitored_IK_2 ON table_sch_monitored (
  monitored_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sch_monitored TO PUBLIC;


CREATE TABLE table_search (
  search_id BIGINT NOT NULL IDENTITY,
  search_name VARCHAR(128) NOT NULL,
  type TINYINT NOT NULL,
  search_data TEXT);
ALTER TABLE table_search ADD CONSTRAINT PRIMARY_86 PRIMARY KEY (
  search_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_search TO PUBLIC;


CREATE TABLE table_search_cust_string (
  search_id BIGINT NOT NULL,
  cust_string_id BIGINT NOT NULL,
  value VARCHAR(512) NOT NULL);
CREATE UNIQUE INDEX search_cust_string_UK_1 ON table_search_cust_string (
  search_id,
  cust_string_id);
CREATE INDEX search_cust_string_IK_1 ON table_search_cust_string (
  search_id);
CREATE INDEX search_cust_string_IK_2 ON table_search_cust_string (
  cust_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_search_cust_string TO PUBLIC;
ALTER TABLE table_search_cust_string ADD CONSTRAINT table_search_cust_str_ibfk_1 FOREIGN KEY (search_id) REFERENCES table_search (search_id) ON DELETE CASCADE;
ALTER TABLE table_search_cust_string ADD CONSTRAINT table_search_cust_str_ibfk_2 FOREIGN KEY (cust_string_id) REFERENCES table_cust_string (cust_string_id) ON DELETE CASCADE;


CREATE TABLE table_search_cust_integer (
  search_id BIGINT NOT NULL,
  cust_integer_id BIGINT NOT NULL,
  value BIGINT NOT NULL);
CREATE UNIQUE INDEX search_cust_integer_UK_1 ON table_search_cust_integer (
  search_id,
  cust_integer_id);
CREATE INDEX search_cust_integer_IK_1 ON table_search_cust_integer (
  search_id);
CREATE INDEX search_cust_integer_IK_2 ON table_search_cust_integer (
  cust_integer_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_search_cust_integer TO PUBLIC;
ALTER TABLE table_search_cust_integer ADD CONSTRAINT table_search_cust_int_ibfk_1 FOREIGN KEY (search_id) REFERENCES table_search (search_id) ON DELETE CASCADE;
ALTER TABLE table_search_cust_integer ADD CONSTRAINT table_search_cust_int_ibfk_2 FOREIGN KEY (cust_integer_id) REFERENCES table_cust_integer (cust_integer_id) ON DELETE CASCADE;


CREATE TABLE table_search_cust_boolean (
  search_id BIGINT NOT NULL,
  cust_boolean_id BIGINT NOT NULL,
  value TINYINT NOT NULL);
CREATE UNIQUE INDEX search_cust_boolean_UK_1 ON table_search_cust_boolean (
  search_id,
  cust_boolean_id);
CREATE INDEX search_cust_boolean_IK_1 ON table_search_cust_boolean (
  search_id);
CREATE INDEX search_cust_boolean_IK_2 ON table_search_cust_boolean (
  cust_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_search_cust_boolean TO PUBLIC;
ALTER TABLE table_search_cust_boolean ADD CONSTRAINT table_search_cust_bool_ibfk_1 FOREIGN KEY (search_id) REFERENCES table_search (search_id) ON DELETE CASCADE;
ALTER TABLE table_search_cust_boolean ADD CONSTRAINT table_search_cust_bool_ibfk_2 FOREIGN KEY (cust_boolean_id) REFERENCES table_cust_boolean (cust_boolean_id) ON DELETE CASCADE;


CREATE TABLE table_search_cust_html (
  search_id BIGINT NOT NULL,
  cust_html_id BIGINT NOT NULL,
  value TEXT);
CREATE UNIQUE INDEX search_cust_html_UK_1 ON table_search_cust_html (
  search_id,
  cust_html_id);
CREATE INDEX search_cust_html_IK_1 ON table_search_cust_html (
  search_id);
CREATE INDEX search_cust_html_IK_2 ON table_search_cust_html (
  cust_html_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_search_cust_html TO PUBLIC;
ALTER TABLE table_search_cust_html ADD CONSTRAINT table_search_cust_html_ibfk_1 FOREIGN KEY (search_id) REFERENCES table_search (search_id) ON DELETE CASCADE;
ALTER TABLE table_search_cust_html ADD CONSTRAINT table_search_cust_html_ibfk_2 FOREIGN KEY (cust_html_id) REFERENCES table_cust_html (cust_html_id) ON DELETE CASCADE;


CREATE TABLE table_search_cust_choice (
  search_id BIGINT NOT NULL,
  cust_choice_id BIGINT NOT NULL,
  value VARCHAR(64) NOT NULL);
CREATE UNIQUE INDEX search_cust_choice_UK_1 ON table_search_cust_choice (
  search_id,
  cust_choice_id);
CREATE INDEX search_cust_choice_IK_1 ON table_search_cust_choice (
  search_id);
CREATE INDEX search_cust_choice_IK_2 ON table_search_cust_choice (
  cust_choice_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_search_cust_choice TO PUBLIC;
ALTER TABLE table_search_cust_choice ADD CONSTRAINT table_search_cust_chce_ibfk_1 FOREIGN KEY (search_id) REFERENCES table_search (search_id) ON DELETE CASCADE;
ALTER TABLE table_search_cust_choice ADD CONSTRAINT table_search_cust_chce_ibfk_2 FOREIGN KEY (cust_choice_id) REFERENCES table_cust_choice (cust_choice_id) ON DELETE CASCADE;




CREATE TABLE table_sess (
  campaign_session_id BIGINT NOT NULL IDENTITY,
  user_id BIGINT NOT NULL,
  campaign_id BIGINT,
  sut_id BIGINT NOT NULL,
  campaign_session_name VARCHAR(128) NOT NULL,
  campaign_session_startDate DATETIME,
  campaign_session_stopDate DATETIME,
  campaign_session_status BIGINT DEFAULT '1' NOT NULL,
  schedule_id BIGINT,
  introduction TEXT,
  conclusion TEXT,
  on_parent_failed TINYINT DEFAULT '3' NOT NULL,
  on_parent_unknown TINYINT DEFAULT '1' NOT NULL,
  monitoring_id BIGINT,
  monitoring_conf_id BIGINT,
  pick TINYINT DEFAULT '1' NOT NULL);
ALTER TABLE table_sess ADD CONSTRAINT PRIMARY_70 PRIMARY KEY (
  campaign_session_id);
CREATE INDEX sess_IK_1 ON table_sess (
  sut_id);
CREATE INDEX sess_IK_2 ON table_sess (
  campaign_id);
CREATE INDEX sess_IK_3 ON table_sess (
  user_id);
CREATE INDEX sess_IK_4 ON table_sess (
  schedule_id);
CREATE INDEX sess_IK_5 ON table_sess (
  monitoring_id);
CREATE INDEX sess_IK_6 ON table_sess (
  monitoring_conf_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess TO PUBLIC;




CREATE TABLE table_sess_agent_status (
  campaign_session_id BIGINT NOT NULL,
  agent_id BIGINT NOT NULL,
  campaign_session_agent_status BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_sess_agent_status ADD CONSTRAINT PRIMARY_71 PRIMARY KEY (
  campaign_session_id,
  agent_id);
CREATE INDEX sess_agent_status_IK_1 ON table_sess_agent_status (
  campaign_session_id);
CREATE INDEX sess_agent_status_IK_2 ON table_sess_agent_status (
  agent_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_agent_status TO PUBLIC;




CREATE TABLE table_sess_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  campaign_session_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_sess_attach ADD CONSTRAINT PRIMARY_72 PRIMARY KEY (
  attachment_id);
CREATE INDEX sess_attach_IK_1 ON table_sess_attach (
  locked_by);
CREATE INDEX sess_attach_IK_2 ON table_sess_attach (
  campaign_session_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_attach TO PUBLIC;




CREATE TABLE table_sess_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_sess_attach_data ADD CONSTRAINT PRIMARY_73 PRIMARY KEY (
  data_id);
CREATE INDEX sess_attach_data_IK_1 ON table_sess_attach_data (
  attachment_id);
CREATE INDEX sess_attach_data_IK_2 ON table_sess_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_attach_data TO PUBLIC;




CREATE TABLE table_sess_attr_boolean (
  campaign_session_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  attr_boolean_id BIGINT NOT NULL,
  value TINYINT DEFAULT '0' NOT NULL);

CREATE INDEX sess_attr_boolean_IK_1 ON table_sess_attr_boolean (
  campaign_session_id);
CREATE INDEX sess_attr_boolean_IK_2 ON table_sess_attr_boolean (
  test_id);
CREATE INDEX sess_attr_boolean_IK_3 ON table_sess_attr_boolean (
  attr_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_attr_boolean TO PUBLIC;




CREATE TABLE table_sess_attr_integer (
  campaign_session_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  attr_integer_id BIGINT NOT NULL,
  value TEXT NOT NULL);

CREATE INDEX sess_attr_integer_IK_2 ON table_sess_attr_integer (
  test_id);
CREATE INDEX sess_attr_integer_IK_3 ON table_sess_attr_integer (
  attr_integer_id);
CREATE INDEX sess_attr_integer_IK_1 ON table_sess_attr_integer (
  campaign_session_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_attr_integer TO PUBLIC;




CREATE TABLE table_sess_attr_string (
  campaign_session_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  attr_string_id BIGINT NOT NULL,
  value TEXT);

CREATE INDEX sess_attr_string_IK_1 ON table_sess_attr_string (
  campaign_session_id);
CREATE INDEX sess_attr_string_IK_2 ON table_sess_attr_string (
  test_id);
CREATE INDEX sess_attr_string_IK_3 ON table_sess_attr_string (
  attr_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_attr_string TO PUBLIC;



CREATE TABLE table_sess_param_boolean (
  campaign_session_id BIGINT NOT NULL,
  param_boolean_id BIGINT NOT NULL,
  value TINYINT DEFAULT '0' NOT NULL);

CREATE INDEX sess_param_boolean_IK_1 ON table_sess_param_boolean (
  campaign_session_id);
CREATE INDEX sess_param_boolean_IK_2 ON table_sess_param_boolean (
  param_boolean_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_param_boolean TO PUBLIC;


CREATE TABLE table_sess_param_integer (
  campaign_session_id BIGINT NOT NULL,
  param_integer_id BIGINT NOT NULL,
  value TEXT NOT NULL);

CREATE INDEX sess_param_integer_IK_1 ON table_sess_param_integer (
  campaign_session_id);
CREATE INDEX sess_param_integer_IK_2 ON table_sess_param_integer (
  param_integer_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_param_integer TO PUBLIC;


CREATE TABLE table_sess_param_string (
  campaign_session_id BIGINT NOT NULL,
  param_string_id BIGINT NOT NULL,
  value TEXT);

CREATE INDEX sess_param_string_IK_1 ON table_sess_param_string (
  campaign_session_id);
CREATE INDEX sess_param_string_IK_3 ON table_sess_param_string (
  param_string_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_param_string TO PUBLIC;



CREATE TABLE table_sess_ccemails (
  campaign_session_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL);
CREATE INDEX sess_ccemails_IK_1 ON table_sess_ccemails (
  campaign_session_id);
CREATE INDEX sess_ccemails_IK_2 ON table_sess_ccemails (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_ccemails TO PUBLIC;




CREATE TABLE table_sess_conf (
  campaign_session_id BIGINT NOT NULL,
  conf_id BIGINT NOT NULL,
  category_id BIGINT NOT NULL);
CREATE INDEX sess_conf_IK_1 ON table_sess_conf (
  campaign_session_id);
CREATE INDEX sess_conf_IK_2 ON table_sess_conf (
  conf_id);
CREATE INDEX sess_conf_IK_3 ON table_sess_conf (
  category_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sess_conf TO PUBLIC;




CREATE TABLE table_spec (
  specification_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  specification_name VARCHAR(128) NOT NULL);
ALTER TABLE table_spec ADD CONSTRAINT PRIMARY_74 PRIMARY KEY (
  specification_id);
CREATE INDEX spec_IK_1 ON table_spec (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_spec TO PUBLIC;




CREATE TABLE table_spec_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  specification_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_spec_attach ADD CONSTRAINT PRIMARY_75 PRIMARY KEY (
  attachment_id);
CREATE INDEX spec_attach_IK_1 ON table_spec_attach (
  locked_by);
CREATE INDEX spec_attach_IK_2 ON table_spec_attach (
  specification_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_spec_attach TO PUBLIC;




CREATE TABLE table_spec_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_spec_attach_data ADD CONSTRAINT PRIMARY_76 PRIMARY KEY (
  data_id);
CREATE INDEX spec_attach_data_IK_1 ON table_spec_attach_data (
  attachment_id);
CREATE INDEX spec_attach_data_IK_2 ON table_spec_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_spec_attach_data TO PUBLIC;




CREATE TABLE table_spec_data (
  data_id BIGINT NOT NULL IDENTITY,
  specification_id BIGINT NOT NULL,
  specification_isFormal TINYINT DEFAULT '0' NOT NULL,
  specification_description TEXT,
  priority TINYINT DEFAULT '20' NOT NULL,
  status TINYINT DEFAULT '30' NOT NULL,
  date_submitted DATETIME,
  revision BIGINT DEFAULT '1' NOT NULL,
  coverage TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_spec_data ADD CONSTRAINT PRIMARY_77 PRIMARY KEY (
  data_id);
CREATE UNIQUE INDEX spec_data_UK_1 ON table_spec_data (
  specification_id,
  revision);
CREATE INDEX spec_data_IK_1 ON table_spec_data (
  specification_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_spec_data TO PUBLIC;




CREATE TABLE table_spec_test (
  specification_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL);
CREATE INDEX spec_test_IK_1 ON table_spec_test (
  test_id);
CREATE INDEX spec_test_IK_2 ON table_spec_test (
  specification_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_spec_test TO PUBLIC;




CREATE TABLE table_sprint (
  sprint_id BIGINT NOT NULL IDENTITY,
  sprint_name VARCHAR(128) NOT NULL,
  sprint_description TEXT,
  status TINYINT NOT NULL,
  start_date DATETIME,
  stop_date DATETIME,
  project_id BIGINT NOT NULL);
ALTER TABLE table_sprint ADD CONSTRAINT PRIMARY_78 PRIMARY KEY (
  sprint_id);
CREATE INDEX sprint_IK_1 ON table_sprint (
  project_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sprint TO PUBLIC;




CREATE TABLE table_sprint_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  sprint_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_sprint_attach ADD CONSTRAINT PRIMARY_79 PRIMARY KEY (
  attachment_id);
CREATE INDEX sprint_attach_IK_1 ON table_sprint_attach (
  locked_by);
CREATE INDEX sprint_attach_IK_2 ON table_sprint_attach (
  sprint_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sprint_attach TO PUBLIC;




CREATE TABLE table_sprint_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_sprint_attach_data ADD CONSTRAINT PRIMARY_80 PRIMARY KEY (
  data_id);
CREATE INDEX sprint_attach_data_IK_1 ON table_sprint_attach_data (
  attachment_id);
CREATE INDEX sprint_attach_data_IK_2 ON table_sprint_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sprint_attach_data TO PUBLIC;




CREATE TABLE table_sprint_developer (
  sprint_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL,
  availability TINYINT DEFAULT '0' NOT NULL);
CREATE INDEX sprint_developer_IK_1 ON table_sprint_developer (
  sprint_id);
CREATE INDEX sprint_developer_IK_2 ON table_sprint_developer (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sprint_developer TO PUBLIC;




CREATE TABLE table_sprint_stat (
  sprint_id BIGINT NOT NULL,
  date_submitted DATETIME,
  stat TEXT NOT NULL);
CREATE INDEX sprint_stat_IK_1 ON table_sprint_stat (
  sprint_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sprint_stat TO PUBLIC;




CREATE TABLE table_sprint_task (
  sprint_id BIGINT NOT NULL,
  task_id BIGINT NOT NULL,
  progress TINYINT DEFAULT '0' NOT NULL,
  assigned_to BIGINT);
CREATE INDEX sprint_task_IK_1 ON table_sprint_task (
  sprint_id);
CREATE INDEX sprint_task_IK_2 ON table_sprint_task (
  task_id);
CREATE INDEX sprint_task_IK_3 ON table_sprint_task (
  assigned_to);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sprint_task TO PUBLIC;




CREATE TABLE table_sut (
  sut_id BIGINT NOT NULL IDENTITY,
  sut_name VARCHAR(128) NOT NULL,
  folder_id BIGINT NOT NULL);
ALTER TABLE table_sut ADD CONSTRAINT PRIMARY_81 PRIMARY KEY (
  sut_id);
CREATE INDEX sut_IK_1 ON table_sut (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sut TO PUBLIC;




CREATE TABLE table_sut_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  sut_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_sut_attach ADD CONSTRAINT PRIMARY_82 PRIMARY KEY (
  attachment_id);
CREATE INDEX sut_attach_IK_1 ON table_sut_attach (
  locked_by);
CREATE INDEX sut_attach_IK_2 ON table_sut_attach (
  sut_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sut_attach TO PUBLIC;




CREATE TABLE table_sut_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_sut_attach_data ADD CONSTRAINT PRIMARY_83 PRIMARY KEY (
  data_id);
CREATE INDEX sut_attach_data_IK_1 ON table_sut_attach_data (
  attachment_id);
CREATE INDEX sut_attach_data_IK_2 ON table_sut_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sut_attach_data TO PUBLIC;




CREATE TABLE table_sut_data (
  data_id BIGINT NOT NULL IDENTITY,
  sut_id BIGINT NOT NULL,
  sut_version VARCHAR(64),
  date_submitted DATETIME,
  revision BIGINT DEFAULT '1' NOT NULL,
  coverage TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_sut_data ADD CONSTRAINT PRIMARY_84 PRIMARY KEY (
  data_id);
CREATE UNIQUE INDEX sut_data_UK_1 ON table_sut_data (
  sut_id,
  revision);
CREATE INDEX sut_data_IK_1 ON table_sut_data (
  sut_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sut_data TO PUBLIC;




CREATE TABLE table_sut_req (
  sut_id BIGINT NOT NULL,
  requirement_id BIGINT NOT NULL);
CREATE INDEX sut_req_IK_1 ON table_sut_req (
  sut_id);
CREATE INDEX sut_req_IK_2 ON table_sut_req (
  requirement_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sut_req TO PUBLIC;




CREATE TABLE table_sync (
  instance_id BIGINT NOT NULL,
  category_id BIGINT NOT NULL,
  sync_id BIGINT DEFAULT '0' NOT NULL);
CREATE UNIQUE INDEX sync_UK_1 ON table_sync (
  instance_id,
  category_id,
  sync_id);
CREATE INDEX sync_IK_1 ON table_sync (
  instance_id);
CREATE INDEX sync_IK_2 ON table_sync (
  category_id);
CREATE INDEX sync_IK_3 ON table_sync (
  sync_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_sync TO PUBLIC;




CREATE TABLE table_task (
  task_id BIGINT NOT NULL IDENTITY,
  folder_id BIGINT NOT NULL,
  task_name VARCHAR(128) NOT NULL,
  task_description TEXT,
  priority TINYINT NOT NULL,
  estimated FLOAT DEFAULT 1.0 NOT NULL);
ALTER TABLE table_task ADD CONSTRAINT PRIMARY_85 PRIMARY KEY (
  task_id);
CREATE INDEX task_IK_1 ON table_task (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_task TO PUBLIC;




CREATE TABLE table_task_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  task_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_task_attach ADD CONSTRAINT PRIMARY_40 PRIMARY KEY (
  attachment_id);
CREATE INDEX task_attach_IK_1 ON table_task_attach (
  locked_by);
CREATE INDEX task_attach_IK_2 ON table_task_attach (
  task_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_task_attach TO PUBLIC;




CREATE TABLE table_task_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_task_attach_data ADD CONSTRAINT PRIMARY_41 PRIMARY KEY (
  data_id);
CREATE INDEX task_attach_data_IK_1 ON table_task_attach_data (
  attachment_id);
CREATE INDEX task_attach_data_IK_2 ON table_task_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_task_attach_data TO PUBLIC;




CREATE TABLE table_test (
  test_id BIGINT NOT NULL IDENTITY,
  author_id BIGINT NOT NULL,
  folder_id BIGINT NOT NULL,
  test_name VARCHAR(128) NOT NULL,
  test_estimatedTime BIGINT DEFAULT '0' NOT NULL,
  developer_id BIGINT);
ALTER TABLE table_test ADD CONSTRAINT PRIMARY_42 PRIMARY KEY (
  test_id);
CREATE INDEX test_IK_1 ON table_test (
  folder_id);
CREATE INDEX test_IK_2 ON table_test (
  author_id);
CREATE INDEX test_IK_3 ON table_test (
  developer_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test TO PUBLIC;




CREATE TABLE table_test_attach (
  attachment_id BIGINT NOT NULL IDENTITY,
  test_id BIGINT NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  locked_by BIGINT,
  hidden TINYINT DEFAULT '0' NOT NULL);
ALTER TABLE table_test_attach ADD CONSTRAINT PRIMARY_43 PRIMARY KEY (
  attachment_id);
CREATE INDEX test_attach_IK_1 ON table_test_attach (
  locked_by);
CREATE INDEX test_attach_IK_2 ON table_test_attach (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_attach TO PUBLIC;




CREATE TABLE table_test_attach_data (
  data_id BIGINT NOT NULL IDENTITY,
  attachment_id BIGINT NOT NULL,
  attachment_data VARBINARY(MAX),
  date_submitted DATETIME,
  size_data BIGINT NOT NULL,
  author_id BIGINT NOT NULL,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_test_attach_data ADD CONSTRAINT PRIMARY_44 PRIMARY KEY (
  data_id);
CREATE INDEX test_attach_data_IK_1 ON table_test_attach_data (
  attachment_id);
CREATE INDEX test_attach_data_IK_2 ON table_test_attach_data (
  author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_attach_data TO PUBLIC;




CREATE TABLE table_test_attr_boolean (
  test_id BIGINT NOT NULL,
  attr_boolean_id BIGINT NOT NULL,
  test_attr_boolean_value TINYINT DEFAULT '0' NOT NULL);
CREATE INDEX test_attr_boolean_IK_1 ON table_test_attr_boolean (
  attr_boolean_id);
CREATE INDEX test_attr_boolean_IK_2 ON table_test_attr_boolean (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_attr_boolean TO PUBLIC;




CREATE TABLE table_test_attr_integer (
  test_id BIGINT NOT NULL,
  attr_integer_id BIGINT NOT NULL,
  test_attr_integer_value TEXT NOT NULL);
CREATE INDEX test_attr_integer_IK_1 ON table_test_attr_integer (
  attr_integer_id);
CREATE INDEX test_attr_integer_IK_2 ON table_test_attr_integer (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_attr_integer TO PUBLIC;




CREATE TABLE table_test_attr_string (
  test_id BIGINT NOT NULL,
  attr_string_id BIGINT NOT NULL,
  test_attr_string_value TEXT);


CREATE INDEX test_attr_string_IK_1 ON table_test_attr_string (
  attr_string_id);
CREATE INDEX test_attr_string_IK_2 ON table_test_attr_string (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_attr_string TO PUBLIC;




CREATE TABLE table_test_camp (
  campaign_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  position BIGINT DEFAULT '0' NOT NULL);
CREATE INDEX test_camp_IK_1 ON table_test_camp (
  test_id);
CREATE INDEX test_camp_IK_2 ON table_test_camp (
  campaign_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_camp TO PUBLIC;




CREATE TABLE table_test_data (
  data_id BIGINT NOT NULL IDENTITY,
  test_id BIGINT NOT NULL,
  test_description TEXT,
  test_priority BIGINT DEFAULT '99' NOT NULL,
  test_canonicalPath VARCHAR(255),
  test_prerequisites TEXT,
  additional_info TEXT,
  date_submitted DATETIME,
  revision BIGINT DEFAULT '1' NOT NULL);
ALTER TABLE table_test_data ADD CONSTRAINT PRIMARY_45 PRIMARY KEY (
  data_id);
CREATE UNIQUE INDEX test_data_UK_1 ON table_test_data (
  test_id,
  revision);
CREATE INDEX test_data_IK_1 ON table_test_data (
  test_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_data TO PUBLIC;




CREATE TABLE table_test_dependencies (
  test_id BIGINT NOT NULL,
  dependsFromTest_id BIGINT NOT NULL);
CREATE INDEX test_dependencies_IK_1 ON table_test_dependencies (
  test_id);
CREATE INDEX test_dependencies_IK_2 ON table_test_dependencies (
  dependsFromTest_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_dependencies TO PUBLIC;




CREATE TABLE table_test_exec (
  test_exec_id BIGINT NOT NULL IDENTITY,
  campaign_session_id BIGINT NOT NULL,
  test_id BIGINT NOT NULL,
  test_exec_result BIGINT NOT NULL,
  timestamp BIGINT DEFAULT '0' NOT NULL,
  instance_id BIGINT NOT NULL);
ALTER TABLE table_test_exec ADD CONSTRAINT PRIMARY_46 PRIMARY KEY (
  test_exec_id);
CREATE UNIQUE INDEX test_exec_UK_1 ON table_test_exec (
  campaign_session_id,
  test_id,
  instance_id);
CREATE INDEX test_exec_IK_1 ON table_test_exec (
  test_id);
CREATE INDEX test_exec_IK_2 ON table_test_exec (
  campaign_session_id);
CREATE INDEX test_exec_IK_3 ON table_test_exec (
  instance_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_exec TO PUBLIC;




CREATE TABLE table_test_exec_def (
  defect_id BIGINT NOT NULL,
  test_exec_id BIGINT NOT NULL);
CREATE UNIQUE INDEX test_exec_def_UK_1 ON table_test_exec_def (
  defect_id,
  test_exec_id);
CREATE INDEX test_exec_def_IK_1 ON table_test_exec_def (
  test_exec_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_exec_def TO PUBLIC;




CREATE TABLE table_test_url (
  url_id BIGINT NOT NULL IDENTITY,
  test_data_id BIGINT NOT NULL,
  url VARCHAR(384) NOT NULL);
ALTER TABLE table_test_url ADD CONSTRAINT PRIMARY_47 PRIMARY KEY (
  url_id);
CREATE INDEX test_url_IK_1 ON table_test_url (
  test_data_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_test_url TO PUBLIC;




CREATE TABLE table_user (
  user_id BIGINT NOT NULL IDENTITY,
  user_name VARCHAR(128) NOT NULL,
  folder_id BIGINT NOT NULL,
  user_password TEXT,
  user_local VARCHAR(5) DEFAULT 'en_US' NOT NULL,
  user_email VARCHAR(50) NOT NULL,
  user_enabled TINYINT DEFAULT '1' NOT NULL,
  country_id CHAR(2) DEFAULT 'US' NOT NULL,
  userprofile_id BIGINT);
ALTER TABLE table_user ADD CONSTRAINT PRIMARY_48 PRIMARY KEY (
  user_id);
CREATE INDEX user_IK_1 ON table_user (
  folder_id);
CREATE INDEX user_IK_2 ON table_user (
  country_id);
CREATE INDEX user_IK_3 ON table_user (
  userprofile_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_user TO PUBLIC;




CREATE TABLE table_usergroup (
  usergroup_id BIGINT NOT NULL IDENTITY,
  usergroup_name VARCHAR(128) NOT NULL,
  folder_id BIGINT NOT NULL);
ALTER TABLE table_usergroup ADD CONSTRAINT PRIMARY_49 PRIMARY KEY (
  usergroup_id);
CREATE INDEX usergroup_IK_1 ON table_usergroup (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_usergroup TO PUBLIC;




CREATE TABLE table_usergroup_category (
  usergroup_id BIGINT NOT NULL,
  category_id BIGINT NOT NULL);
CREATE UNIQUE INDEX usergroup_category_UK_1 ON table_usergroup_category (
  usergroup_id,
  category_id);
CREATE INDEX usergroup_category_IK_1 ON table_usergroup_category (
  usergroup_id);
CREATE INDEX usergroup_category_IK_2 ON table_usergroup_category (
  category_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_usergroup_category TO PUBLIC;




CREATE TABLE table_usergroup_company (
  usergroup_id BIGINT NOT NULL,
  company_id BIGINT NOT NULL);
CREATE UNIQUE INDEX usergroup_company_UK_1 ON table_usergroup_company (
  usergroup_id,
  company_id);
CREATE INDEX usergroup_company_IK_1 ON table_usergroup_company (
  usergroup_id);
CREATE INDEX usergroup_company_IK_2 ON table_usergroup_company (
  company_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_usergroup_company TO PUBLIC;




CREATE TABLE table_usergroup_folder (
  usergroup_id BIGINT NOT NULL,
  folder_id BIGINT NOT NULL);
CREATE UNIQUE INDEX usergroup_folder_UK_1 ON table_usergroup_folder (
  usergroup_id,
  folder_id);
CREATE INDEX usergroup_folder_IK_1 ON table_usergroup_folder (
  usergroup_id);
CREATE INDEX usergroup_folder_IK_2 ON table_usergroup_folder (
  folder_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_usergroup_folder TO PUBLIC;




CREATE TABLE table_usergroup_user (
  usergroup_id BIGINT NOT NULL,
  user_id BIGINT NOT NULL);
CREATE UNIQUE INDEX usergroup_user_UK_1 ON table_usergroup_user (
  usergroup_id,
  user_id);
CREATE INDEX usergroup_user_IK_1 ON table_usergroup_user (
  usergroup_id);
CREATE INDEX usergroup_user_IK_2 ON table_usergroup_user (
  user_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_usergroup_user TO PUBLIC;




CREATE TABLE table_userprofile (
  userprofile_id BIGINT NOT NULL IDENTITY,
  userprofile_name VARCHAR(128) NOT NULL,
  rights TEXT);
ALTER TABLE table_userprofile ADD CONSTRAINT PRIMARY_50 PRIMARY KEY (
  userprofile_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_userprofile TO PUBLIC;




CREATE TABLE table_version (
  version_id BIGINT NOT NULL IDENTITY,
  version_number BIGINT);
ALTER TABLE table_version ADD CONSTRAINT PRIMARY_51 PRIMARY KEY (
  version_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_version TO PUBLIC;




CREATE TABLE table_weekend (
  weekend_id BIGINT NOT NULL IDENTITY,
  country_id CHAR(2) NOT NULL,
  days VARCHAR(14));
ALTER TABLE table_weekend ADD CONSTRAINT PRIMARY_52 PRIMARY KEY (
  weekend_id);
CREATE INDEX weekend_IK_1 ON table_weekend (
  country_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_weekend TO PUBLIC;




ALTER TABLE table_project_manager ADD CONSTRAINT table_project_manager_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_req_generic ADD CONSTRAINT table_req_generic_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id) ON DELETE CASCADE;
ALTER TABLE table_req_int ADD CONSTRAINT table_req_int_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id) ON DELETE CASCADE;
ALTER TABLE table_req_int_attach ADD CONSTRAINT table_req_int_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_req_int_attach ADD CONSTRAINT table_req_int_attach_ibfk_2 FOREIGN KEY (requirement_id) REFERENCES table_req_int (requirement_id) ON DELETE CASCADE;
ALTER TABLE table_req_int_attach_data ADD CONSTRAINT table_req_int_attach_data_ibfk FOREIGN KEY (attachment_id) REFERENCES table_req_int_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_req_int_attach_data ADD CONSTRAINT TABLE_REQ_INT_ATTACH_DATA_I_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_req_int_data ADD CONSTRAINT table_req_int_data_ibfk_1 FOREIGN KEY (requirement_id) REFERENCES table_req_int (requirement_id) ON DELETE CASCADE;
ALTER TABLE table_req_spec ADD CONSTRAINT table_req_spec_ibfk_1 FOREIGN KEY (specification_id) REFERENCES table_spec (specification_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_req_test ADD CONSTRAINT table_req_test_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_sch ADD CONSTRAINT table_sch_ibfk_1 FOREIGN KEY (campaign_id) REFERENCES table_camp (campaign_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch ADD CONSTRAINT table_sch_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch ADD CONSTRAINT table_sch_ibfk_3 FOREIGN KEY (sut_id) REFERENCES table_sut (sut_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch ADD CONSTRAINT table_sch_ibfk_4 FOREIGN KEY (monitoring_id) REFERENCES table_agent (agent_id); -- ON DELETE USELESS
ALTER TABLE table_sch ADD CONSTRAINT table_sch_ibfk_5 FOREIGN KEY (monitoring_conf_id) REFERENCES table_monitoring_conf (monitoring_conf_id); -- ON DELETE USELESS
ALTER TABLE table_sch_agent ADD CONSTRAINT table_sch_agent_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_agent ADD CONSTRAINT table_sch_agent_ibfk_2 FOREIGN KEY (agent_id) REFERENCES table_agent (agent_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_boolean ADD CONSTRAINT table_sch_attr_boolean_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_boolean ADD CONSTRAINT table_sch_attr_boolean_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_boolean ADD CONSTRAINT table_sch_attr_boolean_ibfk_3 FOREIGN KEY (attr_boolean_id) REFERENCES table_attr_boolean (attr_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_sch_attr_integer ADD CONSTRAINT table_sch_attr_integer_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_integer ADD CONSTRAINT table_sch_attr_integer_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_integer ADD CONSTRAINT table_sch_attr_integer_ibfk_3 FOREIGN KEY (attr_integer_id) REFERENCES table_attr_integer (attr_integer_id) ON DELETE CASCADE;
ALTER TABLE table_sch_attr_string ADD CONSTRAINT table_sch_attr_string_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_string ADD CONSTRAINT table_sch_attr_string_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_attr_string ADD CONSTRAINT table_sch_attr_string_ibfk_3 FOREIGN KEY (attr_string_id) REFERENCES table_attr_string (attr_string_id) ON DELETE CASCADE;
ALTER TABLE table_sch_param_boolean ADD CONSTRAINT table_sch_param_boolean_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_param_boolean ADD CONSTRAINT table_sch_param_boolean_ibfk_2 FOREIGN KEY (param_boolean_id) REFERENCES table_param_boolean (param_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_sch_param_integer ADD CONSTRAINT table_sch_param_integer_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_param_integer ADD CONSTRAINT table_sch_param_integer_ibfk_2 FOREIGN KEY (param_integer_id) REFERENCES table_param_integer (param_integer_id) ON DELETE CASCADE;
ALTER TABLE table_sch_param_string ADD CONSTRAINT table_sch_param_string_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_param_string ADD CONSTRAINT table_sch_param_string_ibfk_2 FOREIGN KEY (param_string_id) REFERENCES table_param_string (param_string_id) ON DELETE CASCADE;
ALTER TABLE table_sch_ccemails ADD CONSTRAINT table_sch_ccemails_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_ccemails ADD CONSTRAINT table_sch_ccemails_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sch_conf ADD CONSTRAINT table_sch_conf_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_conf ADD CONSTRAINT table_sch_conf_ibfk_2 FOREIGN KEY (conf_id) REFERENCES table_conf (conf_id) ON DELETE CASCADE;
ALTER TABLE table_sch_conf ADD CONSTRAINT table_sch_conf_ibfk_3 FOREIGN KEY (category_id) REFERENCES table_category (category_id) ON DELETE CASCADE;
ALTER TABLE table_sch_monitored ADD CONSTRAINT table_sch_monitored_ibfk_1 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id) ON DELETE CASCADE;
ALTER TABLE table_sch_monitored ADD CONSTRAINT table_sch_monitored_ibfk_2 FOREIGN KEY (monitored_id) REFERENCES table_agent (agent_id); -- ON DELETE USELESS
ALTER TABLE table_sess ADD CONSTRAINT table_sess_ibfk_1 FOREIGN KEY (sut_id) REFERENCES table_sut (sut_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess ADD CONSTRAINT table_sess_ibfk_2 FOREIGN KEY (campaign_id) REFERENCES table_camp (campaign_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess ADD CONSTRAINT table_sess_ibfk_3 FOREIGN KEY (user_id) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess ADD CONSTRAINT table_sess_ibfk_4 FOREIGN KEY (schedule_id) REFERENCES table_sch (schedule_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess ADD CONSTRAINT table_sess_ibfk_5 FOREIGN KEY (monitoring_id) REFERENCES table_agent (agent_id); -- ON DELETE USELESS
ALTER TABLE table_sess ADD CONSTRAINT table_sess_ibfk_6 FOREIGN KEY (monitoring_conf_id) REFERENCES table_monitoring_conf (monitoring_conf_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_agent_status ADD CONSTRAINT table_sess_agent_status_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_agent_status ADD CONSTRAINT table_sess_agent_status_ibfk_2 FOREIGN KEY (agent_id) REFERENCES table_agent (agent_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attach ADD CONSTRAINT table_sess_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_sess_attach ADD CONSTRAINT table_sess_attach_ibfk_2 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id) ON DELETE CASCADE;
ALTER TABLE table_sess_attach_data ADD CONSTRAINT table_sess_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_sess_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_sess_attach_data ADD CONSTRAINT table_sess_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_sess_attr_boolean ADD CONSTRAINT table_sess_attr_boolean_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attr_boolean ADD CONSTRAINT table_sess_attr_boolean_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attr_boolean ADD CONSTRAINT table_sess_attr_boolean_ibfk_3 FOREIGN KEY (attr_boolean_id) REFERENCES table_attr_boolean (attr_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_sess_attr_integer ADD CONSTRAINT table_sess_attr_integer_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attr_integer ADD CONSTRAINT table_sess_attr_integer_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attr_integer ADD CONSTRAINT table_sess_attr_integer_ibfk_3 FOREIGN KEY (attr_integer_id) REFERENCES table_attr_integer (attr_integer_id) ON DELETE CASCADE;
ALTER TABLE table_sess_attr_string ADD CONSTRAINT table_sess_attr_string_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attr_string ADD CONSTRAINT table_sess_attr_string_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_attr_string ADD CONSTRAINT table_sess_attr_string_ibfk_3 FOREIGN KEY (attr_string_id) REFERENCES table_attr_string (attr_string_id) ON DELETE CASCADE;
ALTER TABLE table_sess_param_boolean ADD CONSTRAINT table_sess_param_boolea_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_param_boolean ADD CONSTRAINT table_sess_param_boolea_ibfk_2 FOREIGN KEY (param_boolean_id) REFERENCES table_param_boolean (param_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_sess_param_integer ADD CONSTRAINT table_sess_param_intege_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_param_integer ADD CONSTRAINT table_sess_param_intege_ibfk_2 FOREIGN KEY (param_integer_id) REFERENCES table_param_integer (param_integer_id) ON DELETE CASCADE;
ALTER TABLE table_sess_param_string ADD CONSTRAINT table_sess_param_string_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_param_string ADD CONSTRAINT table_sess_param_string_ibfk_2 FOREIGN KEY (param_string_id) REFERENCES table_param_string (param_string_id) ON DELETE CASCADE;
ALTER TABLE table_sess_ccemails ADD CONSTRAINT table_sess_ccemails_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_ccemails ADD CONSTRAINT table_sess_ccemails_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sess_conf ADD CONSTRAINT table_sess_conf_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id) ON DELETE CASCADE;
ALTER TABLE table_sess_conf ADD CONSTRAINT table_sess_conf_ibfk_2 FOREIGN KEY (conf_id) REFERENCES table_conf (conf_id) ON DELETE CASCADE;
ALTER TABLE table_sess_conf ADD CONSTRAINT table_sess_conf_ibfk_3 FOREIGN KEY (category_id) REFERENCES table_category (category_id) ON DELETE CASCADE;
ALTER TABLE table_spec ADD CONSTRAINT table_spec_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_spec_attach ADD CONSTRAINT table_spec_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_spec_attach ADD CONSTRAINT table_spec_attach_ibfk_2 FOREIGN KEY (specification_id) REFERENCES table_spec (specification_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_spec_attach_data ADD CONSTRAINT table_spec_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_spec_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_spec_attach_data ADD CONSTRAINT table_spec_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_spec_data ADD CONSTRAINT table_spec_data_ibfk_1 FOREIGN KEY (specification_id) REFERENCES table_spec (specification_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_spec_test ADD CONSTRAINT table_spec_test_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_spec_test ADD CONSTRAINT table_spec_test_ibfk_2 FOREIGN KEY (specification_id) REFERENCES table_spec (specification_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sprint ADD CONSTRAINT table_sprint_ibfk_1 FOREIGN KEY (project_id) REFERENCES table_project (project_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sprint_attach ADD CONSTRAINT table_sprint_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_attach ADD CONSTRAINT table_sprint_attach_ibfk_2 FOREIGN KEY (sprint_id) REFERENCES table_sprint (sprint_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_attach_data ADD CONSTRAINT table_sprint_attach_data_ibfk_ FOREIGN KEY (attachment_id) REFERENCES table_sprint_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_attach_data ADD CONSTRAINT TABLE_SPRINT_ATTACH_DATA_IB_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_sprint_developer ADD CONSTRAINT table_sprint_developer_ibfk_1 FOREIGN KEY (sprint_id) REFERENCES table_sprint (sprint_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_developer ADD CONSTRAINT table_sprint_developer_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_stat ADD CONSTRAINT table_sprint_stat_ibfk_1 FOREIGN KEY (sprint_id) REFERENCES table_sprint (sprint_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_task ADD CONSTRAINT table_sprint_task_ibfk_1 FOREIGN KEY (sprint_id) REFERENCES table_sprint (sprint_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sprint_task ADD CONSTRAINT table_sprint_task_ibfk_2 FOREIGN KEY (task_id) REFERENCES table_task (task_id) ON DELETE CASCADE;
ALTER TABLE table_sprint_task ADD CONSTRAINT table_sprint_task_ibfk_3 FOREIGN KEY (assigned_to) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sut ADD CONSTRAINT table_sut_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_sut_attach ADD CONSTRAINT table_sut_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_sut_attach ADD CONSTRAINT table_sut_attach_ibfk_2 FOREIGN KEY (sut_id) REFERENCES table_sut (sut_id) ON DELETE CASCADE;
ALTER TABLE table_sut_attach_data ADD CONSTRAINT table_sut_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_sut_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_sut_attach_data ADD CONSTRAINT table_sut_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_sut_data ADD CONSTRAINT table_sut_data_ibfk_1 FOREIGN KEY (sut_id) REFERENCES table_sut (sut_id) ON DELETE CASCADE;
ALTER TABLE table_sut_req ADD CONSTRAINT table_sut_req_ibfk_1 FOREIGN KEY (sut_id) REFERENCES table_sut (sut_id) ON DELETE CASCADE;
ALTER TABLE table_sync ADD CONSTRAINT table_sync_ibfk_1 FOREIGN KEY (instance_id) REFERENCES table_instance (instance_id) ON DELETE CASCADE;
ALTER TABLE table_sync ADD CONSTRAINT table_sync_ibfk_2 FOREIGN KEY (category_id) REFERENCES table_category (category_id) ON DELETE CASCADE;
ALTER TABLE table_task ADD CONSTRAINT table_task_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id) ON DELETE CASCADE;
ALTER TABLE table_task_attach ADD CONSTRAINT table_task_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_task_attach ADD CONSTRAINT table_task_attach_ibfk_2 FOREIGN KEY (task_id) REFERENCES table_task (task_id) ON DELETE CASCADE;
ALTER TABLE table_task_attach_data ADD CONSTRAINT table_task_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_task_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_task_attach_data ADD CONSTRAINT table_task_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_test ADD CONSTRAINT table_test_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test ADD CONSTRAINT table_test_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test ADD CONSTRAINT table_test_ibfk_3 FOREIGN KEY (developer_id) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test_attach ADD CONSTRAINT table_test_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_test_attach ADD CONSTRAINT table_test_attach_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_test_attach_data ADD CONSTRAINT table_test_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_test_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_test_attach_data ADD CONSTRAINT table_test_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_test_attr_boolean ADD CONSTRAINT table_test_attr_boolean_ibfk_1 FOREIGN KEY (attr_boolean_id) REFERENCES table_attr_boolean (attr_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_test_attr_boolean ADD CONSTRAINT table_test_attr_boolean_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_test_attr_integer ADD CONSTRAINT table_test_attr_integer_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_test_attr_integer ADD CONSTRAINT table_test_attr_integer_ibfk_2 FOREIGN KEY (attr_integer_id) REFERENCES table_attr_integer (attr_integer_id) ON DELETE CASCADE;
ALTER TABLE table_test_attr_string ADD CONSTRAINT table_test_attr_string_ibfk_1 FOREIGN KEY (attr_string_id) REFERENCES table_attr_string (attr_string_id) ON DELETE CASCADE;
ALTER TABLE table_absence ADD CONSTRAINT table_absence_ibfk_1 FOREIGN KEY (user_id) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_agent ADD CONSTRAINT table_agent_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_camp ADD CONSTRAINT table_camp_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_camp_attach ADD CONSTRAINT table_camp_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_camp_attach ADD CONSTRAINT table_camp_attach_ibfk_2 FOREIGN KEY (campaign_id) REFERENCES table_camp (campaign_id) ON DELETE CASCADE;
ALTER TABLE table_camp_attach_data ADD CONSTRAINT table_camp_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_camp_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_camp_attach_data ADD CONSTRAINT table_camp_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_case ADD CONSTRAINT table_case_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_case_attach ADD CONSTRAINT table_case_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_case_attach ADD CONSTRAINT table_case_attach_ibfk_2 FOREIGN KEY (case_id) REFERENCES table_case (case_id) ON DELETE CASCADE;
ALTER TABLE table_case_attach_data ADD CONSTRAINT table_case_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_case_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_case_attach_data ADD CONSTRAINT table_case_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_case_case_data ADD CONSTRAINT table_case_case_data_ibfk_1 FOREIGN KEY (case_id) REFERENCES table_case (case_id) ON DELETE CASCADE;
ALTER TABLE table_case_case_data ADD CONSTRAINT table_case_case_data_ibfk_2 FOREIGN KEY (data_id) REFERENCES table_case_data (data_id) ON DELETE CASCADE;
ALTER TABLE table_case_exec ADD CONSTRAINT table_case_exec_ibfk_1 FOREIGN KEY (case_id) REFERENCES table_case (case_id) ON DELETE CASCADE;
ALTER TABLE table_case_exec ADD CONSTRAINT table_case_exec_ibfk_2 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_case_exec ADD CONSTRAINT table_case_exec_ibfk_3 FOREIGN KEY (instance_id) REFERENCES table_instance (instance_id) ON DELETE CASCADE;
ALTER TABLE table_case_exec_attach ADD CONSTRAINT table_case_exec_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_case_exec_attach ADD CONSTRAINT table_case_exec_attach_ibfk_2 FOREIGN KEY (testcase_exec_id) REFERENCES table_case_exec (testcase_exec_id) ON DELETE CASCADE;
ALTER TABLE table_case_exec_attach_data ADD CONSTRAINT table_case_exec_attach_data_ib FOREIGN KEY (attachment_id) REFERENCES table_case_exec_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_case_exec_attach_data ADD CONSTRAINT TABLE_CASE_EXEC_ATTACH_DATA_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_case_param_boolean ADD CONSTRAINT table_case_param_boolean_ibfk_ FOREIGN KEY (case_id) REFERENCES table_case (case_id) ON DELETE CASCADE;
ALTER TABLE table_case_param_boolean ADD CONSTRAINT TABLE_CASE_PARAM_BOOLEAN_IB_85 FOREIGN KEY (param_boolean_id) REFERENCES table_param_boolean (param_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_case_param_integer ADD CONSTRAINT table_case_param_integer_ibfk_ FOREIGN KEY (case_id) REFERENCES table_case (case_id) ON DELETE CASCADE;
ALTER TABLE table_case_param_integer ADD CONSTRAINT TABLE_CASE_PARAM_INTEGER_IB_85 FOREIGN KEY (param_integer_id) REFERENCES table_param_integer (param_integer_id) ON DELETE CASCADE;
ALTER TABLE table_case_param_string ADD CONSTRAINT table_case_param_string_ibfk_1 FOREIGN KEY (case_id) REFERENCES table_case (case_id) ON DELETE CASCADE;
ALTER TABLE table_case_param_string ADD CONSTRAINT table_case_param_string_ibfk_2 FOREIGN KEY (param_string_id) REFERENCES table_param_string (param_string_id) ON DELETE CASCADE;
ALTER TABLE table_category_attach ADD CONSTRAINT table_category_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_category_attach ADD CONSTRAINT table_category_attach_ibfk_2 FOREIGN KEY (category_id) REFERENCES table_category (category_id) ON DELETE CASCADE;
ALTER TABLE table_category_attach_data ADD CONSTRAINT table_category_attach_data_ibf FOREIGN KEY (attachment_id) REFERENCES table_category_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_category_attach_data ADD CONSTRAINT TABLE_CATEGORY_ATTACH_DATA__85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_category_stat ADD CONSTRAINT table_category_stat_ibfk_1 FOREIGN KEY (category_id) REFERENCES table_category (category_id) ON DELETE CASCADE;
ALTER TABLE table_change ADD CONSTRAINT table_change_ibfk_1 FOREIGN KEY (user_id) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_company_attach ADD CONSTRAINT table_company_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_company_attach ADD CONSTRAINT table_company_attach_ibfk_2 FOREIGN KEY (company_id) REFERENCES table_company (company_id) ON DELETE CASCADE;
ALTER TABLE table_company_attach_data ADD CONSTRAINT table_company_attach_data_ibfk FOREIGN KEY (attachment_id) REFERENCES table_company_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_company_attach_data ADD CONSTRAINT TABLE_COMPANY_ATTACH_DATA_I_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_cust_boolean_value ADD CONSTRAINT table_cust_boolean_value_ibfk_ FOREIGN KEY (cust_boolean_id) REFERENCES table_cust_boolean (cust_boolean_id) ON DELETE CASCADE;
ALTER TABLE table_cust_choice_value ADD CONSTRAINT table_cust_choice_value_ibfk_1 FOREIGN KEY (cust_choice_id) REFERENCES table_cust_choice (cust_choice_id) ON DELETE CASCADE;
ALTER TABLE table_cust_html_value ADD CONSTRAINT table_cust_html_value_ibfk_1 FOREIGN KEY (cust_html_id) REFERENCES table_cust_html (cust_html_id) ON DELETE CASCADE;
ALTER TABLE table_cust_integer_value ADD CONSTRAINT table_cust_integer_value_ibfk_ FOREIGN KEY (cust_integer_id) REFERENCES table_cust_integer (cust_integer_id) ON DELETE CASCADE;
ALTER TABLE table_cust_string_value ADD CONSTRAINT table_cust_string_value_ibfk_1 FOREIGN KEY (cust_string_id) REFERENCES table_cust_string (cust_string_id) ON DELETE CASCADE;
ALTER TABLE table_def_generic ADD CONSTRAINT table_def_generic_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id) ON DELETE CASCADE;
ALTER TABLE table_def_int ADD CONSTRAINT table_def_int_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id) ON DELETE CASCADE;
ALTER TABLE table_def_int ADD CONSTRAINT table_def_int_ibfk_2 FOREIGN KEY (reporter) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_def_int_assigned_to ADD CONSTRAINT table_def_int_assigned_to_ibfk FOREIGN KEY (defect_id) REFERENCES table_def_int (defect_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_assigned_to ADD CONSTRAINT TABLE_DEF_INT_ASSIGNED_TO_I_85 FOREIGN KEY (assigned_to) REFERENCES table_user (user_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_def_int_attach ADD CONSTRAINT table_def_int_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_attach ADD CONSTRAINT table_def_int_attach_ibfk_2 FOREIGN KEY (defect_id) REFERENCES table_def_int (defect_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_attach_data ADD CONSTRAINT table_def_int_attach_data_ibfk FOREIGN KEY (attachment_id) REFERENCES table_def_int_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_attach_data ADD CONSTRAINT TABLE_DEF_INT_ATTACH_DATA_I_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_def_int_ccemails ADD CONSTRAINT table_def_int_ccemails_ibfk_1 FOREIGN KEY (defect_id) REFERENCES table_def_int (defect_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_ccemails ADD CONSTRAINT table_def_int_ccemails_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_data ADD CONSTRAINT table_def_int_data_ibfk_1 FOREIGN KEY (defect_id) REFERENCES table_def_int (defect_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_sut ADD CONSTRAINT table_def_int_sut_ibfk_1 FOREIGN KEY (defect_id) REFERENCES table_def_int (defect_id) ON DELETE CASCADE;
ALTER TABLE table_def_int_sut ADD CONSTRAINT table_def_int_sut_ibfk_2 FOREIGN KEY (sut_id) REFERENCES table_sut (sut_id); -- ON DELETE USELESS
ALTER TABLE table_folder ADD CONSTRAINT table_folder_ibfk_4 FOREIGN KEY (project_id) REFERENCES table_project (project_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_folder ADD CONSTRAINT table_folder_ibfk_1 FOREIGN KEY (folder_id_2) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_folder ADD CONSTRAINT table_folder_ibfk_2 FOREIGN KEY (category_id) REFERENCES table_category (category_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_folder ADD CONSTRAINT table_folder_ibfk_3 FOREIGN KEY (company_id) REFERENCES table_company (company_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_folder_attach ADD CONSTRAINT table_folder_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_folder_attach ADD CONSTRAINT table_folder_attach_ibfk_2 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id) ON DELETE CASCADE;
ALTER TABLE table_folder_attach_data ADD CONSTRAINT table_folder_attach_data_ibfk_ FOREIGN KEY (attachment_id) REFERENCES table_folder_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_folder_attach_data ADD CONSTRAINT TABLE_FOLDER_ATTACH_DATA_IB_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_holiday ADD CONSTRAINT table_holiday_ibfk_1 FOREIGN KEY (country_id) REFERENCES table_country (country_id) ON DELETE CASCADE;
ALTER TABLE table_instance ADD CONSTRAINT table_instance_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_instance ADD CONSTRAINT table_instance_ibfk_2 FOREIGN KEY (agent_id) REFERENCES table_agent (agent_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_monitor ADD CONSTRAINT table_monitor_ibfk_1 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_monitor ADD CONSTRAINT table_monitor_ibfk_2 FOREIGN KEY (monitored_id) REFERENCES table_agent (agent_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_monitored_results ADD CONSTRAINT table_monitored_results_ibfk_1 FOREIGN KEY (monitor_id) REFERENCES table_monitor (monitor_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_project ADD CONSTRAINT table_project_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_project_attach ADD CONSTRAINT table_project_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_project_attach ADD CONSTRAINT table_project_attach_ibfk_2 FOREIGN KEY (project_id) REFERENCES table_project (project_id) ON DELETE CASCADE;
ALTER TABLE table_project_attach_data ADD CONSTRAINT table_project_attach_data_ibfk FOREIGN KEY (attachment_id) REFERENCES table_project_attach (attachment_id) ON DELETE CASCADE;
ALTER TABLE table_project_attach_data ADD CONSTRAINT TABLE_PROJECT_ATTACH_DATA_I_85 FOREIGN KEY (author_id) REFERENCES table_user (user_id); -- ON DELETE USELESS
ALTER TABLE table_project_manager ADD CONSTRAINT table_project_manager_ibfk_1 FOREIGN KEY (project_id) REFERENCES table_project (project_id) ON DELETE CASCADE;
ALTER TABLE table_test_attr_string ADD CONSTRAINT table_test_attr_string_ibfk_2 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_test_camp ADD CONSTRAINT table_test_camp_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test_camp ADD CONSTRAINT table_test_camp_ibfk_2 FOREIGN KEY (campaign_id) REFERENCES table_camp (campaign_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test_data ADD CONSTRAINT table_test_data_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_test_dependencies ADD CONSTRAINT table_test_dependencies_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test_dependencies ADD CONSTRAINT table_test_dependencies_ibfk_2 FOREIGN KEY (dependsFromTest_id) REFERENCES table_test (test_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test_exec ADD CONSTRAINT table_test_exec_ibfk_1 FOREIGN KEY (test_id) REFERENCES table_test (test_id) ON DELETE CASCADE;
ALTER TABLE table_test_exec ADD CONSTRAINT table_test_exec_ibfk_2 FOREIGN KEY (campaign_session_id) REFERENCES table_sess (campaign_session_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_test_exec ADD CONSTRAINT table_test_exec_ibfk_3 FOREIGN KEY (instance_id) REFERENCES table_instance (instance_id) ON DELETE CASCADE;
ALTER TABLE table_test_exec_def ADD CONSTRAINT table_test_exec_def_ibfk_1 FOREIGN KEY (test_exec_id) REFERENCES table_test_exec (test_exec_id) ON DELETE CASCADE;
ALTER TABLE table_test_url ADD CONSTRAINT table_test_url_ibfk_1 FOREIGN KEY (test_data_id) REFERENCES table_test_data (data_id) ON DELETE CASCADE;
ALTER TABLE table_user ADD CONSTRAINT table_user_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_user ADD CONSTRAINT table_user_ibfk_2 FOREIGN KEY (country_id) REFERENCES table_country (country_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_user ADD CONSTRAINT table_user_ibfk_3 FOREIGN KEY (userprofile_id) REFERENCES table_userprofile (userprofile_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_usergroup ADD CONSTRAINT table_usergroup_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_usergroup_category ADD CONSTRAINT table_usergroup_category_ibfk_ FOREIGN KEY (usergroup_id) REFERENCES table_usergroup (usergroup_id) ON DELETE CASCADE;
ALTER TABLE table_usergroup_category ADD CONSTRAINT TABLE_USERGROUP_CATEGORY_IB_85 FOREIGN KEY (category_id) REFERENCES table_category (category_id) ON DELETE CASCADE;
ALTER TABLE table_usergroup_company ADD CONSTRAINT table_usergroup_company_ibfk_1 FOREIGN KEY (usergroup_id) REFERENCES table_usergroup (usergroup_id) ON DELETE CASCADE;
ALTER TABLE table_usergroup_company ADD CONSTRAINT table_usergroup_company_ibfk_2 FOREIGN KEY (company_id) REFERENCES table_company (company_id) ON DELETE CASCADE;
ALTER TABLE table_usergroup_folder ADD CONSTRAINT table_usergroup_folder_ibfk_1 FOREIGN KEY (usergroup_id) REFERENCES table_usergroup (usergroup_id) ON DELETE CASCADE;
ALTER TABLE table_usergroup_folder ADD CONSTRAINT table_usergroup_folder_ibfk_2 FOREIGN KEY (folder_id) REFERENCES table_folder (folder_id); -- TRIGGER REPLACING ON DELETE
ALTER TABLE table_usergroup_user ADD CONSTRAINT table_usergroup_user_ibfk_1 FOREIGN KEY (usergroup_id) REFERENCES table_usergroup (usergroup_id) ON DELETE CASCADE;
ALTER TABLE table_usergroup_user ADD CONSTRAINT table_usergroup_user_ibfk_2 FOREIGN KEY (user_id) REFERENCES table_user (user_id) ON DELETE CASCADE;
ALTER TABLE table_weekend ADD CONSTRAINT table_weekend_ibfk_1 FOREIGN KEY (country_id) REFERENCES table_country (country_id) ON DELETE CASCADE;

-- when running this script manually, don't forget to insert GO in between each of the following statements

CREATE TRIGGER trig_del_user              ON table_user INSTEAD OF DELETE AS
   DELETE FROM table_sch                  WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch.user_id                            = DELETED.user_id)
   DELETE FROM table_sch_ccemails         WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_ccemails.user_id                   = DELETED.user_id)
   DELETE FROM table_sess                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess.user_id                           = DELETED.user_id)
   DELETE FROM table_sess_ccemails        WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_ccemails.user_id                  = DELETED.user_id)
   DELETE FROM table_sprint_task          WHERE EXISTS (SELECT * FROM DELETED WHERE table_sprint_task.assigned_to                = DELETED.user_id)
   DELETE FROM table_test                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_test.author_id                         = DELETED.user_id)
   DELETE FROM table_test                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_test.developer_id                      = DELETED.user_id)
   DELETE FROM table_def_int_assigned_to  WHERE EXISTS (SELECT * FROM DELETED WHERE table_def_int_assigned_to.assigned_to        = DELETED.user_id)
   DELETE FROM table_def_int              WHERE EXISTS (SELECT * FROM DELETED WHERE table_def_int.reporter                       = DELETED.user_id)
   DELETE FROM table_user                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_user.user_id                           = DELETED.user_id);
   
CREATE TRIGGER trig_del_camp              ON table_camp INSTEAD OF DELETE AS
   DELETE FROM table_sch                  WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch.campaign_id                        = DELETED.campaign_id)
   DELETE FROM table_sess                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess.campaign_id                       = DELETED.campaign_id)
   DELETE FROM table_test_camp            WHERE EXISTS (SELECT * FROM DELETED WHERE table_test_camp.campaign_id                  = DELETED.campaign_id)
   DELETE FROM table_camp                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_camp.campaign_id                       = DELETED.campaign_id);
   
CREATE TRIGGER trig_del_sut               ON table_sut INSTEAD OF DELETE AS
   DELETE FROM table_sch                  WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch.sut_id                             = DELETED.sut_id)
   DELETE FROM table_sess                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess.sut_id                            = DELETED.sut_id)
   DELETE FROM table_def_int_sut          WHERE EXISTS (SELECT * FROM DELETED WHERE table_def_int_sut.sut_id                     = DELETED.sut_id)
   DELETE FROM table_sut                  WHERE EXISTS (SELECT * FROM DELETED WHERE table_sut.sut_id                             = DELETED.sut_id);
   
CREATE TRIGGER trig_del_sprint            ON table_sprint INSTEAD OF DELETE AS
   DELETE FROM table_sprint_task          WHERE EXISTS (SELECT * FROM DELETED WHERE table_sprint_task.sprint_id                  = DELETED.sprint_id)
   DELETE FROM table_sprint               WHERE EXISTS (SELECT * FROM DELETED WHERE table_sprint.sprint_id                       = DELETED.sprint_id);
   
CREATE TRIGGER trig_del_test              ON table_test INSTEAD OF DELETE AS
   DELETE FROM table_spec_test            WHERE EXISTS (SELECT * FROM DELETED WHERE table_spec_test.test_id                      = DELETED.test_id)
   DELETE FROM table_sess_attr_boolean    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_attr_boolean.test_id              = DELETED.test_id)
   DELETE FROM table_sess_attr_integer    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_attr_integer.test_id              = DELETED.test_id)
   DELETE FROM table_sess_attr_string     WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_attr_string.test_id               = DELETED.test_id)
   DELETE FROM table_sch_attr_boolean     WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_attr_boolean.test_id               = DELETED.test_id)
   DELETE FROM table_sch_attr_integer     WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_attr_integer.test_id               = DELETED.test_id)
   DELETE FROM table_sch_attr_string      WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_attr_string.test_id                = DELETED.test_id)
   DELETE FROM table_test_camp            WHERE EXISTS (SELECT * FROM DELETED WHERE table_test_camp.test_id                      = DELETED.test_id)
   DELETE FROM table_test_dependencies    WHERE EXISTS (SELECT * FROM DELETED WHERE table_test_dependencies.test_id              = DELETED.test_id)
   DELETE FROM table_test_dependencies    WHERE EXISTS (SELECT * FROM DELETED WHERE table_test_dependencies.dependsFromTest_id   = DELETED.test_id)
   DELETE FROM table_test                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_test.test_id                           = DELETED.test_id);
   
CREATE TRIGGER trig_del_spec              ON table_spec INSTEAD OF DELETE AS
   DELETE FROM table_spec_test            WHERE EXISTS (SELECT * FROM DELETED WHERE table_spec_test.specification_id             = DELETED.specification_id)
   DELETE FROM table_req_spec             WHERE EXISTS (SELECT * FROM DELETED WHERE table_req_spec.specification_id              = DELETED.specification_id)
   DELETE FROM table_spec_attach          WHERE EXISTS (SELECT * FROM DELETED WHERE table_spec_attach.specification_id           = DELETED.specification_id)
   DELETE FROM table_spec_data            WHERE EXISTS (SELECT * FROM DELETED WHERE table_spec_data.specification_id             = DELETED.specification_id)
   DELETE FROM table_spec                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_spec.specification_id                  = DELETED.specification_id);
   
CREATE TRIGGER trig_del_agent             ON table_agent INSTEAD OF DELETE AS
   DELETE FROM table_sch_agent            WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_agent.agent_id                     = DELETED.agent_id)
   DELETE FROM table_sess_agent_status    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_agent_status.agent_id             = DELETED.agent_id)
   DELETE FROM table_instance             WHERE EXISTS (SELECT * FROM DELETED WHERE table_instance.agent_id                      = DELETED.agent_id)
   DELETE FROM table_monitor              WHERE EXISTS (SELECT * FROM DELETED WHERE table_monitor.monitored_id                   = DELETED.agent_id)
   DELETE FROM table_agent                WHERE EXISTS (SELECT * FROM DELETED WHERE table_agent.agent_id                         = DELETED.agent_id);

CREATE TRIGGER trig_del_sch               ON table_sch INSTEAD OF DELETE AS
   DELETE FROM table_sess                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess.schedule_id                       = DELETED.schedule_id)
   DELETE FROM table_sch_attr_boolean     WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_attr_boolean.schedule_id           = DELETED.schedule_id)
   DELETE FROM table_sch_attr_integer     WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_attr_integer.schedule_id           = DELETED.schedule_id)
   DELETE FROM table_sch_attr_string      WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch_attr_string.schedule_id            = DELETED.schedule_id)
   DELETE FROM table_sch                  WHERE EXISTS (SELECT * FROM DELETED WHERE table_sch.schedule_id                        = DELETED.schedule_id);

CREATE TRIGGER trig_del_sess              ON table_sess INSTEAD OF DELETE AS
   DELETE FROM table_sess_agent_status    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_agent_status.campaign_session_id  = DELETED.campaign_session_id)
   DELETE FROM table_sess_attr_boolean    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_attr_boolean.campaign_session_id  = DELETED.campaign_session_id)
   DELETE FROM table_sess_attr_integer    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_attr_integer.campaign_session_id  = DELETED.campaign_session_id)
   DELETE FROM table_sess_attr_string     WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_attr_string.campaign_session_id   = DELETED.campaign_session_id)
   DELETE FROM table_sess_param_boolean   WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_param_boolean.campaign_session_id = DELETED.campaign_session_id)
   DELETE FROM table_sess_param_integer   WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_param_integer.campaign_session_id = DELETED.campaign_session_id)
   DELETE FROM table_sess_param_string    WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_param_string.campaign_session_id  = DELETED.campaign_session_id)
   DELETE FROM table_sess_ccemails        WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess_ccemails.campaign_session_id      = DELETED.campaign_session_id)
   DELETE FROM table_case_exec            WHERE EXISTS (SELECT * FROM DELETED WHERE table_case_exec.campaign_session_id          = DELETED.campaign_session_id)
   DELETE FROM table_instance             WHERE EXISTS (SELECT * FROM DELETED WHERE table_instance.campaign_session_id           = DELETED.campaign_session_id)
   DELETE FROM table_test_exec            WHERE EXISTS (SELECT * FROM DELETED WHERE table_test_exec.campaign_session_id          = DELETED.campaign_session_id)
   DELETE FROM table_monitor              WHERE EXISTS (SELECT * FROM DELETED WHERE table_monitor.campaign_session_id            = DELETED.campaign_session_id)
   DELETE FROM table_sess                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess.campaign_session_id               = DELETED.campaign_session_id);

CREATE TRIGGER trig_del_monitor           ON table_monitor INSTEAD OF DELETE AS
   DELETE FROM table_monitored_results    WHERE EXISTS (SELECT * FROM DELETED WHERE table_monitored_results.monitor_id           = DELETED.monitor_id)
   DELETE FROM table_monitor              WHERE EXISTS (SELECT * FROM DELETED WHERE table_monitor.monitor_id                     = DELETED.monitor_id);

CREATE TRIGGER trig_del_monitoring_conf   ON table_monitoring_conf INSTEAD OF DELETE AS
   DELETE FROM table_sess                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_sess.monitoring_conf_id                = DELETED.monitoring_conf_id)
   DELETE FROM table_monitoring_conf      WHERE EXISTS (SELECT * FROM DELETED WHERE table_monitoring_conf.monitoring_conf_id     = DELETED.monitoring_conf_id);

CREATE TRIGGER trig_del_category          ON table_category INSTEAD OF DELETE AS
   DELETE FROM table_folder               WHERE EXISTS (SELECT * FROM DELETED WHERE table_folder.category_id                     = DELETED.category_id)
   DELETE FROM table_category             WHERE EXISTS (SELECT * FROM DELETED WHERE table_category.category_id                   = DELETED.category_id);

CREATE TRIGGER trig_del_company           ON table_company INSTEAD OF DELETE AS
   DELETE FROM table_folder               WHERE EXISTS (SELECT * FROM DELETED WHERE table_folder.company_id                      = DELETED.company_id)
   DELETE FROM table_company              WHERE EXISTS (SELECT * FROM DELETED WHERE table_company.company_id                     = DELETED.company_id);

CREATE TRIGGER trig_del_project           ON table_project INSTEAD OF DELETE AS
   DELETE FROM table_folder               WHERE EXISTS (SELECT * FROM DELETED WHERE table_folder.project_id                      = DELETED.project_id)
   DELETE FROM table_sprint               WHERE EXISTS (SELECT * FROM DELETED WHERE table_sprint.project_id                      = DELETED.project_id)
   DELETE FROM table_project              WHERE EXISTS (SELECT * FROM DELETED WHERE table_project.project_id                     = DELETED.project_id);

CREATE TRIGGER trig_del_country           ON table_country INSTEAD OF DELETE AS
   DELETE FROM table_user                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_user.country_id                        = DELETED.country_id)  -- set US instead!
   DELETE FROM table_country              WHERE EXISTS (SELECT * FROM DELETED WHERE table_country.country_id                     = DELETED.country_id); 

CREATE TRIGGER trig_del_userprofile       ON table_userprofile INSTEAD OF DELETE AS
   DELETE FROM table_user                 WHERE EXISTS (SELECT * FROM DELETED WHERE table_user.userprofile_id                    = DELETED.userprofile_id) -- set 50 instead! and protect the userprofile 50 against deletion
   DELETE FROM table_userprofile          WHERE EXISTS (SELECT * FROM DELETED WHERE table_userprofile.userprofile_id             = DELETED.userprofile_id);

