CREATE TABLE table_company (
  company_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_name TEXT NULL,
  PRIMARY KEY(company_id)
)
TYPE=InnoDB;

CREATE TABLE table_check (
  check_id INTEGER UNSIGNED NOT NULL,
  check_description TEXT NULL,
  PRIMARY KEY(check_id)
)
TYPE=InnoDB;

CREATE TABLE table_filter (
  filter_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  filter_description TEXT NULL,
  filter_content LONGTEXT NULL,
  PRIMARY KEY(filter_id)
)
TYPE=InnoDB;

CREATE TABLE table_version (
  version_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  version_number INTEGER UNSIGNED NULL,
  PRIMARY KEY(version_id)
)
TYPE=InnoDB;

CREATE TABLE table_step (
  step_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  step_description TEXT NULL,
  PRIMARY KEY(step_id)
)
TYPE=InnoDB;

CREATE TABLE table_category (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_name Varchar(20) NOT NULL,
  category_envDesc TEXT NOT NULL,
  category_jarName TEXT NULL,
  PRIMARY KEY(category_id)
)
TYPE=InnoDB;

CREATE TABLE table_attr_string (
  attr_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_string_name Varchar(45) NOT NULL,
  attr_string_mandatory BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_string_id)
)
TYPE=InnoDB;

CREATE TABLE table_attr_integer (
  attr_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_integer_name Varchar(45) NOT NULL,
  attr_integer_mandatory BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_integer_id)
)
TYPE=InnoDB;

CREATE TABLE table_attr_boolean (
  attr_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_boolean_name Varchar(45) NOT NULL,
  attr_boolean_mandatory BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_boolean_id)
)
TYPE=InnoDB;

CREATE TABLE table_folder (
  folder_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id_2 INTEGER UNSIGNED NULL,
  folder_name TEXT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  company_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(folder_id),
  INDEX folder_FKIndex1(folder_id_2),
  INDEX folder_FKIndex2(category_id),
  INDEX folder_FKIndex3(company_id),
  FOREIGN KEY(folder_id_2)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_sut (
  sut_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_name TEXT NULL,
  sut_version TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sut_id),
  INDEX sut_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_user (
  user_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_name TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  user_password TEXT NULL,
  PRIMARY KEY(user_id),
  INDEX user_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_defect (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  defect_name TEXT NULL,
  defect_url TEXT NULL,
  defect_ref TEXT NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_requirement (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  requirement_type TEXT NULL,
  requirement_name TEXT NOT NULL,
  requirement_description TEXT NULL,
  PRIMARY KEY(requirement_id),
  INDEX table_requirement_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  campaign_name TEXT NULL,
  PRIMARY KEY(campaign_id),
  INDEX campaign_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_specification (
  specification_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  specification_isFormal BOOL NULL,
  specification_name TEXT NULL,
  specification_description TEXT NULL,
  PRIMARY KEY(specification_id),
  INDEX spec_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_test (
  test_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  test_name Varchar(45) NOT NULL,
  test_description LONGBLOB NOT NULL,
  test_priority INTEGER UNSIGNED NOT NULL DEFAULT 99,
  test_canonicalPath TEXT NOT NULL,
  test_prerequisites TEXT NOT NULL,
  PRIMARY KEY(test_id),
  INDEX test_FKIndex1(folder_id),
  INDEX table_test_FKIndex2(user_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_requirement_specification (
  requirement_id INTEGER UNSIGNED NOT NULL,
  specification_id INTEGER UNSIGNED NOT NULL,
  INDEX requirement_spec_FKIndex1(requirement_id),
  INDEX requirement_specification_FKIndex2(specification_id),
  FOREIGN KEY(requirement_id)
    REFERENCES table_requirement(requirement_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_campaign_session (
  campaign_session_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  campaign_id INTEGER UNSIGNED NOT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  campaign_session_name TEXT NULL,
  campaign_session_startDate DATETIME NULL,
  campaign_session_stopDate DATETIME NULL,
  campaign_session_engaged BOOL NOT NULL DEFAULT 1,
  PRIMARY KEY(campaign_session_id),
  INDEX campaign_session_FKIndex1(sut_id),
  INDEX campaign_session_FKIndex2(campaign_id),
  INDEX campaign_session_FKIndex3(user_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase (
  testcase_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  testcase_index INTEGER UNSIGNED NOT NULL,
  testcase_name TEXT NULL,
  testcase_implemented BOOL NOT NULL DEFAULT 0,
  testcase_lastExecutionId INTEGER UNSIGNED NULL,
  PRIMARY KEY(testcase_id),
  INDEX testcase_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_test_dependencies (
  test_id INTEGER UNSIGNED NOT NULL,
  dependsFromTest_id INTEGER UNSIGNED NOT NULL,
  INDEX test_dependencies_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase_step (
  testcase_step_id INTEGER UNSIGNED NOT NULL,
  step_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  testcase_step_index INTEGER UNSIGNED NULL,
  testcase_step_parameters TEXT NULL,
  PRIMARY KEY(testcase_step_id),
  INDEX testcase_step_FKIndex1(testcase_id),
  INDEX testcase_step_FKIndex2(step_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(step_id)
    REFERENCES table_step(step_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_test_attr_boolean (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  test_attr_boolean_value BOOL NOT NULL,
  INDEX test_attr_boolean_FKIndex1(attr_boolean_id),
  INDEX test_attr_boolean_FKIndex2(test_id),
  FOREIGN KEY(attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_test_attr_string (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  test_attr_string_value TEXT NOT NULL,
  INDEX test_attr_string_FKIndex1(attr_string_id),
  INDEX test_attr_string_FKIndex2(test_id),
  FOREIGN KEY(attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_test_attr_integer (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  test_attr_integer_value INTEGER UNSIGNED NOT NULL,
  INDEX test_attr_integer_FKIndex2(test_id),
  INDEX test_attr_integer_FKIndex1(attr_integer_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_spec_testcase (
  specification_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  INDEX spec_testcase_FKIndex2(testcase_id),
  INDEX table_spec_testcase_FKIndex2(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  INDEX testcase_campaign_FKIndex1(testcase_id),
  INDEX table_testcase_campaign_FKIndex2(campaign_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase_execution (
  testcase_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  testcase_execution_result INTEGER UNSIGNED NOT NULL,
  testcase_execution_message TEXT NULL,
  testcase_execution_trace LONGBLOB NULL,
  PRIMARY KEY(testcase_execution_id),
  INDEX testcase_execution_FKIndex1(testcase_id),
  INDEX testcase_execution_FKIndex2(campaign_session_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase_execution_step (
  testcase_execution_id INTEGER UNSIGNED NOT NULL,
  testcase_execution_step_index INTEGER UNSIGNED NOT NULL,
  testcase_execution_step_date DATETIME NULL,
  testcase_execution_step_actionDesc TEXT NULL,
  testcase_execution_step_status INTEGER UNSIGNED NULL,
  INDEX testcase_execution_step_FKIndex1(testcase_execution_id),
  FOREIGN KEY(testcase_execution_id)
    REFERENCES table_testcase_execution(testcase_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase_step_check (
  testcase_step_id INTEGER UNSIGNED NOT NULL,
  check_id INTEGER UNSIGNED NOT NULL,
  INDEX testcase_step_check_FKIndex1(testcase_step_id),
  INDEX testcase_step_check_FKIndex2(check_id),
  FOREIGN KEY(testcase_step_id)
    REFERENCES table_testcase_step(testcase_step_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(check_id)
    REFERENCES table_check(check_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;

CREATE TABLE table_testcase_execution_defect (
  defect_id INTEGER UNSIGNED NOT NULL,
  testcase_execution_id INTEGER UNSIGNED NOT NULL,
  INDEX testcase_execution_defect_FKIndex1(testcase_execution_id),
  INDEX table_testcase_execution_defect_FKIndex2(defect_id),
  FOREIGN KEY(testcase_execution_id)
    REFERENCES table_testcase_execution(testcase_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(defect_id)
    REFERENCES table_defect(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
TYPE=InnoDB;


