CREATE TABLE table_company (
  company_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_name VARCHAR(128) NOT NULL,
  PRIMARY KEY(company_id)
)
ENGINE=InnoDB;

INSERT INTO table_company VALUES (1, 'na');
INSERT INTO table_company VALUES (10, 'XQual');

CREATE TABLE table_filter (
  filter_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  filter_description TEXT NULL,
  filter_content LONGTEXT NULL,
  PRIMARY KEY(filter_id)
)
ENGINE=InnoDB;

CREATE TABLE table_version (
  version_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  version_number INTEGER UNSIGNED NULL,
  PRIMARY KEY(version_id)
)
ENGINE=InnoDB;

CREATE TABLE table_category (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_name VARCHAR(128) NOT NULL,
  category_envDesc TEXT NOT NULL,
  category_jarName VARCHAR(64) NULL,
  PRIMARY KEY(category_id)
)
ENGINE=InnoDB;

INSERT INTO table_category VALUES (1, 'na', 'na', 'na');

CREATE TABLE table_category_stat (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date DATETIME NULL,
  nb_tests INTEGER UNSIGNED NULL,
  nb_tests_implemented INTEGER UNSIGNED NULL,
  nb_testcases INTEGER UNSIGNED NULL,
  nb_testcases_implemented INTEGER UNSIGNED NULL,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_attr_string (
  attr_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_string_name VARCHAR(60) NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_string_id)
)
ENGINE=InnoDB;

CREATE TABLE table_attr_integer (
  attr_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_integer_name VARCHAR(60) NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_integer_id)
)
ENGINE=InnoDB;

CREATE TABLE table_attr_boolean (
  attr_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_boolean_name VARCHAR(60) NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_boolean_id)
)
ENGINE=InnoDB;

CREATE TABLE table_folder (
  folder_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id_2 INTEGER UNSIGNED NULL,
  folder_name VARCHAR(128) NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  company_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(folder_id),
  INDEX folder_FKIndex1(folder_id_2),
  INDEX folder_FKIndex2(category_id),
  INDEX folder_FKIndex3(company_id),
  FOREIGN KEY(folder_id_2)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

INSERT INTO table_folder VALUES (1,   1, 'na', 1, 1); #user
INSERT INTO table_folder VALUES (2,   2, 'na', 1, 1); #sut
INSERT INTO table_folder VALUES (3,   3, 'na', 1, 1); #req
INSERT INTO table_folder VALUES (4,   4, 'na', 1, 1); #spec
INSERT INTO table_folder VALUES (5,   5, 'na', 1, 1); #test
INSERT INTO table_folder VALUES (6,   6, 'na', 1, 1); #campaign
INSERT INTO table_folder VALUES (7,   7, 'na', 1, 1); #defect
INSERT INTO table_folder VALUES (8,   8, 'na', 1, 1); #agent
INSERT INTO table_folder VALUES (9,   9, 'na', 1, 1); #project
INSERT INTO table_folder VALUES (10, 10, 'na', 1, 1); #task

INSERT INTO table_folder VALUES (29, 1, 'Administration', 1, 10);
INSERT INTO table_folder VALUES (30, 6, 'Manual',         1, 10);

CREATE TABLE table_project (
  project_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  project_name VARCHAR(128) NOT NULL,
  project_description TEXT NULL,
  focus_ratio TINYINT UNSIGNED NOT NULL DEFAULT 80,
  PRIMARY KEY(project_id),
  INDEX project_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

INSERT INTO table_project VALUES (1, 1, 'na', 'na', 80);

ALTER TABLE table_folder ADD project_id INTEGER UNSIGNED NOT NULL DEFAULT 1;
ALTER TABLE table_folder ADD INDEX folder_FKIndex4(project_id);
ALTER TABLE table_folder ADD FOREIGN KEY(project_id) REFERENCES table_project(project_id) ON DELETE CASCADE ON UPDATE NO ACTION;

CREATE TABLE table_sut (
  sut_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_name VARCHAR(128) NOT NULL,
  sut_version VARCHAR(64) NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sut_id),
  INDEX sut_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_agent (
  agent_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  agent_name VARCHAR(128) NOT NULL,
  agent_os VARCHAR(64) NOT NULL,
  agent_description TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(agent_id),
  INDEX agent_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_user (
  user_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_name VARCHAR(128) NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  user_password TEXT NULL,
  user_local VARCHAR(5) DEFAULT 'en_US' NOT NULL,
  user_rights TEXT NULL,
  user_email VARCHAR(50) DEFAULT '' NOT NULL,
  user_enabled BOOL NOT NULL DEFAULT 1,
  PRIMARY KEY(user_id),
  INDEX user_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_generic (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  external_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  defect_name VARCHAR(128) NOT NULL,
  defect_description TEXT NULL,
  priority TINYINT NOT NULL,
  severity TINYINT NOT NULL,
  reporter INTEGER UNSIGNED NOT NULL,
  assigned_to INTEGER UNSIGNED NOT NULL,
  status TINYINT NOT NULL,
  step_to_reproduce TEXT NOT NULL,
  reproducibility TINYINT DEFAULT 1,
  platform_id INTEGER UNSIGNED NOT NULL DEFAULT 999,
  os_id INTEGER UNSIGNED NOT NULL DEFAULT 999,
  fix_target_date DATETIME NULL,
  fix_target_version VARCHAR(32) NULL,
  completion_percentage TINYINT NOT NULL DEFAULT 0,
  fix_type TINYINT NULL,
  fix_description TEXT NULL,
  fix_patches VARCHAR(64) NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  INDEX defect_FKIndex2(reporter),
  INDEX defect_FKIndex3(assigned_to),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(reporter)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(assigned_to)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  requirement_name VARCHAR(128) NOT NULL,
  requirement_description TEXT NULL,
  type SMALLINT NOT NULL DEFAULT 10,
  priority TINYINT NOT NULL DEFAULT 20,
  status TINYINT NOT NULL DEFAULT 30,
  PRIMARY KEY(requirement_id),
  INDEX table_requirement_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  campaign_name VARCHAR(128) NOT NULL,
  PRIMARY KEY(campaign_id),
  INDEX campaign_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification (
  specification_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  specification_isFormal BOOL NOT NULL DEFAULT 0,
  specification_name VARCHAR(128) NOT NULL,
  specification_description TEXT NULL,
  priority TINYINT NOT NULL DEFAULT 20,
  status TINYINT NOT NULL DEFAULT 30,
  PRIMARY KEY(specification_id),
  INDEX spec_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test (
  test_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  test_name VARCHAR(128) NOT NULL,
  test_description LONGBLOB NOT NULL,
  test_priority INTEGER UNSIGNED NOT NULL DEFAULT 99,
  test_canonicalPath VARCHAR(255) NOT NULL,
  test_prerequisites TEXT NOT NULL,
  test_estimatedTime BIGINT UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(test_id),
  INDEX table_test_FKIndex1(folder_id),
  INDEX table_test_FKIndex2(user_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_specification (
  requirement_id INTEGER UNSIGNED NOT NULL,
  specification_id INTEGER UNSIGNED NOT NULL,
  INDEX requirement_spec_FKIndex1(requirement_id),
  INDEX requirement_specification_FKIndex2(specification_id),
  FOREIGN KEY(requirement_id)
    REFERENCES table_requirement(requirement_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule (
  schedule_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  schedule_name VARCHAR(128) NOT NULL,
  schedule_description TEXT NULL,
  schedule_nextStartDate DATETIME NULL,
  campaign_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  schedule_enabled BOOL NOT NULL DEFAULT 1,
  schedule_every TEXT NOT NULL,
  schedule_at TEXT NULL,
  agent_id INTEGER UNSIGNED NOT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  schedule_conf TEXT NULL,
  PRIMARY KEY(schedule_id),
  INDEX table_schedule_FKIndex1(campaign_id),
  INDEX table_schedule_FKIndex2(user_id),
  INDEX table_schedule_FKIndex3(agent_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(agent_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session (
  campaign_session_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  campaign_id INTEGER UNSIGNED,
  sut_id INTEGER UNSIGNED NOT NULL,
  campaign_session_name VARCHAR(128) NOT NULL,
  campaign_session_startDate DATETIME NULL,
  campaign_session_stopDate DATETIME NULL,
  campaign_session_status INTEGER UNSIGNED NOT NULL DEFAULT 1,
  campaign_session_conf TEXT NULL,
  schedule_id INTEGER UNSIGNED,
  agent_id INTEGER UNSIGNED,
  introduction TEXT NULL,
  conclusion TEXT NULL,
  PRIMARY KEY(campaign_session_id),
  INDEX campaign_session_FKIndex1(sut_id),
  INDEX campaign_session_FKIndex2(campaign_id),
  INDEX campaign_session_FKIndex3(user_id),
  INDEX campaign_session_FKIndex4(schedule_id),
  INDEX campaign_session_FKIndex5(agent_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(agent_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;


CREATE TABLE table_testcase (
  testcase_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  testcase_index INTEGER UNSIGNED NOT NULL,
  testcase_name VARCHAR(128) NOT NULL,
  testcase_implemented BOOL NOT NULL DEFAULT 0,
  testcase_steps TEXT NULL,
  testcase_description TEXT NULL,
  testcase_useDescAsTestplan BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(testcase_id),
  INDEX testcase_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_dependencies (
  test_id INTEGER UNSIGNED NOT NULL,
  dependsFromTest_id INTEGER UNSIGNED NOT NULL,
  INDEX test_dependencies_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_boolean (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  test_attr_boolean_value BOOL NOT NULL DEFAULT 0,
  INDEX test_attr_boolean_FKIndex1(attr_boolean_id),
  INDEX test_attr_boolean_FKIndex2(test_id),
  FOREIGN KEY(attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_string (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  test_attr_string_value TEXT NOT NULL,
  INDEX test_attr_string_FKIndex1(attr_string_id),
  INDEX test_attr_string_FKIndex2(test_id),
  FOREIGN KEY(attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_integer (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  test_attr_integer_value TEXT NOT NULL,
  INDEX test_attr_integer_FKIndex2(test_id),
  INDEX test_attr_integer_FKIndex1(attr_integer_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification_test (
  specification_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX specification_test_FKIndex1(test_id),
  INDEX specification_test_FKIndex2(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  position INTEGER UNSIGNED NOT NULL DEFAULT 0,
  INDEX testcase_campaign_FKIndex2(campaign_id),
  INDEX testcase_campaign_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution (
  testcase_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  testcase_execution_result INTEGER UNSIGNED NOT NULL,
  testcase_execution_message MEDIUMTEXT NULL,
  testcase_execution_trace LONGBLOB NULL,
  PRIMARY KEY(testcase_execution_id),
  INDEX testcase_execution_FKIndex1(testcase_id),
  INDEX testcase_execution_FKIndex2(campaign_session_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution (
  test_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  test_execution_result INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(test_execution_id),
  INDEX test_execution_FKIndex1(test_id),
  INDEX test_execution_FKIndex2(campaign_session_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution_defect (
  defect_id INTEGER UNSIGNED NOT NULL,
  test_execution_id INTEGER UNSIGNED NOT NULL,
  INDEX test_execution_defect_FKIndex1(test_execution_id),
  FOREIGN KEY(test_execution_id)
    REFERENCES table_test_execution(test_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_ccemails (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(campaign_session_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule_ccemails (
  schedule_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(schedule_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX testcase_attachment_FKIndex1(testcase_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_folder_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_category_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(category_id),
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_execution_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(testcase_execution_id),
  FOREIGN KEY(testcase_execution_id)
    REFERENCES table_testcase_execution(testcase_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  defect_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(defect_id),
  FOREIGN KEY(defect_id)
    REFERENCES table_defect_integrated(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_change (
  type TINYINT NOT NULL,
  id INTEGER UNSIGNED NOT NULL,
  date DATETIME NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  action TINYINT NOT NULL,
  information VARCHAR(255) NOT NULL,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_stat (
  entry_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  database_type TINYINT NOT NULL,
  container_type TINYINT NOT NULL,
  type TINYINT NOT NULL,
  container VARCHAR(255) NULL,
  date DATETIME NULL,
  stat MEDIUMTEXT NOT NULL,
  PRIMARY KEY(entry_id)
)
ENGINE=InnoDB;

CREATE TABLE table_platform (
  platform_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  platform_name VARCHAR(32) NOT NULL,
  PRIMARY KEY(platform_id)
)
ENGINE=InnoDB;

CREATE TABLE table_os (
  os_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  os_name VARCHAR(32) NOT NULL,
  PRIMARY KEY(os_id)
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated_sut (
  type TINYINT NOT NULL,
  defect_id INTEGER UNSIGNED NOT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  INDEX defect_FKIndex1(defect_id),
  INDEX sut_FKIndex2(sut_id),
  FOREIGN KEY(defect_id)
    REFERENCES table_defect_integrated(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX campaign_session_attachment_FKIndex1(campaign_session_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_configuration (
  configuration_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  jar_name VARCHAR(64) NOT NULL,
  configuration_name VARCHAR(64) NOT NULL,
  configuration_content TEXT NULL,
  INDEX configuration_id_FKIndex1(configuration_id)
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_configuration (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  configuration_id INTEGER UNSIGNED NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX configuration_FKIndex2(configuration_id),
  INDEX category_FKIndex3(category_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(configuration_id)
    REFERENCES table_configuration(configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule_configuration (
  schedule_id INTEGER UNSIGNED NOT NULL,
  configuration_id INTEGER UNSIGNED NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  INDEX schedule_FKIndex1(schedule_id),
  INDEX configuration_FKIndex2(configuration_id),
  INDEX category_FKIndex3(category_id),
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(configuration_id)
    REFERENCES table_configuration(configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_task (
  task_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  task_name VARCHAR(128) NOT NULL,
  task_description TEXT NULL,
  priority TINYINT NOT NULL,
  estimated DECIMAL(3,1) NOT NULL DEFAULT 1.0,
  PRIMARY KEY(task_id),
  INDEX task_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;



CREATE TABLE table_sprint (
  sprint_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sprint_name VARCHAR(128) NOT NULL,
  sprint_description TEXT NULL,
  status TINYINT NOT NULL,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  project_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sprint_id),
  INDEX table_sprint_FKIndex1(project_id),
  FOREIGN KEY(project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_task (
  sprint_id INTEGER UNSIGNED NOT NULL,
  task_id INTEGER UNSIGNED NOT NULL,
  progress TINYINT UNSIGNED NOT NULL DEFAULT 0,
  INDEX sprint_task_FKIndex1(sprint_id),
  INDEX sprint_task_FKIndex2(task_id),
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(task_id)
    REFERENCES table_task(task_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_developer (
  sprint_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  availability TINYINT UNSIGNED NOT NULL DEFAULT 0,
  INDEX sprint_user_FKIndex1(sprint_id),
  INDEX sprint_user_FKIndex2(user_id),
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_stat (
  sprint_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date DATETIME NULL,
  stat MEDIUMTEXT NOT NULL,
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attribute_string (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  value TEXT NOT NULL,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX test_FKIndex2(test_id),
  INDEX attribute_string_FKIndex3(attr_string_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attribute_boolean (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOL NOT NULL DEFAULT 0,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX test_FKIndex2(test_id),
  INDEX attribute_boolean_FKIndex3(attr_boolean_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attribute_integer (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  value TEXT NOT NULL,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX test_FKIndex2(test_id),
  INDEX attribute_integer_FKIndex3(attr_integer_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;
