CREATE TABLE table_company (
  company_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(company_id)
)
ENGINE=InnoDB;

INSERT INTO table_company VALUES (1, 'na');
INSERT INTO table_company VALUES (10, 'XQual');

CREATE TABLE table_filter (
  filter_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  filter_description TEXT CHARACTER SET utf8 NULL,
  filter_content LONGTEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(filter_id)
)
ENGINE=InnoDB;

CREATE TABLE table_version (
  version_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  version_number INTEGER UNSIGNED NULL,
  PRIMARY KEY(version_id)
)
ENGINE=InnoDB;

CREATE TABLE table_category (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  category_envDesc TEXT CHARACTER SET utf8 NOT NULL,
  category_jarName VARCHAR(64) CHARACTER SET utf8 NULL,
  PRIMARY KEY(category_id)
)
ENGINE=InnoDB;

INSERT INTO table_category VALUES (1, 'na', 'na', 'na');

CREATE TABLE table_category_stat (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date DATETIME NULL,
  nb_tests INTEGER UNSIGNED NULL,
  nb_tests_implemented INTEGER UNSIGNED NULL,
  nb_testcases INTEGER UNSIGNED NULL,
  nb_testcases_implemented INTEGER UNSIGNED NULL,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_attr_string (
  attr_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_string_name VARCHAR(60) CHARACTER SET utf8 NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_string_id),
  UNIQUE KEY (attr_string_name)
)
ENGINE=InnoDB;

CREATE TABLE table_attr_integer (
  attr_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_integer_name VARCHAR(60) CHARACTER SET utf8 NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_integer_id),
  UNIQUE KEY (attr_integer_name)
)
ENGINE=InnoDB;

CREATE TABLE table_attr_boolean (
  attr_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_boolean_name VARCHAR(60) CHARACTER SET utf8 NOT NULL,
  dynamic BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_boolean_id),
  UNIQUE KEY (attr_boolean_name)
)
ENGINE=InnoDB;

CREATE TABLE table_folder (
  folder_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id_2 INTEGER UNSIGNED NULL,
  folder_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  company_id INTEGER UNSIGNED NOT NULL,
  folder_description TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(folder_id),
  INDEX folder_FKIndex1(folder_id_2),
  INDEX folder_FKIndex2(category_id),
  INDEX folder_FKIndex3(company_id),
  FOREIGN KEY(folder_id_2)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

INSERT INTO table_folder VALUES (1,   1, 'na', 1, 1, NULL); #user
INSERT INTO table_folder VALUES (2,   2, 'na', 1, 1, NULL); #sut
INSERT INTO table_folder VALUES (3,   3, 'na', 1, 1, NULL); #req
INSERT INTO table_folder VALUES (4,   4, 'na', 1, 1, NULL); #spec
INSERT INTO table_folder VALUES (5,   5, 'na', 1, 1, NULL); #test
INSERT INTO table_folder VALUES (6,   6, 'na', 1, 1, NULL); #campaign
INSERT INTO table_folder VALUES (7,   7, 'na', 1, 1, NULL); #defect
INSERT INTO table_folder VALUES (8,   8, 'na', 1, 1, NULL); #agent
INSERT INTO table_folder VALUES (9,   9, 'na', 1, 1, NULL); #project
INSERT INTO table_folder VALUES (10, 10, 'na', 1, 1, NULL); #task
INSERT INTO table_folder VALUES (11, 11, 'na', 1, 1, NULL); #documents

INSERT INTO table_folder VALUES (29, 1, 'Administration', 1, 10, NULL);
INSERT INTO table_folder VALUES (30, 6, 'Manual',         1, 10, NULL);

CREATE TABLE table_project (
  project_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  project_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  project_description TEXT CHARACTER SET utf8 NULL,
  focus_ratio TINYINT UNSIGNED NOT NULL DEFAULT 80,
  PRIMARY KEY(project_id),
  INDEX project_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

INSERT INTO table_project VALUES (1, 1, 'na', 'na', 80);

ALTER TABLE table_folder ADD project_id INTEGER UNSIGNED NOT NULL DEFAULT 1 AFTER company_id;
ALTER TABLE table_folder ADD INDEX folder_FKIndex4(project_id);
ALTER TABLE table_folder ADD FOREIGN KEY(project_id) 
    REFERENCES table_project(project_id)
      ON DELETE CASCADE 
      ON UPDATE NO ACTION;

CREATE TABLE table_sut (
  sut_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sut_id),
  INDEX sut_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sut_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_id INTEGER UNSIGNED NOT NULL,
  sut_version VARCHAR(64) CHARACTER SET utf8 NULL,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  UNIQUE KEY(sut_id, revision),
  INDEX sut_content_FKIndex1(sut_id),
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
) ENGINE=InnoDB;
											       
													       
CREATE TABLE table_agent (
  agent_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  agent_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  agent_os VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  agent_description TEXT CHARACTER SET utf8 NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(agent_id),
  INDEX agent_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_country (
  country_id CHAR(2) NOT NULL,
  country_name VARCHAR(80) NOT NULL,
  PRIMARY KEY(country_id)
)
ENGINE=InnoDB DEFAULT CHARSET=latin1;

INSERT INTO table_country VALUES ('US','United States');

CREATE TABLE table_user (
  user_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_name VARCHAR(128) NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  user_password TEXT NULL,
  user_local VARCHAR(5) DEFAULT 'en_US' NOT NULL,
  user_rights TEXT NULL,
  user_email VARCHAR(50) DEFAULT '' NOT NULL,
  user_enabled BOOL NOT NULL DEFAULT 1,
  country_id CHAR(2) CHARACTER SET latin1 NOT NULL DEFAULT 'US',
  PRIMARY KEY(user_id),
  INDEX user_FKIndex1(folder_id),
  INDEX user_FKIndex2(country_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(country_id)
    REFERENCES table_country(country_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=InnoDB;

CREATE TABLE table_defect_generic (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  external_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  defect_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  reporter INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  INDEX defect_FKIndex2(reporter),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(reporter)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  defect_id INTEGER UNSIGNED NOT NULL,
  defect_description TEXT CHARACTER SET utf8 NULL,
  priority TINYINT NOT NULL,
  severity TINYINT NOT NULL,
  status TINYINT NOT NULL,
  step_to_reproduce TEXT CHARACTER SET utf8 NOT NULL,
  reproducibility TINYINT DEFAULT 1,
  platform_id INTEGER UNSIGNED NOT NULL DEFAULT 999,
  os_id INTEGER UNSIGNED NOT NULL DEFAULT 999,
  fix_target_date DATETIME NULL,
  fix_target_version VARCHAR(32) CHARACTER SET utf8 NULL,
  completion_percentage TINYINT NOT NULL DEFAULT 0,
  fix_type TINYINT NULL,
  fix_description TEXT CHARACTER SET utf8 NULL,
  fix_patches VARCHAR(64) CHARACTER SET utf8 NULL,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  UNIQUE KEY(defect_id, revision),
  INDEX defect_integrated_content_FKIndex1(defect_id),
  FOREIGN KEY(defect_id)
    REFERENCES table_defect_integrated(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
) ENGINE=InnoDB;

CREATE TABLE table_defect_integrated_assigned_to (
  defect_id INTEGER UNSIGNED NOT NULL,
  assigned_to INTEGER UNSIGNED NOT NULL,
  UNIQUE KEY(defect_id, assigned_to),
  INDEX defect_assigned_to_FKIndex1(defect_id),
  INDEX defect_assigned_to_FKIndex2(assigned_to),
  FOREIGN KEY(defect_id)
    REFERENCES table_defect_integrated(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(assigned_to)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;




CREATE TABLE table_requirement_integrated (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  requirement_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(requirement_id),
  INDEX table_requirement_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  campaign_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  campaign_description TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(campaign_id),
  INDEX campaign_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification (
  specification_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  specification_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(specification_id),
  INDEX spec_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test (
  test_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  author_id INTEGER UNSIGNED NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  test_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  test_estimatedTime BIGINT UNSIGNED NOT NULL DEFAULT 0,
  developer_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(test_id),
  INDEX table_test_FKIndex1(folder_id),
  INDEX table_test_FKIndex2(author_id),
  INDEX table_test_FKIndex3(developer_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(developer_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  test_description LONGTEXT CHARACTER SET utf8 NOT NULL,
  test_priority INTEGER UNSIGNED NOT NULL DEFAULT 99,
  test_canonicalPath VARCHAR(255) NOT NULL,
  test_prerequisites TEXT CHARACTER SET utf8 NOT NULL,
  additional_info TEXT CHARACTER SET utf8 NOT NULL,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  UNIQUE KEY(test_id, revision),
  INDEX test_content_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_specification (
  requirement_id INTEGER UNSIGNED NOT NULL,
  specification_id INTEGER UNSIGNED NOT NULL,
  INDEX requirement_spec_FKIndex1(requirement_id),
  INDEX requirement_specification_FKIndex2(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_monitoring_configuration (
  monitoring_configuration_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  monitoring_configuration_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  monitoring_configuration_content TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(monitoring_configuration_id),
  INDEX monitoring_configuration_id_FKIndex1(monitoring_configuration_id)
)
ENGINE=InnoDB;

CREATE TABLE table_schedule (
  schedule_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  schedule_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  schedule_description TEXT CHARACTER SET utf8 NULL,
  schedule_nextStartDate DATETIME NULL,
  campaign_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  schedule_enabled BOOL NOT NULL DEFAULT 1,
  schedule_every TEXT NOT NULL,
  schedule_at TEXT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  on_parent_failed TINYINT NOT NULL DEFAULT 3,
  on_parent_unknown TINYINT NOT NULL DEFAULT 1,
  monitoring_id INTEGER UNSIGNED,
  monitoring_configuration_id INTEGER UNSIGNED,
  PRIMARY KEY(schedule_id),
  INDEX table_schedule_FKIndex1(campaign_id),
  INDEX table_schedule_FKIndex2(user_id),
  INDEX table_schedule_FKIndex4(sut_id),
  INDEX table_schedule_FKIndex5(monitoring_id),
  INDEX table_schedule_FKIndex6(monitoring_configuration_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(monitoring_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(monitoring_configuration_id)
    REFERENCES table_monitoring_configuration(monitoring_configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule_agent ( 
  schedule_id INTEGER UNSIGNED NOT NULL, 
  agent_id INTEGER UNSIGNED NOT NULL, 
  nb_instance INTEGER UNSIGNED NOT NULL DEFAULT 1,
  sync_type TINYINT UNSIGNED NOT NULL DEFAULT 0,
  UNIQUE KEY(schedule_id, agent_id), 
  INDEX schedule_agent_FKIndex1(schedule_id), 
  INDEX schedule_agent_FKIndex2(agent_id), 
  FOREIGN KEY(schedule_id) 
    REFERENCES table_schedule(schedule_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(agent_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session (
  campaign_session_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  campaign_id INTEGER UNSIGNED,
  sut_id INTEGER UNSIGNED NOT NULL,
  campaign_session_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  campaign_session_startDate DATETIME NULL,
  campaign_session_stopDate DATETIME NULL,
  campaign_session_status INTEGER UNSIGNED NOT NULL DEFAULT 1,
  schedule_id INTEGER UNSIGNED,
  introduction TEXT CHARACTER SET utf8 NULL,
  conclusion TEXT CHARACTER SET utf8 NULL,
  on_parent_failed TINYINT NOT NULL DEFAULT 3,
  on_parent_unknown TINYINT NOT NULL DEFAULT 1,
  monitoring_id INTEGER UNSIGNED,
  monitoring_configuration_id INTEGER UNSIGNED,
  PRIMARY KEY(campaign_session_id),
  INDEX campaign_session_FKIndex1(sut_id),
  INDEX campaign_session_FKIndex2(campaign_id),
  INDEX campaign_session_FKIndex3(user_id),
  INDEX campaign_session_FKIndex4(schedule_id),
  INDEX campaign_session_FKIndex6(monitoring_id),
  INDEX campaign_session_FKIndex7(monitoring_configuration_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(monitoring_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(monitoring_configuration_id)
    REFERENCES table_monitoring_configuration(monitoring_configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=InnoDB;

CREATE TABLE table_instance (
  instance_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  campaign_session_id INTEGER UNSIGNED NOT NULL, 
  agent_id INTEGER UNSIGNED NOT NULL, 
  instance_index INTEGER UNSIGNED NOT NULL DEFAULT 0, 
  sync_type TINYINT UNSIGNED NOT NULL DEFAULT 0,  
  PRIMARY KEY(instance_id),
  UNIQUE KEY(campaign_session_id, agent_id, instance_index), 
  INDEX instance_FKIndex1(campaign_session_id), 
  INDEX instance_FKIndex2(agent_id), 
  INDEX instance_FKIndex3(instance_index), 
  INDEX instance_FKIndex4(sync_type), 

  FOREIGN KEY(campaign_session_id) 
    REFERENCES table_campaign_session(campaign_session_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(agent_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;

CREATE TABLE table_sync (
  instance_id INTEGER UNSIGNED NOT NULL, 
  category_id INTEGER UNSIGNED NOT NULL, 
  sync_id INTEGER UNSIGNED NOT NULL DEFAULT 0,
  INDEX sync_FKIndex1(instance_id), 
  INDEX sync_FKIndex2(category_id), 
  INDEX sync_FKIndex3(sync_id), 
  FOREIGN KEY(instance_id) 
    REFERENCES table_instance(instance_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(category_id) 
    REFERENCES table_category(category_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB; 
  
CREATE TABLE table_testcase (
  testcase_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  testcase_index INTEGER UNSIGNED NOT NULL,
  testcase_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  testcase_dev_completed BOOL NOT NULL DEFAULT 0,
  testcase_auth_completed BOOL NOT NULL DEFAULT 1,
  PRIMARY KEY(testcase_id),
  UNIQUE KEY(test_id, testcase_index, testcase_name),
  INDEX testcase_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_steps TEXT CHARACTER SET utf8 NULL,
  testcase_description TEXT CHARACTER SET utf8 NULL,
  testcase_useDescAsTestplan BOOL NOT NULL DEFAULT 0,
  additional_info TEXT CHARACTER SET utf8 NOT NULL,
  date_submitted DATETIME NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id)
)
ENGINE=InnoDB;


CREATE TABLE table_test_dependencies (
  test_id INTEGER UNSIGNED NOT NULL,
  dependsFromTest_id INTEGER UNSIGNED NOT NULL,
  INDEX test_dependencies_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(dependsFromTest_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_boolean (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  test_attr_boolean_value BOOL NOT NULL DEFAULT 0,
  INDEX test_attr_boolean_FKIndex1(attr_boolean_id),
  INDEX test_attr_boolean_FKIndex2(test_id),
  FOREIGN KEY(attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_string (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  test_attr_string_value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX test_attr_string_FKIndex1(attr_string_id),
  INDEX test_attr_string_FKIndex2(test_id),
  FOREIGN KEY(attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_integer (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  test_attr_integer_value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX test_attr_integer_FKIndex2(test_id),
  INDEX test_attr_integer_FKIndex1(attr_integer_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification_test (
  specification_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX specification_test_FKIndex1(test_id),
  INDEX specification_test_FKIndex2(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  position INTEGER UNSIGNED NOT NULL DEFAULT 0,
  INDEX testcase_campaign_FKIndex2(campaign_id),
  INDEX testcase_campaign_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution (
  testcase_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  testcase_execution_result INTEGER UNSIGNED NOT NULL,
  testcase_execution_message MEDIUMTEXT CHARACTER SET utf8 NULL,
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  instance_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(testcase_execution_id),
  UNIQUE KEY (campaign_session_id, testcase_id, instance_id),
  INDEX testcase_execution_FKIndex1(testcase_id),
  INDEX testcase_execution_FKIndex2(campaign_session_id),
  INDEX testcase_execution_FKIndex3(instance_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(instance_id)
    REFERENCES table_instance(instance_id)
      ON DELETE CASCADE 
      ON UPDATE NO ACTION      
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution (
  test_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  test_execution_result INTEGER UNSIGNED NOT NULL,
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  instance_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(test_execution_id),
  UNIQUE KEY (campaign_session_id, test_id, instance_id),
  INDEX test_execution_FKIndex1(test_id),
  INDEX test_execution_FKIndex2(campaign_session_id),
  INDEX test_execution_FKIndex3(instance_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(instance_id)
    REFERENCES table_instance(instance_id)
      ON DELETE CASCADE 
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution_defect (
  defect_id INTEGER UNSIGNED NOT NULL,
  test_execution_id INTEGER UNSIGNED NOT NULL,
  INDEX test_execution_defect_FKIndex1(test_execution_id),
  FOREIGN KEY(test_execution_id)
    REFERENCES table_test_execution(test_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_ccemails (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(campaign_session_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule_ccemails (
  schedule_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(schedule_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_change (
  type TINYINT NOT NULL,
  id INTEGER UNSIGNED NOT NULL,
  date DATETIME NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  action TINYINT NOT NULL,
  information VARCHAR(255) CHARACTER SET utf8 NOT NULL,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_stat (
  entry_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  database_type TINYINT NOT NULL,
  container_type TINYINT NOT NULL,
  type TINYINT NOT NULL,
  container VARCHAR(255) CHARACTER SET utf8 NULL,
  date DATETIME NULL,
  stat MEDIUMTEXT CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(entry_id)
)
ENGINE=InnoDB;

CREATE TABLE table_platform (
  platform_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  platform_name VARCHAR(32) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(platform_id)
)
ENGINE=InnoDB;

CREATE TABLE table_os (
  os_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  os_name VARCHAR(32) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(os_id)
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated_sut (
  type TINYINT NOT NULL,
  defect_id INTEGER UNSIGNED NOT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  UNIQUE KEY (type, defect_id, sut_id),
  INDEX defect_FKIndex1(defect_id),
  INDEX sut_FKIndex2(sut_id),
  FOREIGN KEY(defect_id)
    REFERENCES table_defect_integrated(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_configuration (
  configuration_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  jar_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  configuration_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  configuration_content TEXT CHARACTER SET utf8 NULL,
  INDEX configuration_id_FKIndex1(configuration_id),
  UNIQUE KEY(jar_name, configuration_name)
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_configuration (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  configuration_id INTEGER UNSIGNED NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX configuration_FKIndex2(configuration_id),
  INDEX category_FKIndex3(category_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(configuration_id)
    REFERENCES table_configuration(configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule_configuration (
  schedule_id INTEGER UNSIGNED NOT NULL,
  configuration_id INTEGER UNSIGNED NOT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  INDEX schedule_FKIndex1(schedule_id),
  INDEX configuration_FKIndex2(configuration_id),
  INDEX category_FKIndex3(category_id),
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(configuration_id)
    REFERENCES table_configuration(configuration_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_task (
  task_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  task_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  task_description TEXT CHARACTER SET utf8 NULL,
  priority TINYINT NOT NULL,
  estimated DECIMAL(3,1) NOT NULL DEFAULT 1.0,
  PRIMARY KEY(task_id),
  INDEX task_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;



CREATE TABLE table_sprint (
  sprint_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sprint_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  sprint_description TEXT CHARACTER SET utf8 NULL,
  status TINYINT NOT NULL,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  project_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sprint_id),
  INDEX table_sprint_FKIndex1(project_id),
  FOREIGN KEY(project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_task (
  sprint_id INTEGER UNSIGNED NOT NULL,
  task_id INTEGER UNSIGNED NOT NULL,
  progress TINYINT UNSIGNED NOT NULL DEFAULT 0,
  assigned_to INTEGER UNSIGNED NULL,
  INDEX sprint_task_FKIndex1(sprint_id),
  INDEX sprint_task_FKIndex2(task_id),
  INDEX sprint_task_FKIndex3(assigned_to),
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(task_id)
    REFERENCES table_task(task_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(assigned_to)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION      
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_developer (
  sprint_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  availability TINYINT UNSIGNED NOT NULL DEFAULT 0,
  INDEX sprint_user_FKIndex1(sprint_id),
  INDEX sprint_user_FKIndex2(user_id),
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_stat (
  sprint_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date DATETIME NULL,
  stat MEDIUMTEXT CHARACTER SET utf8 NOT NULL,
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attribute_string (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX test_FKIndex2(test_id),
  INDEX attribute_string_FKIndex3(attr_string_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attribute_boolean (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  value BOOL NOT NULL DEFAULT 0,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX test_FKIndex2(test_id),
  INDEX attribute_boolean_FKIndex3(attr_boolean_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attribute_integer (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  INDEX campaign_session_FKIndex1(campaign_session_id),
  INDEX test_FKIndex2(test_id),
  INDEX attribute_integer_FKIndex3(attr_integer_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_absence_type (
  absence_type_id TINYINT UNSIGNED NOT NULL AUTO_INCREMENT,
  absence_type_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(absence_type_id)
)
ENGINE=InnoDB;

CREATE TABLE table_absence (
  absence_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  type TINYINT NOT NULL DEFAULT 10,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  comment TEXT CHARACTER SET utf8 NULL,
  status TINYINT NOT NULL DEFAULT 10,
  PRIMARY KEY(absence_id),
  INDEX abs_FKIndex1(user_id),
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_holiday (
  holiday_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  country_id CHAR(2) NOT NULL,
  start_date DATETIME NULL,
  stop_date DATETIME NULL,
  comment TEXT CHARACTER SET utf8 NULL,
  PRIMARY KEY(holiday_id),
  INDEX holiday_FKIndex1(country_id),
  FOREIGN KEY(country_id)
    REFERENCES table_country(country_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE table_weekend (
  weekend_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  country_id CHAR(2) NOT NULL,
  days VARCHAR(14) CHARACTER SET utf8 ,
  PRIMARY KEY(weekend_id),
  INDEX weekend_FKIndex1(country_id),
  FOREIGN KEY(country_id)
    REFERENCES table_country(country_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE table_sut_requirement (
  sut_id INTEGER UNSIGNED NOT NULL,
  requirement_id INTEGER UNSIGNED NOT NULL,
  INDEX sut_requirement_FKIndex1(sut_id),
  INDEX sut_requirement_FKIndex2(requirement_id),
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX testcase_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX testcase_attachment_FKIndex1(testcase_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX testcase_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_testcase_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX testcase_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX test_attachment_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX test_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_test_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX test_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_folder_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX folder_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX test_attachment_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_folder_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX folder_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_folder_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX folder_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_category_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX category_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX test_attachment_FKIndex1(category_id),
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_category_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX category_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_category_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX category_categorycontent_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_execution_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX testcase_execution_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX test_attachment_FKIndex1(testcase_execution_id),
  FOREIGN KEY(testcase_execution_id)
    REFERENCES table_testcase_execution(testcase_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX testcase_execution_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_testcase_execution_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX testcase_execution_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  defect_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX defect_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX test_attachment_FKIndex1(defect_id),
  FOREIGN KEY(defect_id)
    REFERENCES table_defect_integrated(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX defect_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_defect_integrated_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX defect_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX campaign_session_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX campaign_session_attachment_FKIndex1(campaign_session_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX campaign_session_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_campaign_session_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX campaign_session_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_integrated_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  requirement_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX requirement_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX req_attachment_FKIndex1(requirement_id),
  FOREIGN KEY(requirement_id)
    REFERENCES table_requirement_integrated(requirement_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_integrated_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX requirement_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_requirement_integrated_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX requirement_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  specification_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX specification_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX spec_attachment_FKIndex1(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX specification_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_specification_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX specification_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_monitor ( 
  monitor_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  campaign_session_id INTEGER UNSIGNED NOT NULL, 
  monitored_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(monitor_id),
  UNIQUE KEY(campaign_session_id, monitored_id), 
  INDEX monitoring_FKIndex1(campaign_session_id), 
  INDEX monitoring_FKIndex2(monitored_id), 
  FOREIGN KEY(campaign_session_id) 
    REFERENCES table_campaign_session(campaign_session_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(monitored_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB; 

CREATE TABLE table_monitored_results ( 
  monitor_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  timestamp BIGINT UNSIGNED NOT NULL DEFAULT 0,
  class VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  subclass VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  value INTEGER NOT NULL DEFAULT 0, 
  INDEX monitored_results_FKIndex1(monitor_id),
  FOREIGN KEY(monitor_id) 
    REFERENCES table_monitor(monitor_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION     
)
ENGINE=InnoDB;        

CREATE TABLE table_schedule_monitored ( 
  schedule_id INTEGER UNSIGNED NOT NULL, 
  monitored_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(schedule_id, monitored_id), 
  INDEX schedule_monitored_FKIndex1(schedule_id), 
  INDEX schedule_monitored_FKIndex2(monitored_id), 
  FOREIGN KEY(schedule_id) 
    REFERENCES table_schedule(schedule_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(monitored_id) 
    REFERENCES table_agent(agent_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_integrated_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  requirement_id INTEGER UNSIGNED NOT NULL, 
  requirement_description TEXT CHARACTER SET utf8 NULL, 
  type SMALLINT NOT NULL DEFAULT 10, 
  priority TINYINT NOT NULL DEFAULT 20, 
  status TINYINT NOT NULL DEFAULT 30, 
  date_submitted DATETIME NULL, 
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1, 
  PRIMARY KEY(content_id), 
  UNIQUE KEY(requirement_id, revision), 
  INDEX requirement_content_FKIndex1(requirement_id), 
  FOREIGN KEY(requirement_id) 
    REFERENCES table_requirement_integrated(requirement_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
) ENGINE=InnoDB;


CREATE TABLE table_specification_content ( 
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT, 
  specification_id INTEGER UNSIGNED NOT NULL, 
  specification_isFormal BOOL NOT NULL DEFAULT 0, 
  specification_description TEXT CHARACTER SET utf8 NULL, 
  priority TINYINT NOT NULL DEFAULT 20, 
  status TINYINT NOT NULL DEFAULT 30, 
  date_submitted DATETIME NULL, 
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1, 
  PRIMARY KEY(content_id), 
  UNIQUE KEY(specification_id, revision), 
  INDEX specification_content_FKIndex1(specification_id), 
  FOREIGN KEY(specification_id) 
    REFERENCES table_specification(specification_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
) ENGINE=InnoDB;

CREATE TABLE table_project_manager (
  project_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  UNIQUE KEY(project_id, user_id),
  INDEX project_manager_FKIndex1(project_id),
  INDEX project_manager_FKIndex2(user_id),
  FOREIGN KEY(project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_url (
  url_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_content_id INTEGER UNSIGNED NOT NULL,
  url VARCHAR(384) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(url_id), 
  INDEX test_url_FKIndex1(test_content_id),
  FOREIGN KEY(test_content_id)
    REFERENCES table_test_content(content_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=INNODB;

CREATE TABLE table_param_string (
  param_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  param_string_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  param_string_normal_values VARCHAR(4096) CHARACTER SET utf8 NOT NULL,
  param_string_invalid_values VARCHAR(4096) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(param_string_id),
  UNIQUE KEY (param_string_name)
)
ENGINE=INNODB;

CREATE TABLE table_param_integer (
  param_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  param_integer_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  param_integer_normal_values VARCHAR(4096) CHARACTER SET utf8 NOT NULL,
  param_integer_invalid_values VARCHAR(4096) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(param_integer_id),
  UNIQUE KEY (param_integer_name)
)
ENGINE=INNODB;

CREATE TABLE table_param_boolean (
  param_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  param_boolean_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  PRIMARY KEY(param_boolean_id),
  UNIQUE KEY (param_boolean_name)
)
ENGINE=INNODB;

CREATE TABLE table_testcase_testcase_content ( 
  testcase_id INTEGER UNSIGNED NOT NULL, 
  content_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(testcase_id, content_id), 
  INDEX testcase_testcase_content_id_FKIndex1(testcase_id), 
  FOREIGN KEY(testcase_id) 
    REFERENCES table_testcase(testcase_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  INDEX testcase_testcase_content_id_FKIndex2(content_id), 
  FOREIGN KEY(content_id) 
    REFERENCES table_testcase_content(content_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
) ENGINE=InnoDB;

CREATE TABLE table_testcase_param_string (
  testcase_id INTEGER UNSIGNED NOT NULL,
  param_string_id INTEGER UNSIGNED NOT NULL,
  param_string_value VARCHAR(256) CHARACTER SET utf8 NOT NULL,
  UNIQUE KEY(testcase_id, param_string_id),
  INDEX testcase_param_string_FKIndex1(testcase_id),
  INDEX testcase_param_string_FKIndex2(param_string_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(param_string_id)
    REFERENCES table_param_string(param_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION  
)
ENGINE=INNODB;

CREATE TABLE table_testcase_param_integer (
  testcase_id INTEGER UNSIGNED NOT NULL,
  param_integer_id INTEGER UNSIGNED NOT NULL,
  param_integer_value VARCHAR(16) NOT NULL,
  UNIQUE KEY(testcase_id, param_integer_id),
  INDEX testcase_param_integer_FKIndex1(testcase_id),
  INDEX testcase_param_integer_FKIndex2(param_integer_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(param_integer_id)
    REFERENCES table_param_integer(param_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION  
)
ENGINE=INNODB;

CREATE TABLE table_testcase_param_boolean (
  testcase_id INTEGER UNSIGNED NOT NULL,
  param_boolean_id INTEGER UNSIGNED NOT NULL,
  param_boolean_value BOOL NOT NULL DEFAULT 0,
  UNIQUE KEY(testcase_id, param_boolean_id),
  INDEX testcase_param_boolean_FKIndex1(testcase_id),
  INDEX testcase_param_boolean_FKIndex2(param_boolean_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(param_boolean_id)
    REFERENCES table_param_boolean(param_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION  
)
ENGINE=INNODB;

CREATE TABLE table_campaign_session_agent_status (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  agent_id INTEGER UNSIGNED NOT NULL,
  campaign_session_agent_status INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(campaign_session_id, agent_id),
  INDEX campaign_session_agent_status_FKIndex1(campaign_session_id),
  INDEX campaign_session_agent_status_FKIndex2(agent_id),
  FOREIGN KEY(campaign_session_id )
    REFERENCES table_campaign_session(campaign_session_id )
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(agent_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_usergroup (
  usergroup_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  usergroup_name VARCHAR(128) NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(usergroup_id),
  INDEX user_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION     
)
ENGINE=InnoDB;

CREATE TABLE table_usergroup_user (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  user_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(usergroup_id, user_id), 
  INDEX usergroup_user_FKIndex1(usergroup_id), 
  INDEX usergroup_user_FKIndex2(user_id), 
  FOREIGN KEY(usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(user_id) 
    REFERENCES table_user(user_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;

CREATE TABLE table_usergroup_folder (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  folder_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(usergroup_id, folder_id), 
  INDEX usergroup_folder_FKIndex1(usergroup_id), 
  INDEX usergroup_folder_FKIndex2(folder_id), 
  FOREIGN KEY(usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(folder_id) 
    REFERENCES table_folder(folder_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;

CREATE TABLE table_usergroup_company (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  company_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(usergroup_id, company_id), 
  INDEX usergroup_company_FKIndex1(usergroup_id), 
  INDEX usergroup_company_FKIndex2(company_id), 
  FOREIGN KEY(usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(company_id) 
    REFERENCES table_company(company_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;

CREATE TABLE table_usergroup_category (
  usergroup_id INTEGER UNSIGNED NOT NULL, 
  category_id INTEGER UNSIGNED NOT NULL, 
  UNIQUE KEY(usergroup_id, category_id), 
  INDEX usergroup_category_FKIndex1(usergroup_id), 
  INDEX usergroup_category_FKIndex2(category_id), 
  FOREIGN KEY(usergroup_id) 
    REFERENCES table_usergroup(usergroup_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION, 
  FOREIGN KEY(category_id) 
    REFERENCES table_category(category_id) 
      ON DELETE CASCADE 
      ON UPDATE NO ACTION 
)
ENGINE=InnoDB;









CREATE TABLE table_company_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX company_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX company_attachment_FKIndex1(company_id),
  FOREIGN KEY(company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_company_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX company_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_company_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX company_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sut_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sut_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sut_attachment_FKIndex1(sut_id),
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sut_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX sut_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_sut_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sut_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_project_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  project_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX project_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX project_attachment_FKIndex1(project_id),
  FOREIGN KEY(project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_project_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX project_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_project_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX project_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_task_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  task_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX task_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX task_attachment_FKIndex1(task_id),
  FOREIGN KEY(task_id)
    REFERENCES table_task(task_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_task_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX task_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_task_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX task_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sprint_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sprint_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sprint_attachment_FKIndex1(sprint_id),
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX sprint_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_sprint_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sprint_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX campaign_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX campaign_attachment_FKIndex1(campaign_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX campaign_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_campaign_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX campaign_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_custom_field_string (
  custom_field_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  custom_field_string_source_type SMALLINT NOT NULL DEFAULT 0,
  custom_field_string_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  custom_field_string_mandatory BOOL NOT NULL DEFAULT 0,
  custom_field_string_default_value VARCHAR(4096) CHARACTER SET utf8 NOT NULL DEFAULT '',
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(custom_field_string_id),
  UNIQUE KEY (custom_field_string_source_type, custom_field_string_name)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_integer (
  custom_field_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  custom_field_integer_source_type SMALLINT NOT NULL DEFAULT 0,
  custom_field_integer_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  custom_field_integer_mandatory BOOL NOT NULL DEFAULT 0,
  custom_field_integer_default_value INTEGER NOT NULL DEFAULT 0,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(custom_field_integer_id),
  UNIQUE KEY (custom_field_integer_source_type, custom_field_integer_name)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_boolean (
  custom_field_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  custom_field_boolean_source_type SMALLINT NOT NULL DEFAULT 0,
  custom_field_boolean_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  custom_field_boolean_default_value BOOL NOT NULL DEFAULT 0,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(custom_field_boolean_id),
  UNIQUE KEY (custom_field_boolean_source_type, custom_field_boolean_name)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_html (
  custom_field_html_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  custom_field_html_source_type SMALLINT NOT NULL DEFAULT 0,
  custom_field_html_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  custom_field_html_mandatory BOOL NOT NULL DEFAULT 0,
  custom_field_html_default_value TEXT CHARACTER SET utf8 NOT NULL,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(custom_field_html_id),
  UNIQUE KEY (custom_field_html_source_type, custom_field_html_name)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_stringchoice (
  custom_field_stringchoice_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  custom_field_stringchoice_source_type SMALLINT NOT NULL DEFAULT 0,
  custom_field_stringchoice_name VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  custom_field_stringchoice_possible_values VARCHAR(4096) CHARACTER SET utf8 NOT NULL DEFAULT '',
  custom_field_stringchoice_default_value VARCHAR(4096) CHARACTER SET utf8 NOT NULL DEFAULT '',
  custom_field_stringchoice_multiple_choices BOOL NOT NULL DEFAULT 0,
  position SMALLINT NOT NULL DEFAULT 1,
  PRIMARY KEY(custom_field_stringchoice_id),
  UNIQUE KEY (custom_field_stringchoice_source_type, custom_field_stringchoice_name)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_string_value (
  custom_field_string_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  FOREIGN KEY(custom_field_string_id)
    REFERENCES table_custom_field_string(custom_field_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY (custom_field_string_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_integer_value (
  custom_field_integer_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value INTEGER NOT NULL,
  FOREIGN KEY(custom_field_integer_id)
    REFERENCES table_custom_field_integer(custom_field_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY (custom_field_integer_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_boolean_value (
  custom_field_boolean_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value BOOLEAN NOT NULL,
  FOREIGN KEY(custom_field_boolean_id)
    REFERENCES table_custom_field_boolean(custom_field_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY (custom_field_boolean_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_html_value (
  custom_field_html_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value TEXT CHARACTER SET utf8 NOT NULL,
  FOREIGN KEY(custom_field_html_id)
    REFERENCES table_custom_field_html(custom_field_html_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY (custom_field_html_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_custom_field_stringchoice_value (
  custom_field_stringchoice_id INTEGER UNSIGNED NOT NULL,
  source_id INTEGER UNSIGNED NOT NULL,
  value VARCHAR(64) CHARACTER SET utf8 NOT NULL,
  FOREIGN KEY(custom_field_stringchoice_id)
    REFERENCES table_custom_field_stringchoice(custom_field_stringchoice_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  UNIQUE KEY (custom_field_stringchoice_id, source_id)
)
ENGINE=INNODB;

CREATE TABLE table_requirement_generic (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  external_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(requirement_id),
  INDEX requirement_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_test (
  requirement_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX requirement_test_FKIndex1(requirement_id),
  INDEX requirement_test_FKIndex2(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

