UPDATE table_version SET version_number = '2' WHERE version_id = '1';

INSERT INTO table_folder VALUES (9, 6, 'Manual', 1, 10);

ALTER TABLE table_user             ADD    user_local               Varchar(5)        DEFAULT 'en_US'            NOT NULL;
ALTER TABLE table_user             ADD    user_rights              TEXT              DEFAULT 'CAE9AAFDF655DF22' NOT NULL;
ALTER TABLE table_user             ADD    user_email               TEXT              DEFAULT ''                 NOT NULL;
ALTER TABLE table_test             DROP   testcase_lastExecutionId;
ALTER TABLE table_testcase         ADD    testcase_steps           TEXT              DEFAULT ''                 NOT NULL;
ALTER TABLE table_campaign_session ADD    campaign_session_conf    TEXT              DEFAULT ''                 NOT NULL;
ALTER TABLE table_campaign_session ADD    schedule_id              INTEGER UNSIGNED,
ALTER TABLE table_campaign_session CHANGE campaign_session_engaged campaign_session_status INTEGER UNSIGNED NOT NULL DEFAULT 1;


DROP TABLE table_testcase_execution_step;
DROP TABLE table_testcase_step_check;
DROP TABLE table_testcase_step;
DROP TABLE table_step;
DROP TABLE table_check;


# backward incompatibility
DROP TABLE table_testcase_campaign;

CREATE TABLE table_test_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX testcase_campaign_FKIndex2(campaign_id),
  INDEX testcase_campaign_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution (
  test_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  test_execution_result INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(test_execution_id),
  INDEX test_execution_FKIndex1(test_id),
  INDEX test_execution_FKIndex2(campaign_session_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

DROP TABLE table_testcase_execution_defect ;

CREATE TABLE table_test_execution_defect (
  defect_id INTEGER UNSIGNED NOT NULL,
  test_execution_id INTEGER UNSIGNED NOT NULL,
  INDEX test_execution_defect_FKIndex1(test_execution_id),
  INDEX table_test_execution_defect_FKIndex2(defect_id),
  FOREIGN KEY(test_execution_id)
    REFERENCES table_test_execution(test_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(defect_id)
    REFERENCES table_defect(defect_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

DROP TABLE table_spec_testcase;

CREATE TABLE table_specification_test (
  specification_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX specification_test_FKIndex2(test_id),
  INDEX table_spec_testcase_FKIndex2(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;


CREATE TABLE table_agent (
  agent_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  agent_name TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(agent_id),
  INDEX agent_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_notification (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(campaign_session_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule (
  schedule_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  schedule_name Varchar(45) NOT NULL,
  schedule_description LONGBLOB NOT NULL,
  campaign_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(schedule_id),
  INDEX table_schedule_FKIndex1(campaign_id),
  INDEX table_schedule_FKIndex2(user_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;
