UPDATE table_version SET version_number = '54' WHERE version_id = '1';

DROP SEQUENCE SEQ_sess_attr_boolean;
DROP SEQUENCE SEQ_sess_attr_integer;
DROP SEQUENCE SEQ_sess_attr_string;

CREATE SEQUENCE  SEQ_expl MINVALUE 1 MAXVALUE 999999999999999999999999 INCREMENT BY 1  NOCYCLE;
CREATE SEQUENCE  SEQ_expl_data MINVALUE 1 MAXVALUE 999999999999999999999999 INCREMENT BY 1  NOCYCLE;
CREATE SEQUENCE  SEQ_expl_attach MINVALUE 1 MAXVALUE 999999999999999999999999 INCREMENT BY 1  NOCYCLE;
CREATE SEQUENCE  SEQ_expl_attach_data MINVALUE 1 MAXVALUE 999999999999999999999999 INCREMENT BY 1  NOCYCLE;

CREATE TABLE table_expl (
  expl_id NUMBER(10,0) NOT NULL,
  expl_name VARCHAR2(128 CHAR) NOT NULL,
  folder_id NUMBER(10,0) NOT NULL,
  sut_id NUMBER(10,0) NOT NULL,
  tester_id NUMBER(10,0) NOT NULL
);
ALTER TABLE table_expl ADD CONSTRAINT PRIMARY_89 PRIMARY KEY (expl_id) ENABLE;
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl TO PUBLIC;

CREATE TABLE table_expl_data (
  data_id NUMBER(10,0) NOT NULL,
  expl_id NUMBER(10,0) NOT NULL,
  status NUMBER(3,0) DEFAULT '10' NOT NULL,
  priority NUMBER(3,0) DEFAULT '20' NOT NULL,
  charter CLOB,
  notes CLOB,
  percent_setup NUMBER(3,0) DEFAULT '100' NOT NULL,
  percent_exec NUMBER(3,0) DEFAULT '0' NOT NULL,
  percent_report NUMBER(3,0) DEFAULT '0' NOT NULL,
  percent_other NUMBER(3,0) DEFAULT '0' NOT NULL,
  startDate DATE,
  stopDate DATE,
  cummul_runtime NUMBER(10,0) DEFAULT '0' NOT NULL,
  date_submitted DATE,
  revision NUMBER(10,0) DEFAULT '1' NOT NULL
);
ALTER TABLE table_expl_data ADD CONSTRAINT PRIMARY_90 PRIMARY KEY (data_id) ENABLE;
CREATE UNIQUE INDEX expl_data_UK_1 ON table_expl_data (expl_id, revision);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl_data TO PUBLIC;

CREATE TABLE table_def_int_expl (
  defect_id NUMBER(10,0) NOT NULL,
  expl_id NUMBER(10,0) NOT NULL
);
CREATE INDEX def_int_expl_IK_1 ON table_def_int_expl(defect_id);
CREATE INDEX def_int_expl_IK_2 ON table_def_int_expl(expl_id);
CREATE UNIQUE INDEX def_int_expl_UK_1 ON table_def_int_expl (defect_id, expl_id);

CREATE TABLE table_expl_attach (
  attachment_id NUMBER(10,0) NOT NULL,
  expl_id NUMBER(10,0) NOT NULL,
  attachment_name VARCHAR2(128 CHAR) NOT NULL,
  locked_by NUMBER(10,0),
  hidden NUMBER(3,0) DEFAULT '0' NOT NULL
);
ALTER TABLE table_expl_attach ADD CONSTRAINT PRIMARY_91 PRIMARY KEY (attachment_id) ENABLE;
CREATE INDEX expl_attach_IK_1 ON table_expl_attach (locked_by);
CREATE INDEX expl_attach_IK_2 ON table_expl_attach (expl_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl_attach TO PUBLIC;

CREATE TABLE table_expl_attach_data (
  data_id NUMBER(10,0) NOT NULL,
  attachment_id NUMBER(10,0) NOT NULL,
  attachment_data BLOB,
  date_submitted DATE,
  size_data NUMBER(10,0) NOT NULL,
  author_id NUMBER(10,0) NOT NULL,
  revision NUMBER(10,0) DEFAULT '1' NOT NULL
);
ALTER TABLE table_expl_attach_data ADD CONSTRAINT PRIMARY_92 PRIMARY KEY (data_id) ENABLE;
CREATE INDEX expl_attach_data_IK_1 ON table_expl_attach_data (attachment_id);
CREATE INDEX expl_attach_data_IK_2 ON table_expl_attach_data (author_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl_attach_data TO PUBLIC;

CREATE TABLE table_expl_attr_boolean (
  expl_id NUMBER(10,0) NOT NULL,
  attr_boolean_id NUMBER(10,0) NOT NULL,
  expl_attr_boolean_value NUMBER(3,0) DEFAULT '0' NOT NULL
);
CREATE INDEX expl_attr_boolean_IK_1 ON table_expl_attr_boolean (attr_boolean_id);
CREATE INDEX expl_attr_boolean_IK_2 ON table_expl_attr_boolean (expl_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl_attr_boolean TO PUBLIC;

CREATE TABLE table_expl_attr_integer (
  expl_id NUMBER(10,0) NOT NULL,
  attr_integer_id NUMBER(10,0) NOT NULL,
  expl_attr_integer_value CLOB NOT NULL
);
CREATE INDEX expl_attr_integer_IK_1 ON table_expl_attr_integer (attr_integer_id);
CREATE INDEX expl_attr_integer_IK_2 ON table_expl_attr_integer (expl_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl_attr_integer TO PUBLIC;

CREATE TABLE table_expl_attr_string (
  expl_id NUMBER(10,0) NOT NULL,
  attr_string_id NUMBER(10,0) NOT NULL,
  expl_attr_string_value CLOB
);
CREATE INDEX expl_attr_string_IK_1 ON table_expl_attr_string (attr_string_id);
CREATE INDEX expl_attr_string_IK_2 ON table_expl_attr_string (expl_id);
GRANT SELECT, INSERT, DELETE, UPDATE, REFERENCES ON table_expl_attr_string TO PUBLIC;




ALTER TABLE table_expl ADD CONSTRAINT table_expl_ibfk_1 FOREIGN KEY (folder_id) REFERENCES table_folder(folder_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl ADD CONSTRAINT table_expl_ibfk_2 FOREIGN KEY (sut_id)    REFERENCES table_sut(sut_id)       ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl ADD CONSTRAINT table_expl_ibfk_3 FOREIGN KEY (tester_id) REFERENCES table_user(user_id)     ON DELETE CASCADE ENABLE;

ALTER TABLE table_expl_data ADD CONSTRAINT table_expl_data_ibfk_1 FOREIGN KEY (expl_id) REFERENCES table_expl(expl_id) ON DELETE CASCADE ENABLE;

ALTER TABLE table_def_int_expl ADD CONSTRAINT table_def_int_expl_ibfk_1 FOREIGN KEY (defect_id) REFERENCES table_def_int(defect_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_def_int_expl ADD CONSTRAINT table_def_int_expl_ibfk_2 FOREIGN KEY (expl_id)   REFERENCES table_expl(expl_id)      ON DELETE CASCADE ENABLE;

ALTER TABLE table_expl_attach ADD CONSTRAINT table_expl_attach_ibfk_1 FOREIGN KEY (locked_by) REFERENCES table_user (user_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl_attach ADD CONSTRAINT table_expl_attach_ibfk_2 FOREIGN KEY (expl_id) REFERENCES table_expl (expl_id) ON DELETE CASCADE ENABLE;

ALTER TABLE table_expl_attach_data ADD CONSTRAINT table_expl_attach_data_ibfk_1 FOREIGN KEY (attachment_id) REFERENCES table_expl_attach (attachment_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl_attach_data ADD CONSTRAINT table_expl_attach_data_ibfk_2 FOREIGN KEY (author_id) REFERENCES table_user (user_id) ON DELETE CASCADE ENABLE;

ALTER TABLE table_expl_attr_boolean ADD CONSTRAINT table_expl_attr_boolean_ibfk_1 FOREIGN KEY (attr_boolean_id) REFERENCES table_attr_boolean (attr_boolean_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl_attr_boolean ADD CONSTRAINT table_expl_attr_boolean_ibfk_2 FOREIGN KEY (expl_id) REFERENCES table_expl (expl_id) ON DELETE CASCADE ENABLE;

ALTER TABLE table_expl_attr_integer ADD CONSTRAINT table_expl_attr_integer_ibfk_1 FOREIGN KEY (attr_integer_id) REFERENCES table_attr_integer (attr_integer_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl_attr_integer ADD CONSTRAINT table_expl_attr_integer_ibfk_2 FOREIGN KEY (expl_id) REFERENCES table_expl (expl_id) ON DELETE CASCADE ENABLE;

ALTER TABLE table_expl_attr_string ADD CONSTRAINT table_expl_attr_string_ibfk_1 FOREIGN KEY (attr_string_id) REFERENCES table_attr_string (attr_string_id) ON DELETE CASCADE ENABLE;
ALTER TABLE table_expl_attr_string ADD CONSTRAINT table_expl_attr_string_ibfk_2 FOREIGN KEY (expl_id) REFERENCES table_expl (expl_id) ON DELETE CASCADE ENABLE;




CREATE OR REPLACE TRIGGER TRIG_expl BEFORE INSERT OR UPDATE ON table_expl FOR EACH ROW
DECLARE 
v_newVal NUMBER(12) := 0;
v_incval NUMBER(12) := 0;
BEGIN
  IF INSERTING AND :new.expl_id IS NULL THEN
    SELECT  SEQ_expl.NEXTVAL INTO v_newVal FROM DUAL;
    IF v_newVal = 1 THEN 
      SELECT NVL(max(expl_id),0) INTO v_newVal FROM table_expl;
      v_newVal := v_newVal + 1;
      LOOP
           EXIT WHEN v_incval>=v_newVal;
           SELECT SEQ_expl.nextval INTO v_incval FROM dual;
      END LOOP;
    END IF;
   :new.expl_id := v_newVal;
  END IF;
END;
/
CREATE OR REPLACE TRIGGER TRIG_expl_data BEFORE INSERT OR UPDATE ON table_expl_data FOR EACH ROW
DECLARE 
v_newVal NUMBER(12) := 0;
v_incval NUMBER(12) := 0;
BEGIN
  IF INSERTING AND :new.data_id IS NULL THEN
    SELECT  SEQ_expl_data.NEXTVAL INTO v_newVal FROM DUAL;
    IF v_newVal = 1 THEN 
      SELECT NVL(max(data_id),0) INTO v_newVal FROM table_expl_data;
      v_newVal := v_newVal + 1;
      LOOP
           EXIT WHEN v_incval>=v_newVal;
           SELECT SEQ_expl_data.nextval INTO v_incval FROM dual;
      END LOOP;
    END IF;
   :new.data_id := v_newVal;
  END IF;
END;
/
CREATE OR REPLACE TRIGGER TRIG_expl_attach BEFORE INSERT OR UPDATE ON table_expl_attach FOR EACH ROW
DECLARE 
v_newVal NUMBER(12) := 0;
v_incval NUMBER(12) := 0;
BEGIN
  IF INSERTING AND :new.attachment_id IS NULL THEN
    SELECT  SEQ_expl_attach.NEXTVAL INTO v_newVal FROM DUAL;    
	IF v_newVal = 1 THEN       
	  SELECT NVL(max(attachment_id),0) INTO v_newVal FROM table_expl_attach;
      v_newVal := v_newVal + 1;
      LOOP
           EXIT WHEN v_incval>=v_newVal;
           SELECT SEQ_expl_attach.nextval INTO v_incval FROM dual;
      END LOOP;
    END IF;
   :new.attachment_id := v_newVal;
  END IF;
END;
/
CREATE OR REPLACE TRIGGER TRIG_expl_attach_data BEFORE INSERT OR UPDATE ON table_expl_attach_data FOR EACH ROW
DECLARE 
v_newVal NUMBER(12) := 0;
v_incval NUMBER(12) := 0;
BEGIN
  IF INSERTING AND :new.data_id IS NULL THEN
    SELECT  SEQ_expl_attach_data.NEXTVAL INTO v_newVal FROM DUAL;
    IF v_newVal = 1 THEN 
      SELECT NVL(max(data_id),0) INTO v_newVal FROM table_expl_attach_data;
      v_newVal := v_newVal + 1;
      LOOP
           EXIT WHEN v_incval>=v_newVal;
           SELECT SEQ_expl_attach_data.nextval INTO v_incval FROM dual;
      END LOOP;
    END IF;
   :new.data_id := v_newVal;
  END IF;
END;
/

DISCONNECT;
exit;
