<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="defects/@codebase" />
  <xsl:variable name="bugtrackingType" select="defects/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="defects/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="defects/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/defectHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    
	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="domain"                select="defects/@domain" />
        <xsl:variable name="graphInReportsEnabled" select="defects/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="defects/@date" />
        <xsl:variable name="documentAuthor"        select="defects/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$domain = 1">
            <span class="report_title">#defect.Complete_Defect#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 3">
            <span class="report_title">#defect.Folder_Defect#</span><br/>
          </xsl:if>
          <span class="report_subtitle">Active Defects With Statistics</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_metrics">#defect.Metrics#</a><br/>
          <a class="report_table_of_content" href="#_summary">#defect.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#defect.Details#</a><br/>
          <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field --> 
            <a class="report_table_of_content" href="#_perpriority">#defect.Per_priority#</a><br/>
            <a class="report_table_of_content" href="#_perseverity">#defect.Per_severity#</a><br/>
            <a class="report_table_of_content" href="#_perstatus">#defect.Per_status#</a><br/>
          </xsl:if>
          <a class="report_table_of_content" href="#_tbd">#defect.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#defect.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <a name="_metrics"/>
        <h1>#defect.Metrics#</h1>
        <xsl:call-template name="generateGlobalMetrics"/>

        <a name="_summary"/>
        <h1>#defect.Summary#</h1>
        <!-- If we want to display some charts here they should be showing only active defects -->
        <xsl:call-template name="insertCharts">
          <xsl:with-param name="graphInReportsEnabled" select="$graphInReportsEnabled"/>
          <xsl:with-param name="domain" select="$domain"/>
        </xsl:call-template>


        <table width="100%">
          <!-- ******************* defect SUMMARY *************************** -->
          <tr>
            <td class="table_data_header" width="90%">#defect.Folder#</td>
            <td class="table_data_header">#defect.Nb_defects#</td>
            <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field --> 
              <td class="table_data_header">#defect.priority.High#</td>
              <td class="table_data_header">#defect.priority.Normal#</td>
              <td class="table_data_header">#defect.priority.Low#</td>
              <td class="table_data_header">#defect.severity.Blocking#</td>
              <td class="table_data_header">#defect.severity.Major#</td>
              <td class="table_data_header">#defect.severity.Minor#</td>
              <td class="table_data_header">#defect.severity.Cosmetic#</td>
              <td class="table_data_header">#defect.severity.Enhancement#</td>
              <td class="table_data_header">#defect.status.New#</td>
              <td class="table_data_header">#defect.status.Assigned#</td>
              <td class="table_data_header">#defect.status.Acknowledged#</td>
            </xsl:if>
            <!--
            <td class="table_data_header">#defect.status.Resolved#</td>
            <td class="table_data_header">#defect.status.Closed#</td>
            -->
          </tr>

          <xsl:for-each select="defects/folder">
            <xsl:call-template name="generateSummaryFolder">
              <xsl:with-param name="parentName" select="''"/>
              <xsl:with-param name="tab" select="''"/>
            </xsl:call-template>
          </xsl:for-each>
        </table>


        <a name="_details"/>
        <h1>#defect.Details#</h1>
        <!-- ******************* defect DETAILS *************************** -->
        <!-- Folders -->
        <xsl:for-each select="defects/folder"> <!-- recursive call to display folders -->
          <xsl:if test="count(descendant::defect[@status='10' or @status='20' or @status='30']) > 0">
            <xsl:call-template name="generateDetailsFolder">
              <xsl:with-param name="parentName" select="''"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>

        <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field -->
          <a name="_perpriority"/>
          <h1>#defect.Per_priority#</h1>
          <!-- ******************* defect PER PRIORITY *************************** -->
          <table width="100%">
            <tr>
              <td class="table_data_header">#defect.Defects#</td>
              <td class="table_data_header">#defect.Priority#</td>
              <td class="table_data_header">#defect.Severity#</td>
              <td class="table_data_header">#defect.Status#</td>
            </tr>
            <xsl:for-each select="//defect[@status='10' or @status='20' or @status='30']">
                <xsl:sort select="@priority" data-type="number"/>
  
              <xsl:variable name="defectId"       select="@id" />
              <xsl:variable name="defectName"     select="@name" />
              <xsl:variable name="defectPriority" select="@priority" />
              <xsl:variable name="defectSeverity" select="@severity" />
              <xsl:variable name="defectStatus"   select="@status" />
  
              <!-- defects -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'defect'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    [D_<xsl:value-of select="$defectId" />] <xsl:value-of select="$defectName" />
                  </a>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectPriorityToString"><xsl:with-param name="priority" select="$defectPriority"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectSeverityToString"><xsl:with-param name="severity" select="$defectSeverity"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectStatusToString"><xsl:with-param name="status" select="$defectStatus"/></xsl:call-template>
                </td>
  
              </tr>
            </xsl:for-each>
          </table>
  
  
  
          <a name="_perseverity"/>
          <h1>#defect.Per_severity#</h1>
          <!-- ******************* defect PER SEVERITY *************************** -->
          <table width="100%">
            <tr>
              <td class="table_data_header">#defect.Defects#</td>
              <td class="table_data_header">#defect.Priority#</td>
              <td class="table_data_header">#defect.Severity#</td>
              <td class="table_data_header">#defect.Status#</td>
            </tr>
            <xsl:for-each select="//defect[@status='10' or @status='20' or @status='30']">
                <xsl:sort select="@severity" data-type="number"/>
  
              <xsl:variable name="defectId"       select="@id" />
              <xsl:variable name="defectName"     select="@name" />
              <xsl:variable name="defectPriority" select="@priority" />
              <xsl:variable name="defectSeverity" select="@severity" />
              <xsl:variable name="defectStatus"   select="@status" />
  
              <!-- defects -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'defect'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    [D_<xsl:value-of select="$defectId" />] <xsl:value-of select="$defectName" />
                  </a>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectPriorityToString"><xsl:with-param name="priority" select="$defectPriority"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectSeverityToString"><xsl:with-param name="severity" select="$defectSeverity"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectStatusToString"><xsl:with-param name="status" select="$defectStatus"/></xsl:call-template>
                </td>
  
              </tr>
            </xsl:for-each>
          </table>
  
  
  
  
          <a name="_perstatus"/>
          <h1>#defect.Per_status#</h1>
          <!-- ******************* defect PER STATUS *************************** -->
          <table width="100%">
            <tr>
              <td class="table_data_header">#defect.Defects#</td>
              <td class="table_data_header">#defect.Priority#</td>
              <td class="table_data_header">#defect.Severity#</td>
              <td class="table_data_header">#defect.Status#</td>
            </tr>
            <xsl:for-each select="//defect[@status='10' or @status='20' or @status='30']">
                <xsl:sort select="@status" data-type="number"/>
  
              <xsl:variable name="defectId"       select="@id" />
              <xsl:variable name="defectName"     select="@name" />
              <xsl:variable name="defectPriority" select="@priority" />
              <xsl:variable name="defectSeverity" select="@severity" />
              <xsl:variable name="defectStatus"   select="@status" />
  
              <!-- defects -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'defect'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    [D_<xsl:value-of select="$defectId" />] <xsl:value-of select="$defectName" />
                  </a>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectPriorityToString"><xsl:with-param name="priority" select="$defectPriority"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectSeverityToString"><xsl:with-param name="severity" select="$defectSeverity"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="defectStatusToString"><xsl:with-param name="status" select="$defectStatus"/></xsl:call-template>
                </td>
  
              </tr>
            </xsl:for-each>
          </table>
          <br/><br/><br/><br/>
        </xsl:if>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
      </body>
    </html>

  </xsl:template>









  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />

    <tr>
      <td width="100%" class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::defect[@status='10' or @status='20' or @status='30']"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field -->
        <xsl:call-template name="generate3PriorityTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::defect[@status='10' or @status='20' or @status='30']"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
        <xsl:call-template name="generate5SeverityTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::defect[@status='10' or @status='20' or @status='30']"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
        <xsl:call-template name="generate5StatusOnlyActiveTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::defect[@status='10' or @status='20' or @status='30']"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
      </xsl:if>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>






  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td class="table_data_header">#defect.Defects#</td>
        <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field -->
          <td class="table_data_header">#defect.Priority#</td>
          <td class="table_data_header">#defect.Severity#</td>
          <td class="table_data_header">#defect.Status#</td>
        </xsl:if>
      </tr>
      <xsl:for-each select="defect[@status='10' or @status='20' or @status='30']">
        <xsl:variable name="defectId"       select="@id" />
        <xsl:variable name="defectName"     select="@name" />
        <xsl:variable name="defectPriority" select="@priority" />
        <xsl:variable name="defectSeverity" select="@severity" />
        <xsl:variable name="defectStatus"   select="@status" />

        <!-- defects -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'defect'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [D_<xsl:value-of select="$defectId" />] <xsl:value-of select="$defectName" />
            </a>
          </td>
          <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field -->
            <td class="table_data_subheader">
              <xsl:call-template name="defectPriorityToString"><xsl:with-param name="priority" select="$defectPriority"/></xsl:call-template>
            </td>
            <td class="table_data_subheader">
              <xsl:call-template name="defectSeverityToString"><xsl:with-param name="severity" select="$defectSeverity"/></xsl:call-template>
            </td>
            <td class="table_data_subheader">
              <xsl:call-template name="defectStatusToString"><xsl:with-param name="status" select="$defectStatus"/></xsl:call-template>
            </td>
          </xsl:if>
        </tr>
      </xsl:for-each>
    </table>
    <br/>
  </xsl:template>



  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>
    
    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(defect[@status='10' or @status='20' or @status='30']) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>


      <xsl:call-template name="generateAttachments">
        <xsl:with-param name="parentType" select="'FL_'"/>
        <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
      </xsl:call-template>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>

      <xsl:call-template name="generateOnlyActiveDefectsDetailsFromCurrentLevel">
      </xsl:call-template>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::defect[@status='10' or @status='20' or @status='30']) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobaldefects"            select="count(defects/descendant::defect[@status='10' or @status='20' or @status='30'])"/>

    <xsl:variable name="nbGlobaldefectsNew"         select="count(defects/descendant::defect[@status='10'])"/>
    <xsl:variable name="nbGlobaldefectsAssigned"    select="count(defects/descendant::defect[@status='20'])"/>
    <xsl:variable name="nbGlobaldefectsAck"         select="count(defects/descendant::defect[@status='30'])"/>
    <!--
    <xsl:variable name="nbGlobaldefectsResolved"    select="count(defects/descendant::defect[@status='40'])"/>
    <xsl:variable name="nbGlobaldefectsClosed"      select="count(defects/descendant::defect[@status='50'])"/>
    -->

    <xsl:variable name="nbGlobaldefectsHigh"        select="count(defects/descendant::defect[@priority='10'])"/>
    <xsl:variable name="nbGlobaldefectsNormal"      select="count(defects/descendant::defect[@priority='20'])"/>
    <xsl:variable name="nbGlobaldefectsLow"         select="count(defects/descendant::defect[@priority='30'])"/>

    <xsl:variable name="nbGlobaldefectsBlocking"    select="count(defects/descendant::defect[@severity='10'])"/>
    <xsl:variable name="nbGlobaldefectsMajor"       select="count(defects/descendant::defect[@severity='20'])"/>
    <xsl:variable name="nbGlobaldefectsMinor"       select="count(defects/descendant::defect[@severity='30'])"/>
    <xsl:variable name="nbGlobaldefectsCosmetic"    select="count(defects/descendant::defect[@severity='40'])"/>
    <xsl:variable name="nbGlobaldefectsEnhancement" select="count(defects/descendant::defect[@severity='50'])"/>

    <xsl:if test="$nbGlobaldefects != 0">
      <table>
        <tr>
          <td class="table_label">#defect.Nb_defects#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefects"/></td>
        </tr>
      </table>
      <br/>
      <xsl:if test="$bugtrackingType = 1">  <!-- only bug type that have type field -->
        <table>
          <tr>
            <td valign="top">
              <table>
                  <tr><td colspan="2" class="table_label"><u>#defect.Priority#:</u></td></tr>
                  <tr>
                    <td class="table_label">#defect.priority.High#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsHigh"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.priority.Normal#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsNormal"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.priority.Low#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsLow"/></td>
                  </tr>
              </table>
            </td>
            <td width="50px">&#160;</td>
            <td valign="top">
              <table>
                  <tr><td colspan="2" class="table_label"><u>#defect.Severity#:</u></td></tr>
                  <tr>
                    <td class="table_label">#defect.severity.Blocking#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsBlocking"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.severity.Major#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsMajor"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.severity.Minor#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsMinor"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.severity.Cosmetic#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsCosmetic"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.severity.Enhancement#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsEnhancement"/></td>
                  </tr>
              </table>
            </td>
            <td width="50px">&#160;</td>
            <td valign="top">
              <table>
                  <tr><td colspan="2" class="table_label"><u>#defect.Status#:</u></td></tr>
                  <tr>
                    <td class="table_label">#defect.status.New#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsNew"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.status.Assigned#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsAssigned"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.status.Acknowledged#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsAck"/></td>
                  </tr>
                  <!--
                  <tr>
                    <td class="table_label">#defect.status.Resolved#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsResolved"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#defect.status.Closed#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobaldefectsClosed"/></td>
                  </tr>
                  -->
              </table>
            </td>
          </tr>
        </table>
      </xsl:if>
    </xsl:if>
    <xsl:if test="$nbGlobaldefects = 0">
      <h3>no defect available</h3>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbdefects"   select="count(descendant-or-self::defect[@status='10' or @status='20' or @status='30'])"/>

    <xsl:if test="$nbdefects != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbdefects"/></td>
    </xsl:if>
    <xsl:if test="$nbdefects = 0">
      <td class="table_data_content"></td>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>