<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" indent="yes" encoding="UTF-8"/>
  
  <!-- 
  generate something like: 
  <a href="http://192.168.10.1:8080/XSTUDIO/bin/xstudio.php?id=T_1234">http://192.168.10.1:8080/XSTUDIO/bin/xstudio.php?id=T_1234</a>
  -->
  <xsl:template name="urlToObject">
      <xsl:param name="globalId"/>
      <xsl:param name="name"/>
      
      <xsl:variable name="codebase" select="$codebase" /> <!-- variable inherited from the original template -->

      <xsl:if test="$codebase!='null'">
        <a>
          <xsl:attribute name="href">
            <xsl:value-of select="concat($codebase, 'bin/xstudio.php?id=', $globalId)" />
          </xsl:attribute>
          <xsl:value-of select="concat($codebase, 'bin/xstudio.php?id=', $globalId)" />
        </a>
      </xsl:if>
      <xsl:if test="$codebase='null'">-</xsl:if>      
  </xsl:template>
    
  <xsl:template name="defectPriorityToString">
    <xsl:param name="priority"/>
    <xsl:if test="$priority='10'"><span class="text_red">High</span></xsl:if>
    <xsl:if test="$priority='20'"><span class="text_blue">Normal</span></xsl:if>
    <xsl:if test="$priority='30'"><span class="text_grey">Low</span></xsl:if>
  </xsl:template>

  <xsl:template name="defectSeverityToString">
    <xsl:param name="severity"/>
    <xsl:if test="$severity='10'"><span class="text_red">Blocking</span></xsl:if>
    <xsl:if test="$severity='20'"><span class="text_orange">Major</span></xsl:if>
    <xsl:if test="$severity='30'"><span class="text_blue">Minor</span></xsl:if>
    <xsl:if test="$severity='40'"><span class="text_green">Cosmetic</span></xsl:if>
    <xsl:if test="$severity='50'"><span class="text_grey">Enhancement</span></xsl:if>
  </xsl:template>

  <xsl:template name="defectStatusToString">
    <xsl:param name="status"/>
    <xsl:if test="$status='10'"><span class="text_red">New</span></xsl:if>
    <xsl:if test="$status='20'"><span class="text_orange">Assigned</span></xsl:if>
    <xsl:if test="$status='30'"><span class="text_blue">Acknowledged</span></xsl:if>
    <xsl:if test="$status='40'"><span class="text_green">Resolved</span></xsl:if>
    <xsl:if test="$status='50'"><span class="text_grey">Closed</span></xsl:if>
  </xsl:template>

  <xsl:template name="defectReproducibilityToString">
    <xsl:param name="reproducibility"/>
    <xsl:if test="$reproducibility='10'">Always</xsl:if>
    <xsl:if test="$reproducibility='20'">Random</xsl:if>
    <xsl:if test="$reproducibility='30'">Once</xsl:if>
  </xsl:template>

  <xsl:template name="defectFixTypeToString">
    <xsl:param name="fixType"/>
    <xsl:if test="$fixType='10'">Resolved</xsl:if>
    <xsl:if test="$fixType='20'">Unable to reproduce</xsl:if>
    <xsl:if test="$fixType='30'">No change required</xsl:if>
    <xsl:if test="$fixType='40'">Duplicate</xsl:if>
  </xsl:template>
  
  <xsl:template name="resultToString">
    <xsl:param name="result"/>
    <xsl:if test="$result='0'"><span class="text_grey">Not executed</span></xsl:if>
    <xsl:if test="$result='1'"><span class="text_green">Success</span></xsl:if>
    <xsl:if test="$result='2'"><span class="text_red">Failure</span></xsl:if>
    <xsl:if test="$result='3'"><span class="text_blue">Relative</span></xsl:if>
  </xsl:template>

  <xsl:template name="insertCustomFields"> 
    <xsl:for-each select="properties/customField">
      <xsl:sort select="@position" data-type="number"/>
  
      <xsl:variable name="customFieldType"      select="@type" />
      <xsl:variable name="customFieldName"      select="@name" />
      <xsl:variable name="customFieldMandatory" select="@mandatory" />
      <xsl:variable name="customFieldValue"     select="@value" />
      <xsl:if test="$customFieldType='html'">
        <xsl:variable name="customFieldValue"   select="." />
      </xsl:if>
    
      <tr>
        <td class="table_data_subheader"><xsl:value-of select="$customFieldName" />:</td>
        <td class="table_data_content">
          <xsl:if test="$customFieldType='html'">
            <xsl:value-of disable-output-escaping="yes" select="." />
          </xsl:if>
          <xsl:if test="$customFieldType!='html'">
            <xsl:value-of select="@value" />
          </xsl:if>
        </td>
      </tr>

    </xsl:for-each>     
  </xsl:template>
    
</xsl:stylesheet>
