<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="reports/@codebase" />
  <xsl:variable name="bugtrackingType" select="reports/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="reports/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="reports/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/reportHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    
	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="nbCategory"            select="count(reports/campaignsession/category[count(descendant-or-self::test)>0])" />
        <xsl:variable name="graphInReportsEnabled" select="reports/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="reports/@date" />
        <xsl:variable name="documentAuthor"        select="reports/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
              <td valign="top" align="right">
                <table>
                  <tr><td class="table_label" align="right">#report.Start_date#:</td><td class="table_value" align="left"><xsl:value-of disable-output-escaping="yes" select="reports/campaignsession/@start_date"/></td></tr>
                  <tr><td class="table_label" align="right">#report.Stop_date#:</td><td class="table_value" align="left"><xsl:value-of disable-output-escaping="yes" select="reports/campaignsession/@stop_date"/></td></tr>
                </table>
              </td>
            </tr>
          </table>
          <br/>

          <span class="report_title">#report.Campaign_session_report#</span><br/>
          <span class="report_subtitle">Complete With Statistics - <xsl:value-of disable-output-escaping="yes" select="reports/campaignsession/@name"/></span><br/>
          <span class="report_subtitle">Execution Order</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_introduction">#report.Introduction#</a><br/>
          <a class="report_table_of_content" href="#_conf">#report.Configuration#</a><br/>
          <a class="report_table_of_content" href="#_summary">#report.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#report.Details#</a><br/>
          <a class="report_table_of_content" href="#_defects">#report.Defects#</a><br/>
          <a class="report_table_of_content" href="#_conclusion">#report.Conclusion#</a><br/>
          <a class="report_table_of_content" href="#_tbd">#report.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#report.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <xsl:for-each select="reports/campaignsession">

          <a name="_introduction"/>
          <h1>#report.Introduction#</h1>
          <p><xsl:value-of disable-output-escaping="yes" select="introduction"/></p>

          <!-- Attachments -->
          <xsl:call-template name="generateAttachments">
            <xsl:with-param name="parentType"     select="'CS_'"/>
            <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
          </xsl:call-template>

          <a name="_conf"/>
          <h1>#report.Configuration#</h1>
          <table border="0">
            <tr>
                <td class="table_data_subsubheader">#report.Sut#</td>
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="sut/@name"/>&#160;<xsl:value-of disable-output-escaping="yes" select="sut/@version"/></td>
            </tr>
            <tr>
                <td class="table_data_subsubheader">#report.Operator#</td>
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="operator/@name"/></td>
            </tr>
            <tr>
                <td class="table_data_subsubheader">#report.Agent#</td>
                <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="agent/@name"/>&#160;<xsl:value-of disable-output-escaping="yes" select="agent/@os"/></td>
            </tr>
          </table>

          <xsl:for-each select="configurations/configuration">
            <h2><xsl:value-of select="@categoryName" /> (<xsl:value-of select="@jarName" />: <xsl:value-of select="@name" />)</h2>
            <xsl:for-each select="object[@type='root']/form">
              <table border="0" width="100%">
                <tr>
                  <td colspan="2" class="table_data_subheader"><xsl:value-of select="@name" /></td>
                </tr>
                <xsl:call-template name="conf"/>
              </table>
              <br/>
            </xsl:for-each>
          </xsl:for-each>


          <a name="_summary"/>
          <h1>#report.Summary#</h1>
        <xsl:call-template name="insertCharts">
          <xsl:with-param name="graphInReportsEnabled" select="$graphInReportsEnabled"/>
        </xsl:call-template>


        <table width="100%">
          <!-- ******************* tests SUMMARY *************************** -->
          <xsl:if test="$nbCategory > 0">
            <tr>
              <td rowspan="2" class="table_data_header" width="90%">#report.Category#</td>
              <td rowspan="2" class="table_data_header">#report.Nb_tests#</td>
              <td rowspan="2" class="table_data_header">#report.Nb_testcases#</td>
              <td colspan="3" class="table_data_header">#report.Tests#</td>
              <td colspan="4" class="table_data_header">#report.Testcases#</td>
            </tr>
            <tr>
              <td class="table_data_header">#report.Nb_success#</td> <!-- test -->
              <td class="table_data_header">#report.Nb_failure#</td>
              <td class="table_data_header">#report.Nb_unknown#</td>
              <td class="table_data_header">#report.Nb_success#</td> <!-- testcase -->
              <td class="table_data_header">#report.Nb_failure#</td>
              <td class="table_data_header">#report.Nb_not_executed#</td>
              <td class="table_data_header">#report.Nb_relative#</td>
            </tr>

            <xsl:for-each select="category[count(descendant-or-self::test)>0]">
              <xsl:variable name="categoryName" select="@name" />

              <!-- Categories -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'category'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:value-of select="$categoryName" />
                  </a>
                </td>
                <xsl:call-template name="generateNbTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
                <xsl:call-template name="generateNbTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
                <xsl:call-template name="generateTestResultTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
                <xsl:call-template name="generateTestcaseResultTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
              </tr>

              <!-- Folders -->
              <xsl:for-each select="folder"> <!-- recursive call to display folders -->
                <xsl:call-template name="generateSummaryFolder">
                  <xsl:with-param name="parentName" select="$categoryName"/>
                  <xsl:with-param name="tab" select="''"/>
                </xsl:call-template>
              </xsl:for-each>

            </xsl:for-each>
          </xsl:if>
        </table>




          <a name="_details"/>
          <h1>#report.Details#</h1>
          <!-- ******************* tests DETAILS *************************** -->
          <xsl:if test="$nbCategory > 0">
            <xsl:for-each select="category[count(descendant-or-self::test)>0]">
              <xsl:variable name="categoryName" select="@name" />
              <xsl:variable name="nbTestsInThisCategory" select="count(descendant::test)" />

              <!-- Categories -->
              <a>
                <xsl:attribute name="name">
                  <xsl:call-template name="generateUniqueId">
                    <xsl:with-param name="type" select="'category'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
              </a>
              <h2>
                <img src="#images#/IconCategory.gif"/>&#160;
                <xsl:value-of disable-output-escaping="yes" select="$categoryName" />&#160;
              </h2>

              <!-- Attachments -->
              <xsl:call-template name="generateAttachments">
                <xsl:with-param name="parentType"     select="'CT_'"/>
                <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
              </xsl:call-template>

              <!-- Tests -->
              <xsl:for-each select="descendant::test">
                  <xsl:sort select="@position" data-type="number"/>
                  <xsl:call-template name="generateTestsExecutionDetails"/>
              </xsl:for-each>

            </xsl:for-each>
          </xsl:if>

          <a name="_defects"/>
          <h1>#report.Defects#</h1>


          <xsl:variable name="nbDefects" select="count(descendant::defect)" />
          <xsl:if test="$nbDefects > 0">
            <!-- ******************* DEFECTS *************************** -->

            <!--
            A defect can be associated to several tests.
            How to return unique nodes?
            The method is a simplified version of the so-called Muenchian method.
            The idea is that the xsl:key returns node sets that match each unique
            value of the key, in this case the defect.
            -->
            <xsl:key name='defectKey' match='defect' use='@id'/>

            <!--
            Then, we do a for-each, but only on those nodes that match the first
            node returned by the unique keys.
            -->
            <xsl:call-template name="generateDefectsDetails">
			      <xsl:with-param name="nodeSet" select="descendant::defect[generate-id()=generate-id(key('defectKey',@id)[1])]"/>
			      <br/>
    		</xsl:call-template>
          </xsl:if>
          <xsl:if test="$nbDefects = 0">
             #defect.No_defect_available#
          </xsl:if>

          <a name="_conclusion"/>
          <h1>#report.Conclusion#</h1>
          <p><xsl:value-of disable-output-escaping="yes" select="conclusion"/></p>

        </xsl:for-each>
      </body>
        <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
    </html>

  </xsl:template>




  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />

    <tr>
      <td class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateTestResultTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateTestcaseResultTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td rowspan="2" class="table_data_header">#report.Tests#</td>
        <td rowspan="2" class="table_data_header">#report.Nb_testcases#</td>
        <td rowspan="2" class="table_data_header">#report.Result#</td>
        <td colspan="4" class="table_data_header">#report.Testcases#</td>
      </tr>
      <tr>
        <td class="table_data_header">#report.Nb_success#</td>
        <td class="table_data_header">#report.Nb_failure#</td>
        <td class="table_data_header">#report.Nb_not_executed#</td>
        <td class="table_data_header">#report.Nb_relative#</td>
      </tr>
      <xsl:for-each select="test">
        <xsl:variable name="testId"       select="@id" />
        <xsl:variable name="testName"     select="@name" />
        <xsl:variable name="nbTestcases"  select="count(testcase)" />
        <xsl:variable name="testStatus"   select="@status" />

        <!-- tests -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'test'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [T_<xsl:value-of select="$testId" />] <xsl:value-of select="$testName" />
            </a>
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$nbTestcases" />
          </td>
          <td class="table_data_subheader">
            <b><xsl:call-template name="statusToIconAndString"><xsl:with-param name="status" select="$testStatus"/></xsl:call-template></b>
          </td>
          <xsl:call-template name="generateTestcaseResultTd">
            <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
            <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
          </xsl:call-template>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>


  <xsl:template name="generateTestsExecutionDetails">
      <xsl:variable name="testId" select="@id" />
      <xsl:variable name="testName" select="@name" />
      <xsl:variable name="testStatus" select="@status" />
      <xsl:variable name="testPosition" select="@position" />

      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'test'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>

      <h2>
        <img src="#images#/IconTest.gif"/>&#160;(<xsl:value-of select="$testPosition" />)&#160;
        [T_<xsl:value-of select="$testId" />] <xsl:value-of disable-output-escaping="yes" select="$testName" />&#160;
        <xsl:call-template name="statusToIcon">
          <xsl:with-param name="status" select="$testStatus"/>
        </xsl:call-template>
      </h2>

      <table border="0" cellpading="0" cellspacing="0">
        <tr><td valign="top"><xsl:call-template name="testcaseDetailsStats"/></td></tr>
      </table>
      <br/>


      <table border="0" width="100%">
        <tr>
          <td class="table_data_subheader">#report.Index#</td>
          <td class="table_data_subheader">#report.Name#</td>
          <td class="table_data_subheader">#report.Message#</td>
          <td class="table_data_subheader">#report.Result#</td>
        </tr>

        <!-- ******************* TESTCASES *************************** -->
        <xsl:for-each select="testcase">
          <!--<xsl:sort select="@index" />-->

          <xsl:variable name="testcaseId"      select="@id" />
          <xsl:variable name="testcaseIndex"   select="@index" />
          <xsl:variable name="testcaseName"    select="@name" />
          <xsl:variable name="testcaseStatus"  select="@status" />

          <tr>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$testcaseIndex" /></td>

            <td class="table_data_content">
              <h3 class="no_margin">
                [TC_<xsl:value-of disable-output-escaping="yes" select="$testcaseId" />] <xsl:value-of disable-output-escaping="yes" select="$testcaseName" />
              </h3>
            </td>

            <td class="table_data_content">
               <xsl:call-template name="testcaseMessage"/>
               <br/>
              <!-- Attachments -->
              <xsl:call-template name="generateAttachments">
                <xsl:with-param name="parentType"     select="'TC_'"/>
                <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
              </xsl:call-template>
            </td>

            <td class="table_data_content" width="100px">
              <xsl:call-template name="statusToIconAndString">
                <xsl:with-param name="status" select="$testcaseStatus"/>
              </xsl:call-template>
            </td>
          </tr>
        </xsl:for-each> <!-- testcases -->
      </table>
      <br/>

      <xsl:variable name="nbDefects" select="count(defect)" />
      <xsl:if test="$nbDefects > 0">
          <!-- ******************* DEFECTS *************************** -->
          <table width="100%">
            <xsl:call-template name="generateShortDefectHeader">
            </xsl:call-template>
            <xsl:for-each select="defect">
               <xsl:call-template name="generateShortDefect">
              </xsl:call-template>
            </xsl:for-each>
          </table>
      </xsl:if>
      <!--
      <xsl:if test="$nbDefects = 0">
         #defect.No_defect_available#
      </xsl:if>
      -->
  </xsl:template>

</xsl:stylesheet>