<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="requirements/@codebase" />
  <xsl:variable name="bugtrackingType" select="requirements/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="requirements/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="requirements/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/requirementHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    
	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="domain"                select="requirements/@domain" />
        <xsl:variable name="graphInReportsEnabled" select="requirements/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="requirements/@date" />
        <xsl:variable name="documentAuthor"        select="requirements/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$domain = 1">
            <span class="report_title">#requirement.Complete_Requirement#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 3">
            <span class="report_title">#requirement.Folder_Requirement#</span><br/>
          </xsl:if>
          <span class="report_subtitle">Complete With Statistics</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_metrics">#requirement.Metrics#</a><br/>
          <a class="report_table_of_content" href="#_summary">#requirement.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#requirement.Details#</a><br/>
          <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->   
            <a class="report_table_of_content" href="#_pertype">#requirement.Per_type#</a><br/>
            <a class="report_table_of_content" href="#_perpriority">#requirement.Per_priority#</a><br/>
            <a class="report_table_of_content" href="#_perstatus">#requirement.Per_status#</a><br/>
          </xsl:if>
          <a class="report_table_of_content" href="#_matrix">#requirement.Traceability_Matrix#</a><br/>
          <a class="report_table_of_content" href="#_tbd">#requirement.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#requirement.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <a name="_metrics"/>
        <h1>#requirement.Metrics#</h1>
        <xsl:call-template name="generateGlobalMetrics"/>


        <a name="_summary"/>
        <h1>#requirement.Summary#</h1>
        <xsl:call-template name="insertCharts">
          <xsl:with-param name="graphInReportsEnabled" select="$graphInReportsEnabled"/>
          <xsl:with-param name="domain" select="$domain"/>
        </xsl:call-template>

        	        
        <table width="100%">
          <!-- ******************* requirement SUMMARY *************************** -->
          <tr>
            <td class="table_data_header" width="90%">#requirement.Folder#</td>
            <td class="table_data_header">#requirement.Nb_requirements#</td>
            <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->   
              <td class="table_data_header">#requirement.status.New#</td>
              <td class="table_data_header">#requirement.status.Acknowledged#</td>
              <td class="table_data_header">#requirement.status.Approved#</td>
              <td class="table_data_header">#requirement.priority.High#</td>
              <td class="table_data_header">#requirement.priority.Normal#</td>
              <td class="table_data_header">#requirement.priority.Low#</td>
            </xsl:if>
          </tr>

          <xsl:for-each select="requirements/folder">
            <xsl:call-template name="generateSummaryFolder">
              <xsl:with-param name="parentName" select="''"/>
              <xsl:with-param name="tab" select="''"/>
            </xsl:call-template>
          </xsl:for-each>
        </table>




        <a name="_details"/>
        <h1>#requirement.Details#</h1>
        <!-- ******************* requirement DETAILS *************************** -->
        <!-- Folders -->
        <xsl:for-each select="requirements/folder"> <!-- recursive call to display folders -->
          <xsl:if test="count(descendant::requirement) > 0">
            <xsl:call-template name="generateDetailsFolder">
              <xsl:with-param name="parentName" select="''"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>



        <!-- REQUIREMENT_TYPE_INTEGRATED -->
        <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->    
          <a name="_pertype"/>
          <h1>#requirement.Per_type#</h1>
          <!-- ******************* requirement PER TYPE *************************** -->
          <table width="100%">
            <tr>
              <td class="table_data_header">#requirement.Requirements#</td>
              <td class="table_data_header">#requirement.Type#</td>
              <td class="table_data_header">#requirement.Priority#</td>
              <td class="table_data_header">#requirement.Status#</td>
            </tr>
  
            <xsl:for-each select="//requirement">
              <xsl:sort select="@type" data-type="number"/>
  
              <xsl:variable name="requirementId"       select="@id" />
              <xsl:variable name="requirementName"     select="@name" />
              <xsl:variable name="requirementType"     select="@type" />
              <xsl:variable name="requirementPriority" select="@priority" />
              <xsl:variable name="requirementStatus"   select="@status" />
  
              <!-- requirements -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'requirement'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    [R_<xsl:value-of select="$requirementId" />] <xsl:value-of select="$requirementName" />
                  </a>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="requirementTypeToString"><xsl:with-param name="type" select="$requirementType"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="requirementPriorityToString"><xsl:with-param name="priority" select="$requirementPriority"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="requirementStatusToString"><xsl:with-param name="status" select="$requirementStatus"/></xsl:call-template>
                </td>
              </tr>
            </xsl:for-each>
          </table>
        </xsl:if> <!-- Integrated -->




        <!-- REQUIREMENT_TYPE_INTEGRATED -->
        <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->    
        <a name="_perpriority"/>
        <h1>#requirement.Per_priority#</h1>
        <!-- ******************* requirement PER PRIORITY *************************** -->
        <table width="100%">
          <tr>
            <td class="table_data_header">#requirement.Requirements#</td>
            <td class="table_data_header">#requirement.Type#</td>
            <td class="table_data_header">#requirement.Priority#</td>
            <td class="table_data_header">#requirement.Status#</td>
          </tr>
          <xsl:for-each select="//requirement">
              <xsl:sort select="@priority" data-type="number"/>

            <xsl:variable name="requirementId"       select="@id" />
            <xsl:variable name="requirementName"     select="@name" />
            <xsl:variable name="requirementType"     select="@type" />
            <xsl:variable name="requirementPriority" select="@priority" />
            <xsl:variable name="requirementStatus"   select="@status" />

            <!-- requirements -->
            <tr>
              <td class="table_data_subheader">
                <!-- anchor link -->
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="generateSharpUniqueId">
                      <xsl:with-param name="type" select="'requirement'"/>
                      <xsl:with-param name="id" select="@id"/>
                    </xsl:call-template>
                  </xsl:attribute>
                  [R_<xsl:value-of select="$requirementId" />] <xsl:value-of select="$requirementName" />
                </a>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementTypeToString"><xsl:with-param name="type" select="$requirementType"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementPriorityToString"><xsl:with-param name="priority" select="$requirementPriority"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementStatusToString"><xsl:with-param name="status" select="$requirementStatus"/></xsl:call-template>
              </td>

            </tr>
          </xsl:for-each>
        </table>
        </xsl:if> <!-- Integrated -->




        <!-- REQUIREMENT_TYPE_INTEGRATED -->
        <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->    
        <a name="_perstatus"/>
        <h1>#requirement.Per_status#</h1>
        <!-- ******************* requirement PER STATUS *************************** -->
        <table width="100%">
          <tr>
            <td class="table_data_header">#requirement.Requirements#</td>
            <td class="table_data_header">#requirement.Type#</td>
            <td class="table_data_header">#requirement.Priority#</td>
            <td class="table_data_header">#requirement.Status#</td>
          </tr>
          <xsl:for-each select="//requirement">
              <xsl:sort select="@status" data-type="number"/>

            <xsl:variable name="requirementId"       select="@id" />
            <xsl:variable name="requirementName"     select="@name" />
            <xsl:variable name="requirementType"     select="@type" />
            <xsl:variable name="requirementPriority" select="@priority" />
            <xsl:variable name="requirementStatus"   select="@status" />

            <!-- requirements -->
            <tr>
              <td class="table_data_subheader">
                <!-- anchor link -->
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="generateSharpUniqueId">
                      <xsl:with-param name="type" select="'requirement'"/>
                      <xsl:with-param name="id" select="@id"/>
                    </xsl:call-template>
                  </xsl:attribute>
                  [R_<xsl:value-of select="$requirementId" />] <xsl:value-of select="$requirementName" />
                </a>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementTypeToString"><xsl:with-param name="type" select="$requirementType"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementPriorityToString"><xsl:with-param name="priority" select="$requirementPriority"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementStatusToString"><xsl:with-param name="status" select="$requirementStatus"/></xsl:call-template>
              </td>
            </tr>
          </xsl:for-each>
        </table>
        </xsl:if> <!-- Integrated -->




        <a name="_matrix"/>
        <h1>#requirement.Traceability_Matrix#</h1>
        <!-- ******************* requirement TRACEABILITY MATRIX *************************** -->
        <table width="100%">
          <tr>
            <td class="table_data_header">#requirement.Requirements#</td>
            <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->   
              <td class="table_data_header">#requirement.Type#</td>
              <td class="table_data_header">#requirement.Priority#</td>
              <td class="table_data_header">#requirement.Status#</td> 
            </xsl:if>
            <xsl:if test="$specificationInLifecycle = 'true'">
              <td class="table_data_header">#requirement.Specifications#</td>
            </xsl:if>
            <xsl:if test="$specificationInLifecycle = 'false'">
              <td class="table_data_header">#requirement.Tests#</td>
            </xsl:if>
          </tr>
          <xsl:for-each select="//requirement">
            <xsl:sort select="@id" data-type="number"/>

            <xsl:variable name="requirementId"       select="@id" />
            <xsl:variable name="requirementName"     select="@name" />
            <xsl:variable name="requirementType"     select="@type" />
            <xsl:variable name="requirementPriority" select="@priority" />
            <xsl:variable name="requirementStatus"   select="@status" />

            <!-- requirements -->
            <tr>
              <td class="table_data_subheader">
                <!-- anchor link -->
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="generateSharpUniqueId">
                      <xsl:with-param name="type" select="'requirement'"/>
                      <xsl:with-param name="id" select="@id"/>
                    </xsl:call-template>
                  </xsl:attribute>
                  <xsl:if test="$requirementTrackingType = 1">  
                    [R_<xsl:value-of select="$requirementId" />] <xsl:value-of select="$requirementName" />
                  </xsl:if>
                  <xsl:if test="$requirementTrackingType != 1">  <!-- external id -->  
                    <xsl:value-of select="$requirementId" /> <xsl:value-of select="$requirementName" />
                  </xsl:if>
                </a>
              </td>
              <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->   
                <td class="table_data_subheader">
                  <xsl:call-template name="requirementTypeToString"><xsl:with-param name="type" select="$requirementType"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="requirementPriorityToString"><xsl:with-param name="priority" select="$requirementPriority"/></xsl:call-template>
                </td>
                <td class="table_data_subheader">
                  <xsl:call-template name="requirementStatusToString"><xsl:with-param name="status" select="$requirementStatus"/></xsl:call-template>
                </td>
              </xsl:if>
              
              <xsl:if test="$specificationInLifecycle = 'true'">
                <xsl:call-template name="generateListOfUniqueIds">
                  <xsl:with-param name="nodeSet" select="specification"/>
                  <xsl:with-param name="prefix" select="'S_'"/>
                </xsl:call-template>
              </xsl:if>
              <xsl:if test="$specificationInLifecycle = 'false'">
                <xsl:call-template name="generateListOfUniqueIds">
                  <xsl:with-param name="nodeSet" select="test"/>
                  <xsl:with-param name="prefix" select="'T_'"/>
                </xsl:call-template>
              </xsl:if>
              
            </tr>
          </xsl:for-each>
        </table>
        <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
      </body>
    </html>

  </xsl:template>









  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />
    <tr>
      <td class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::requirement"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->  
        <xsl:call-template name="generate3StatusTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::requirement"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
        <xsl:call-template name="generate3PriorityTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::requirement"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
      </xsl:if>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
    
      <!-- REQUIREMENT_TYPE_INTEGRATED -->
      <xsl:if test="$requirementTrackingType = 1"> 
        <tr>
          <td class="table_data_header">#requirement.Requirements#</td>
          <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->  
            <td class="table_data_header">#requirement.Type#</td>
            <td class="table_data_header">#requirement.Priority#</td>
            <td class="table_data_header">#requirement.Status#</td>
          </xsl:if>
        </tr>
        <xsl:for-each select="requirement">
          <xsl:variable name="requirementId"       select="@id" />
          <xsl:variable name="requirementName"     select="@name" />
          <xsl:variable name="requirementType"     select="@type" />
          <xsl:variable name="requirementPriority" select="@priority" />
          <xsl:variable name="requirementStatus"   select="@status" />
  
          <!-- requirements -->
          <tr>
            <td class="table_data_subheader">
              <!-- anchor link -->
              <a>
                <xsl:attribute name="href">
                  <xsl:call-template name="generateSharpUniqueId">
                    <xsl:with-param name="type" select="'requirement'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
                [R_<xsl:value-of select="$requirementId" />] <xsl:value-of select="$requirementName" />
              </a>
            </td>
            <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->  
              <td class="table_data_subheader">
                <xsl:call-template name="requirementTypeToString"><xsl:with-param name="type" select="$requirementType"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementPriorityToString"><xsl:with-param name="priority" select="$requirementPriority"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="requirementStatusToString"><xsl:with-param name="status" select="$requirementStatus"/></xsl:call-template>
              </td>
            </xsl:if>
          </tr>
        </xsl:for-each>          
      </xsl:if>
      
      <!-- REQUIREMENT_TYPE_GENERIC -->
      <!-- REQUIREMENT_TYPE_JIRA -->
      <xsl:if test="$requirementTrackingType = 2 or $requirementTrackingType = 6">
        <tr>
          <td class="table_data_header">#requirement.Requirements#</td>
          <td class="table_data_header">#requirement.Link#</td>
        </tr>
        <xsl:for-each select="requirement">
          <xsl:variable name="requirementId"  select="@id" />
          <xsl:variable name="requirementUrl" select="@url" />

          <!-- requirements -->
          <tr>
            <td class="table_data_subheader">
              <!-- anchor link -->
              <a>
                <xsl:attribute name="href">
                  <xsl:call-template name="generateSharpUniqueId">
                    <xsl:with-param name="type" select="'requirement'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
                <xsl:value-of select="$requirementId" />
              </a>
            </td>
            <td class="table_data_subheader">
              <!-- anchor link -->
              <a>
                <xsl:attribute name="href">
                  <xsl:value-of select="$requirementUrl" />
                </xsl:attribute>
                <xsl:value-of select="$requirementUrl" />
              </a>
            </td>
          </tr>
        </xsl:for-each>      
      </xsl:if>
    </table>
  </xsl:template>



  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(requirement) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateAttachments">
        <xsl:with-param name="parentType" select="'FL_'"/>
        <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
      </xsl:call-template>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>

      <!-- REQUIREMENT_TYPE_INTEGRATED -->
      <xsl:if test="$requirementTrackingType = 1">
        <xsl:call-template name="generateRequirementsDetailsFromCurrentLevel"/>    
      </xsl:if>
      
      <!-- REQUIREMENT_TYPE_GENERIC -->
      <!-- REQUIREMENT_TYPE_JIRA -->
      <xsl:if test="$requirementTrackingType = 2 or $requirementTrackingType = 6">
        <!-- DO NOTHING: there is no additional details to show -->
      </xsl:if>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::requirement) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobalrequirements"          select="count(requirements/descendant::requirement)"/>

    <xsl:variable name="nbGlobalrequirementsNew"       select="count(requirements/descendant::requirement[@status='10'])"/>
    <xsl:variable name="nbGlobalrequirementsAck"       select="count(requirements/descendant::requirement[@status='20'])"/>
    <xsl:variable name="nbGlobalrequirementsApproved"  select="count(requirements/descendant::requirement[@status='30'])"/>

    <xsl:variable name="nbGlobalrequirementsHigh"      select="count(requirements/descendant::requirement[@priority='10'])"/>
    <xsl:variable name="nbGlobalrequirementsNormal"    select="count(requirements/descendant::requirement[@priority='20'])"/>
    <xsl:variable name="nbGlobalrequirementsLow"       select="count(requirements/descendant::requirement[@priority='30'])"/>

    <xsl:if test="$nbGlobalrequirements != 0">
      <table>
        <tr>
          <td class="table_label">#requirement.Nb_requirements#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirements"/></td>
        </tr>
      </table>
      <br/>
      <xsl:if test="$requirementTrackingType = 1">  <!-- only requirement type that have type field -->   
        <table>
          <tr>
            <td valign="top">
              <table>
                  <tr><td colspan="2" class="table_label"><u>#requirement.Status#:</u></td></tr>
                  <tr>
                    <td class="table_label">#requirement.status.New#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirementsNew"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#requirement.status.Acknowledged#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirementsAck"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#requirement.status.Approved#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirementsApproved"/></td>
                  </tr>
              </table>
            </td>
            <td width="50px">&#160;</td>
            <td valign="top">
              <table>
                  <tr><td colspan="2" class="table_label"><u>#requirement.Priority#:</u></td></tr>
                  <tr>
                    <td class="table_label">#requirement.priority.High#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirementsHigh"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#requirement.priority.Normal#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirementsNormal"/></td>
                  </tr>
                  <tr>
                    <td class="table_label">#requirement.priority.Low#:</td>
                    <td class="table_value" width="8px">&#160;</td>
                    <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalrequirementsLow"/></td>
                  </tr>
              </table>
            </td>
          </tr>
        </table>
      </xsl:if>
    </xsl:if>
    <xsl:if test="$nbGlobalrequirements = 0">
      <h3>no requirement available</h3>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbrequirements"   select="count(descendant-or-self::requirement)"/>

    <xsl:if test="$nbrequirements != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbrequirements"/></td>
    </xsl:if>
    <xsl:if test="$nbrequirements = 0">
      <td class="table_data_content"></td>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>