<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="suts/@codebase" />
  <xsl:variable name="bugtrackingType" select="suts/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="suts/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="suts/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/sutHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    
	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="nbCompany"             select="count(suts/company)" />
        <xsl:variable name="nbFolder"              select="count(suts//folder)" />
        <xsl:variable name="domain"                select="suts/@domain" />
        <xsl:variable name="graphInReportsEnabled" select="suts/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="suts/@date" />
        <xsl:variable name="documentAuthor"        select="suts/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$domain = 1">
            <span class="report_title">#sut.Complete_Sut#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 2">
            <span class="report_title">#sut.Company_Sut#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 3">
            <span class="report_title">#sut.Folder_Sut#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 4">
            <span class="report_title">#sut.Sut_Sut#</span><br/>
          </xsl:if>
          <span class="report_subtitle">Complete With Statistics</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <xsl:if test="$nbFolder > 0">
            <a class="report_table_of_content" href="#_metrics">#sut.Metrics#</a><br/>
            <a class="report_table_of_content" href="#_summary">#sut.Summary#</a><br/>
          </xsl:if>
          <a class="report_table_of_content" href="#_details">#sut.Details#</a><br/>
          <a class="report_table_of_content" href="#_requirements">#sut.Requirements#</a><br/>
          <xsl:if test="$specificationInLifecycle = 'true'">
            <a class="report_table_of_content" href="#_specifications">#sut.Specifications#</a><br/>
          </xsl:if>
          <a class="report_table_of_content" href="#_tests">#sut.Tests#</a><br/>
          <a class="report_table_of_content" href="#_defects">#sut.Defects#</a><br/>
          <a class="report_table_of_content" href="#_tbd">#sut.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#sut.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <xsl:if test="$nbFolder > 0">
          <a name="_metrics"/>
          <h1>#sut.Metrics#</h1>
          <xsl:call-template name="generateGlobalMetrics"/>

          <a name="_summary"/>
          <h1>#sut.Summary#</h1>
          <table width="100%">
            <!-- ******************* sut SUMMARY *************************** -->
            <xsl:if test="$nbCompany > 0">
              <tr>
                <td class="table_data_header" width="90%">#sut.Company#</td>
                <td class="table_data_header">#sut.Nb_suts#</td>
              </tr>

              <xsl:for-each select="suts/company">
                <xsl:variable name="companyName" select="@name" />

                <!-- Categories -->
                <tr>
                  <td class="table_data_subheader">
                    <!-- anchor link -->
                    <a>
                      <xsl:attribute name="href">
                        <xsl:call-template name="generateSharpUniqueId">
                          <xsl:with-param name="type" select="'company'"/>
                          <xsl:with-param name="id" select="@id"/>
                        </xsl:call-template>
                      </xsl:attribute>
                      <xsl:value-of select="$companyName" />
                    </a>
                  </td>
                  <xsl:call-template name="generateNbTd">
                    <xsl:with-param name="nodeSet" select="descendant-or-self::sut"/>
                    <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                  </xsl:call-template>
                </tr>

                <!-- Folders -->
                <xsl:for-each select="folder"> <!-- recursive call to display folders -->
                  <xsl:call-template name="generateSummaryFolder">
                    <xsl:with-param name="parentName" select="$companyName"/>
                    <xsl:with-param name="tab" select="''"/>
                  </xsl:call-template>
                </xsl:for-each>

              </xsl:for-each>
            </xsl:if>

            <xsl:if test="$nbCompany = 0">
              <tr>
                <td class="table_data_header" width="90%">#sut.Folder#</td>
                <td class="table_data_header">#sut.Nb_suts#</td>
              </tr>

              <xsl:for-each select="suts/folder">
                <xsl:call-template name="generateSummaryFolder">
                  <xsl:with-param name="parentName" select="''"/>
                  <xsl:with-param name="tab" select="''"/>
                </xsl:call-template>
              </xsl:for-each>
            </xsl:if>

          </table>
        </xsl:if>

        <a name="_details"/>
        <h1>#sut.Details#</h1>
        <!-- ******************* sut DETAILS *************************** -->
        <xsl:if test="$nbCompany > 0">
          <xsl:for-each select="suts/company">
            <xsl:variable name="companyName" select="@name" />
            <xsl:variable name="nbsutsInThisCompany" select="count(descendant::sut)" />

            <xsl:if test="$nbsutsInThisCompany > 0">
              <!-- Companies -->
              <a>
                <xsl:attribute name="name">
                  <xsl:call-template name="generateUniqueId">
                    <xsl:with-param name="type" select="'company'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
              </a>
              <h2>
                <img src="#images#/IconCompany.gif"/>&#160;
                <xsl:value-of disable-output-escaping="yes" select="$companyName" />&#160;
              </h2>

              <!-- Folders -->
              <xsl:for-each select="folder"> <!-- recursive call to display folders -->
                <xsl:if test="count(descendant::sut) > 0">
                  <xsl:call-template name="generateDetailsFolder">
                    <xsl:with-param name="parentName" select="$companyName"/>
                  </xsl:call-template>
                </xsl:if>
              </xsl:for-each>
            </xsl:if>
          </xsl:for-each>
        </xsl:if>
        <xsl:if test="$nbCompany = 0 and $nbFolder > 0">
          <!-- Folders -->
          <xsl:for-each select="suts/folder"> <!-- recursive call to display folders -->
            <xsl:if test="count(descendant::sut) > 0">
              <xsl:call-template name="generateDetailsFolder">
                <xsl:with-param name="parentName" select="''"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:for-each>
        </xsl:if>
        <xsl:if test="$nbFolder = 0">
          <xsl:for-each select="suts">
            <xsl:call-template name="generateSutsDetailsFromCurrentLevel"/>
          </xsl:for-each>
        </xsl:if>


        <a name="_requirements"/>
        <h1>#sut.Requirements#</h1>
        <!-- ******************* ALL REQUIREMENTS ************************** -->
        <xsl:call-template name="generateUniqueRequirementsDetailsFromAllLevels"/>

        <xsl:if test="$specificationInLifecycle = 'true'">
          <a name="_specifications"/>
          <h1>#sut.Specifications#</h1>
          <!-- ******************* ALL SPECIFICATIONS ************************ -->
          <xsl:call-template name="generateUniqueSpecificationsDetailsFromAllLevels"/>
        </xsl:if>

        <a name="_tests"/>
        <h1>#sut.Tests#</h1>
        <!-- *********************** ALL TESTS ***************************** -->
        <xsl:call-template name="generateUniqueTestsDetailsFromAllLevels"/>

        <a name="_defects"/>
        <h1>#sut.Defects#</h1>
        <!-- ********************** ALL DEFECTS **************************** -->
        <xsl:call-template name="generateUniqueDefectsDetailsFromAllLevels">
        </xsl:call-template>
         <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
      </body>
    </html>

  </xsl:template>









  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />
    <tr>
      <td class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::sut"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td class="table_data_header" width="90%">#sut.Suts#</td>
        <td class="table_data_header">#sut.Nb_requirements#</td>
        <xsl:if test="$specificationInLifecycle = 'true'">
          <td class="table_data_header">#sut.Nb_specifications#</td>
        </xsl:if>
        <td class="table_data_header">#sut.Nb_tests#</td>
        <td class="table_data_header">#sut.Nb_defects_found#</td>
        <td class="table_data_header">#sut.Nb_defects_fixed#</td>
        <td class="table_data_header">#sut.Nb_campaign_sessions#</td>
      </tr>

      <xsl:for-each select="sut">
        <xsl:variable name="sutId"                  select="@id" />
        <xsl:variable name="sutName"                select="@name" />
        <xsl:variable name="sutVersion"             select="@version" />
        <xsl:variable name="nbUniqueRequirements"   select="count(requirement)" />
        <xsl:variable name="nbUniqueSpecifications" select="@nbUniqueSpecifications" />
        <xsl:variable name="nbUniqueTests"          select="@nbUniqueTests" />
        <xsl:variable name="nbFoundInDefects"       select="count(foundIn/defect)" />
        <xsl:variable name="nbFixedInDefects"       select="count(fixedIn/defect)" />
        <xsl:variable name="nbCampaignSessions"     select="count(campaignsession)" />

        <!-- suts -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'sut'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [SU_<xsl:value-of select="$sutId" />] <xsl:value-of select="$sutName" />&#160;<xsl:value-of select="$sutVersion"/>
            </a>
          </td>


          <xsl:if test="$nbUniqueRequirements > 0">
            <td class="table_data_subheader"><xsl:value-of select="$nbUniqueRequirements"/></td>
          </xsl:if>
          <xsl:if test="$nbUniqueRequirements = 0">
            <td class="table_data_subheader">&#160;</td>
          </xsl:if>

          <xsl:if test="$specificationInLifecycle = 'true'">
            <xsl:if test="$nbUniqueSpecifications > 0">
              <td class="table_data_subheader"><xsl:value-of select="$nbUniqueSpecifications"/></td>
            </xsl:if>
            <xsl:if test="$nbUniqueSpecifications = 0">
              <td class="table_data_subheader">&#160;</td>
            </xsl:if>
          </xsl:if>

          <xsl:if test="$nbUniqueTests > 0">
            <td class="table_data_subheader"><xsl:value-of select="$nbUniqueTests"/></td>
          </xsl:if>
          <xsl:if test="$nbUniqueTests = 0">
            <td class="table_data_subheader">&#160;</td>
          </xsl:if>

          <xsl:if test="$nbFoundInDefects > 0">
            <td class="table_data_subheader"><xsl:value-of select="$nbFoundInDefects"/></td>
          </xsl:if>
          <xsl:if test="$nbFoundInDefects = 0">
            <td class="table_data_subheader">&#160;</td>
          </xsl:if>

          <xsl:if test="$nbFixedInDefects > 0">
            <td class="table_data_subheader"><xsl:value-of select="$nbFixedInDefects"/></td>
          </xsl:if>
          <xsl:if test="$nbFixedInDefects = 0">
            <td class="table_data_subheader">&#160;</td>
          </xsl:if>

          <xsl:if test="$nbCampaignSessions > 0">
            <td class="table_data_subheader"><xsl:value-of select="$nbCampaignSessions"/></td>
          </xsl:if>
          <xsl:if test="$nbCampaignSessions = 0">
            <td class="table_data_subheader">&#160;</td>
          </xsl:if>

        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>



  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(sut) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>
      <br/>
      <xsl:call-template name="generateSutsDetailsFromCurrentLevel"/>
    </xsl:if>


    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::sut) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobalsuts" select="count(suts/descendant::sut)"/>

    <xsl:if test="$nbGlobalsuts != 0">
      <table>
        <tr>
          <td class="table_label">#sut.Nb_suts#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalsuts"/></td>
        </tr>
      </table>
    </xsl:if>
    <xsl:if test="$nbGlobalsuts = 0">
      <h3>no sut available</h3>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbsuts"   select="count(descendant-or-self::sut)"/>

    <xsl:if test="$nbsuts != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbsuts"/></td>
    </xsl:if>
    <xsl:if test="$nbsuts = 0">
      <td class="table_data_content"></td>
    </xsl:if>
  </xsl:template>


</xsl:stylesheet>