<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="testplans/@codebase" />
  <xsl:variable name="bugtrackingType" select="testplans/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="testplans/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="testplans/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/testplanHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="nbCategory"            select="count(testplans/category)" />
        <xsl:variable name="domain"                select="testplans/@domain" />
        <xsl:variable name="graphInReportsEnabled" select="testplans/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="testplans/@date" />
        <xsl:variable name="documentAuthor"        select="testplans/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$domain = 1">
             <span class="report_title">#testplan.Complete_Testplan#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 2">
            <span class="report_title">#testplan.Category_Testplan#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 3">
            <span class="report_title">#testplan.Folder_Testplan#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 4">
            <span class="report_title">#testplan.Campaign_Testplan#</span><br/>
          </xsl:if>
          <span class="report_subtitle">Only Not Implemented Test Cases</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_metrics">#testplan.Metrics#</a><br/>
          <a class="report_table_of_content" href="#_summary">#testplan.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#testplan.Details#</a><br/>
          <a class="report_table_of_content" href="#_tbd">#testplan.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#testplan.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <a name="_metrics"/>
        <h1>#testplan.Metrics#</h1>
        <table>
          <tr>
            <td valign="top">
              <!-- ******************* TESTPLAN METRICS *************************** -->
              <xsl:if test="$nbCategory > 0">
                <xsl:call-template name="generateGlobalMetrics"/>
              </xsl:if>
              <xsl:if test="$nbCategory = 0">
                <xsl:call-template name="generateGlobalMetricsWithoutCategory"/>
              </xsl:if>
            </td>
          </tr>
        </table>


        <a name="_summary"/>
        <h1>#testplan.Summary#</h1>
        <xsl:call-template name="insertCharts">
          <xsl:with-param name="graphInReportsEnabled" select="$graphInReportsEnabled"/>
          <xsl:with-param name="domain" select="$domain"/>
        </xsl:call-template>


        <table width="100%">
          <!-- ******************* TESTPLAN SUMMARY *************************** -->
          <xsl:if test="$nbCategory > 0">
            <tr>
              <td class="table_data_header" width="90%">#testplan.Category#</td>
              <td class="table_data_header">#testplan.Nb_tests#</td>
              <td class="table_data_header">#testplan.Nb_testcases#</td>
              <td class="table_data_header">#testplan.Not_implemented#</td>
              <td class="table_data_header">#testplan.Implemented#</td>
              <td class="table_data_header">#testplan.Completion#</td>
            </tr>

            <xsl:for-each select="testplans/category">
              <xsl:variable name="categoryName" select="@name" />

              <!-- Categories -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'category'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:value-of select="$categoryName" />
                  </a>
                </td>
                <xsl:call-template name="generateNbTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
                <xsl:call-template name="generateNbTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
                <xsl:call-template name="generateCompletionTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
              </tr>

              <!-- Folders -->
              <xsl:for-each select="folder[count(descendant::testcase[@devCompleted='0'])>0]"> <!-- recursive call to display folders -->
                <xsl:call-template name="generateSummaryFolder">
                  <xsl:with-param name="parentName" select="$categoryName"/>
                  <xsl:with-param name="tab" select="''"/>
                </xsl:call-template>
              </xsl:for-each>

            </xsl:for-each>
          </xsl:if>
          <xsl:if test="$nbCategory = 0">
            <tr>
              <td class="table_data_header" width="90%">#testplan.Folder#</td>
              <td class="table_data_header">#testplan.Nb_tests#</td>
              <td class="table_data_header">#testplan.Nb_testcases#</td>
              <td class="table_data_header">#testplan.Not_implemented#</td>
              <td class="table_data_header">#testplan.Implemented#</td>
              <td class="table_data_header">#testplan.Completion#</td>
            </tr>

            <xsl:for-each select="testplans/folder[count(descendant::testcase[@devCompleted='0'])>0]">
              <xsl:call-template name="generateSummaryFolder">
                <xsl:with-param name="parentName" select="''"/>
                <xsl:with-param name="tab" select="''"/>
              </xsl:call-template>
            </xsl:for-each>
          </xsl:if>
        </table>


        <a name="_details"/>
        <h1>#testplan.Details#</h1>
        
        <xsl:if test="$domain = 4"> <!-- campaign testplan -->
          <xsl:variable name="campaignName"        select="testplans/campaign/@name" />
          <xsl:variable name="campaignDescription" select="testplans/campaign/description" />

          <h2>
            <img src="#images#/IconCampaign.gif"/>&#160;
            Campaign: <xsl:value-of disable-output-escaping="yes" select="$campaignName" />&#160;
          </h2>
          <!-- folder description -->
          <xsl:if test="string-length($campaignDescription)>0">
            <p><xsl:value-of disable-output-escaping="yes" select="$campaignDescription" /></p>
          </xsl:if>
        </xsl:if>
        
        <!-- ******************* TESTPLAN DETAILS *************************** -->
        <xsl:if test="$nbCategory > 0">
          <xsl:for-each select="testplans/category">
            <xsl:variable name="categoryName" select="@name" />
            <xsl:variable name="nbTestsInThisCategory" select="count(descendant::test[count(testcase[@devCompleted='0'])>0])" />

            <xsl:if test="$nbTestsInThisCategory > 0">
              <!-- Categories -->
              <a>
                <xsl:attribute name="name">
                  <xsl:call-template name="generateUniqueId">
                    <xsl:with-param name="type" select="'category'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
              </a>
              <h2>
                <img src="#images#/IconCategory.gif"/>&#160;
                <xsl:value-of disable-output-escaping="yes" select="$categoryName" />&#160;
              </h2>

              <!-- Attachments -->
              <xsl:call-template name="generateAttachments">
                <xsl:with-param name="parentType"     select="'CT_'"/>
                <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
              </xsl:call-template>

              <!-- Folders -->
              <xsl:for-each select="folder[count(descendant::testcase[@devCompleted='0'])>0]"> <!-- recursive call to display folders -->
                <xsl:call-template name="generateDetailsFolder">
                  <xsl:with-param name="parentName" select="$categoryName"/>
                </xsl:call-template>
              </xsl:for-each>
            </xsl:if>
          </xsl:for-each>
        </xsl:if>
        <xsl:if test="$nbCategory = 0">
          <!-- Folders -->
          <xsl:for-each select="testplans/folder[count(descendant::testcase[@devCompleted='0'])>0]"> <!-- recursive call to display folders -->
            <xsl:call-template name="generateDetailsFolder">
              <xsl:with-param name="parentName" select="''"/>
            </xsl:call-template>
          </xsl:for-each>
        </xsl:if>
        <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
      </body>
    </html>

  </xsl:template>












  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />

    <tr>
      <td class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateCompletionTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
    </tr>

    <xsl:for-each select="folder[count(descendant::testcase[@devCompleted='0'])>0]">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td class="table_data_header">#testplan.Tests#</td>
        <td class="table_data_header">#testplan.Nb_testcases#</td>
      </tr>
      <xsl:for-each select="test[count(testcase[@devCompleted='0'])>0]">
        <xsl:variable name="testName" select="@name" />
        <xsl:variable name="testNbTestcases" select="count(testcase[@devCompleted='0'])" />

        <!-- Tests -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'test'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              <xsl:value-of select="$testName" />
            </a>
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$testNbTestcases" />
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>








  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(test) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateAttachments">
        <xsl:with-param name="parentType" select="'FL_'"/>
        <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
      </xsl:call-template>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>

      <xsl:call-template name="generateTestsNotImplementedDetailsFromCurrentLevel"/>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder[count(descendant::testcase[@devCompleted='0'])>0]">
      <xsl:call-template name="generateDetailsFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>

<!--
  <xsl:template name="generateTestsNotImplementedDetails">
    <xsl:param name="parentName"/>

    <xsl:for-each select="test[count(testcase[@devCompleted='0'])>0]">
      <xsl:variable name="testName"          select="@name" />
      <xsl:variable name="testId"            select="@id" />
      <xsl:variable name="author"            select="@author" />
      <xsl:variable name="testDescription"   select="description" />
      <xsl:variable name="testPrerequisites" select="prerequisites" />
      <xsl:variable name="nbTestcases"       select="count(testcase[@devCompleted='0'])" />

      <br/>
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'test'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>

      <table width="100%">
        <tr><td colspan="4" class="table_data_subheader">[T_<xsl:value-of select="$testId"/>]&#160;<xsl:value-of select="$testName" /></td></tr>

        <tr><td colspan="4" class="table_data_subsubheader">#testplan.Author#</td></tr>
        <tr><td colspan="4" class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$author" /></td></tr>

        <tr><td colspan="4" class="table_data_subsubheader">#testplan.Description#</td></tr>
        <tr><td colspan="4" class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$testDescription" /></td></tr>

        <tr><td colspan="4" class="table_data_subsubheader">#testplan.Prerequisites#</td></tr>
        <tr><td colspan="4" class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$testPrerequisites" /></td></tr>

        <tr><td colspan="4" class="table_data_subsubheader">#testplan.Requirements#</td></tr>
        <xsl:for-each select="requirement">
          <xsl:variable name="reqName"          select="@name" />
          <xsl:variable name="reqId"            select="@id" />
          <xsl:variable name="reqDescription"   select="description" />
          <tr>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$reqId" /></td>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$reqName" /></td>
            <td colspan="2" class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$reqDescription" /></td>
          </tr>
        </xsl:for-each>

        <tr><td colspan="4" class="table_data_subsubheader">#testplan.Specifications#</td></tr>
        <xsl:for-each select="specification">
          <xsl:variable name="specName"          select="@name" />
          <xsl:variable name="specId"            select="@id" />
          <xsl:variable name="specDescription"   select="description" />
          <tr>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$specId" /></td>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$specName" /></td>
            <td colspan="2" class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$specDescription" /></td>
          </tr>
        </xsl:for-each>


        <xsl:if test="$nbTestcases>0">
          <tr>
            <td width="50px" class="table_data_subheader2" colspan="4">#testplan.Ref#</td>
          </tr>
          <xsl:for-each select="testcase[@devCompleted='0']">
            <xsl:sort select="@index" data-type="number"/>

            <xsl:variable name="testcaseId"                select="@id" />
            <xsl:variable name="testcaseName"              select="@name" />
            <xsl:variable name="testcaseIndex"             select="@index" />
            <xsl:variable name="testcaseUseDescAsTestplan" select="@useDescAsTestplan" />
            <xsl:variable name="testcaseDescription"       select="description" />
            <xsl:variable name="nbStep"                    select="count(steps/object[@type='root']/object[@type='step'])" />

            <tr>
              <td class="table_data_content2">
                <xsl:attribute name="rowspan">
                  <xsl:value-of select="$nbStep+3" />
                </xsl:attribute>
                <img src="#images#/IconTestcase.gif"/>
                <b><i><xsl:value-of select="$testcaseName"/></i></b>
                <br/>
                <img src="#images#/IconNotImplemented.gif"/>
                [TC_<xsl:value-of select="$testcaseId"/>] (<xsl:value-of select="$testcaseIndex"/>)
              </td>

              <td class="table_data_subsubheader" colspan="3">#testplan.Description#</td>
            </tr>
            <tr>
              <td  class="table_data_content2" colspan="3"><xsl:value-of disable-output-escaping="yes" select="$testcaseDescription"/></td>
            </tr>


            <tr>
              <td class="table_data_subsubheader">#testplan.Step#</td>
              <td class="table_data_subsubheader">#testplan.Parameters#</td>
              <td class="table_data_subsubheader">#testplan.ExpectedResult#</td>
            </tr>
            <xsl:if test="$nbStep > 0">
              <xsl:for-each select="steps/object[@type='root']/object[@type='step']">
                <xsl:variable name="nbParameters" select="count(object[@type='parameters']/object[@type='parameter'])" />

                <tr>

                  <td class="table_data_content"><xsl:value-of select="@description" /></td>
                  <td class="table_data_content">
                    <xsl:if test="$nbParameters = 0">
                      &#160;
                    </xsl:if>
                    <xsl:for-each select="object[@type='parameters']/object[@type='parameter']">
                      - <xsl:value-of select="@description" /><br/>
                    </xsl:for-each>
                  </td>
                  <td class="table_data_content">
                    <table>
                      <xsl:for-each select="object[@type='checks']/object[@type='operator']">
                        <xsl:call-template name="generateChecksDetails">
                          <xsl:with-param name="tab" select="''"/>
                        </xsl:call-template>
                      </xsl:for-each>
                    </table>
                  </td>
                </tr>
              </xsl:for-each>
            </xsl:if>
          </xsl:for-each>
        </xsl:if>
      </table>
      <br/>
    </xsl:for-each>
  </xsl:template>
 -->
 
  <xsl:template name="generateTestsNotImplementedDetailsFromCurrentLevel">
    <xsl:call-template name="generateTestsNotImplementedDetails">
      <xsl:with-param name="nodeSet" select="test[count(testcase[@devCompleted='0'])>0]"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="generateTestsNotImplementedDetails">
    <xsl:param name="nodeSet"/>

    <xsl:for-each select="$nodeSet">
      <xsl:call-template name="generateTestNotImplementedDetails"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="generateTestNotImplementedDetails">
    <xsl:variable name="testName"          select="@name" />
    <xsl:variable name="testId"            select="@id" />
    <xsl:variable name="author"            select="@author" />
    <xsl:variable name="developer"         select="@developer" />
    <xsl:variable name="testDescription"   select="description" />
    <xsl:variable name="testPrerequisites" select="prerequisites" />
    <xsl:variable name="nbTestcases"       select="count(testcase[@devCompleted='0'])" />

    <br/>
    <a>
      <xsl:attribute name="name">
        <xsl:call-template name="generateUniqueId">
          <xsl:with-param name="type" select="'test'"/>
          <xsl:with-param name="id" select="@id"/>
        </xsl:call-template>
      </xsl:attribute>
    </a>

    <table width="100%">
      <tr>
        <td class="table_data_subheader_bottom_align">
          <h4 class="no_margin">
            <img src="resources/images/IconTest.gif"/>&#160;
            [T_<xsl:value-of select="$testId"/>]&#160;<xsl:value-of select="$testName" />
          </h4>
        </td>
        <td class="table_data_subheader_bottom_align">
          <b>#testplan.Author#: </b> <xsl:value-of disable-output-escaping="yes" select="$author" />
          &#160;&#160;&#160;&#160;&#160;&#160;
          <b>#testplan.Developer#: </b> <xsl:value-of disable-output-escaping="yes" select="$developer" />
          &#160;&#160;&#160;&#160;&#160;&#160; Pass/Fail:  _________________
        </td>
      </tr>
      
      
      <!-- test description is mandatory so displayed even if empty -->
      <tr><td colspan="2" class="table_data_subsubsubheader">#testplan.Description#</td></tr>
      <tr>
      	<td colspan="2" class="table_data_content">
           <xsl:call-template name="generateAttachments">
              <xsl:with-param name="parentType" select="'T_'"/>
              <xsl:with-param name="attachmentIcon" select="'resources/images/IconAttachment.gif'"/>
           </xsl:call-template>
      	   <xsl:value-of disable-output-escaping="yes" select="$testDescription" />
      	   &#160; <!-- to avoid having a ugly effect when there is no description -->
      	</td>
      </tr>
      
      <xsl:if test="string-length($testPrerequisites)>0">
        <tr><td colspan="2" class="table_data_subsubsubheader">#testplan.Prerequisites#</td></tr>
        <tr>
          <td colspan="2" class="table_data_content">
            <xsl:value-of disable-output-escaping="yes" select="$testPrerequisites" />
          </td>
        </tr>
      </xsl:if>

      <xsl:if test="count(requirement)>0">
        <tr><td colspan="2" class="table_data_subsubsubheader">#testplan.Requirements#</td></tr>
        <xsl:for-each select="requirement">
          <xsl:variable name="reqName"          select="@name" />
          <xsl:variable name="reqId"            select="@id" />
          <xsl:variable name="reqDescription"   select="description" />
          <tr>
            <td class="table_data_content">
              <xsl:value-of disable-output-escaping="yes" select="$reqId" />&#160; &#160; &#160;<xsl:value-of disable-output-escaping="yes" select="$reqName" />
            </td>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$reqDescription" /></td>
          </tr>
        </xsl:for-each>
      </xsl:if>


      <xsl:if test="count(specification)>0">
        <tr><td colspan="2" class="table_data_subsubsubheader">#testplan.Specifications#</td></tr>
        <xsl:for-each select="specification">
          <xsl:variable name="specName"          select="@name" />
          <xsl:variable name="specId"            select="@id" />
          <xsl:variable name="specDescription"   select="description" />
          <tr>
            <td class="table_data_content">
              <xsl:value-of disable-output-escaping="yes" select="$specId" />&#160; &#160; &#160;<xsl:value-of disable-output-escaping="yes" select="$specName" />
            </td>
            <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$specDescription" /></td>
          </tr>
        </xsl:for-each>
      </xsl:if>
      
    </table>
    <br/>

    <xsl:if test="$nbTestcases>0">
      <xsl:for-each select="testcase[@devCompleted='0']">
        <xsl:sort select="@index" data-type="number"/>

        <xsl:variable name="testcaseId"                select="@id" />
        <xsl:variable name="testcaseName"              select="@name" />
        <xsl:variable name="testcaseIndex"             select="@index" />
        <xsl:variable name="testcaseImplemented"       select="@devCompleted" />
        <xsl:variable name="testcaseUseDescAsTestplan" select="@useDescAsTestplan" />
        <xsl:variable name="testcaseDescription"       select="description" />
        <xsl:variable name="nbStep"                    select="count(steps/object[@type='root']/object[@type='step'])" />
        <xsl:variable name="nbAttachment"              select="count(attachment)" />

        <!--
        table:        border missing
        margin:       overwrite the right border in Word
        padding:      no effect on Word
        margin in %:  no effect on Word
        margin-right: no effect on Word
        -->
        <!-- <div style="margin-left:50px"> -->
        <table border="0" width="100%"><tr><td width="10%">&#160;&#160;</td><td class="table_container" width="90%">
        
        <table border="0" width="100%">
          <tr>
            <td class="table_data_subsubheader_bottom_align" colspan="2">

              <h5 class="no_margin">
                <img src="resources/images/IconTestcase.gif"/>
                <xsl:if test="$testcaseImplemented='1'">
                  <img src="resources/images/IconImplemented.gif"/>
                </xsl:if>
                <xsl:if test="$testcaseImplemented='0'">
                  <img src="resources/images/IconNotImplemented.gif"/>
                </xsl:if>
                [TC_<xsl:value-of select="$testcaseId"/>] (<xsl:value-of select="$testcaseIndex"/>)
                <b>&#160;&#160;&#160;<xsl:value-of select="$testcaseName"/></b>
              </h5>
              
            </td>
            <td with="40%" class="table_data_subsubheader_bottom_align" valign="bottom">Pass/Fail:  _________________</td>
          </tr>
          
          <xsl:if test="string-length($testcaseDescription)>0 or $nbAttachment>0">
            <tr>
              <td class="table_data_subsubsubheader" colspan="3">#testplan.Description#</td>
            </tr>
            <tr>
              <td  class="table_data_content2" colspan="3">
                <xsl:call-template name="generateAttachments">
                    <xsl:with-param name="parentType" select="'TC_'"/>
                    <xsl:with-param name="attachmentIcon" select="'resources/images/IconAttachment.gif'"/>
                </xsl:call-template>
                <xsl:value-of disable-output-escaping="yes" select="$testcaseDescription"/>
              </td>
            </tr>
          </xsl:if>

          <!-- steps -->
          <xsl:if test="$nbStep > 0">
            <tr>
              <td class="table_data_subsubsubheader">#testplan.Step#</td>
              <td class="table_data_subsubsubheader">#testplan.Parameters#</td>
              <td class="table_data_subsubsubheader">#testplan.ExpectedResult#</td>
            </tr>
            <xsl:for-each select="steps/object[@type='root']/object[@type='step']">
              <xsl:variable name="nbParameters" select="count(object[@type='parameters']/object[@type='parameter'])" />

              <tr>
                <!-- all the other lines: we add the description, parameters and checks -->
                <td class="table_data_content"><xsl:value-of select="@description" /></td>
                <td class="table_data_content">
                  <xsl:if test="$nbParameters = 0">
                    &#160;
                  </xsl:if>
                  <xsl:for-each select="object[@type='parameters']/object[@type='parameter']">
                    - <xsl:value-of select="@description" /><br/>
                  </xsl:for-each>
                </td>
                <td class="table_data_content">
                  <table>
                    <xsl:for-each select="object[@type='checks']/object[@type='operator']">
                      <xsl:call-template name="generateChecksDetails">
                        <xsl:with-param name="tab" select="''"/>
                      </xsl:call-template>
                    </xsl:for-each>
                  </table>
                </td>
              </tr>
            </xsl:for-each>
          </xsl:if>
          
        </table>
        </td></tr></table>
        <br/>
      </xsl:for-each>
      
    </xsl:if>
  </xsl:template>
  
  
  
  
  
  
 

  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobalTests"            select="count(testplans/descendant::test[count(testcase[@devCompleted='0'])>0])"/>
    <xsl:variable name="nbGlobalTestcases"        select="count(testplans/descendant::testcase[@devCompleted='0'])"/>

    <xsl:if test="$nbGlobalTestcases != 0">
      <table width="100%">
        <tr>
          <td class="table_label">#testplan.Nb_tests#:</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTests"/></td>
        </tr>
        <tr>
          <td class="table_label">#testplan.Nb_testcases#:</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTestcases"/></td>
        </tr>
      </table>
    </xsl:if>
    <xsl:if test="$nbGlobalTestcases = 0">
      <h3>no tests available</h3>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateGlobalMetricsWithoutCategory">
    <xsl:variable name="nbGlobalTests"            select="count(testplans/descendant::test[count(testcase[@devCompleted='0'])>0])"/>
    <xsl:variable name="nbGlobalTestcases"        select="count(testplans/descendant::test/testcase[@devCompleted='0'])"/>

    <xsl:if test="$nbGlobalTestcases != 0">
      <table width="100%">
        <tr>
          <td class="table_label">#testplan.Nb_tests#:</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTests"/></td>
        </tr>
        <tr>
          <td class="table_label">#testplan.Nb_testcases#:</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTestcases"/></td>
        </tr>
      </table>
    </xsl:if>
    <xsl:if test="$nbGlobalTestcases = 0">
      <h3>no tests available</h3>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateCategoryMetrics">
    <xsl:variable name="nbTests"            select="count(descendant::test[count(testcase[@devCompleted='0'])>0])"/>
    <xsl:variable name="nbTestcases"        select="count(descendant::testcase[@devCompleted='0'])"/>

    <xsl:if test="$nbTests != 0">
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="$nbTests"/></td>
    </xsl:if>
    <xsl:if test="$nbTests = 0">
      <td class="table_data_subheader"></td>
    </xsl:if>

    <xsl:if test="$nbTestcases != 0">
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="$nbTestcases"/></td>
    </xsl:if>
    <xsl:if test="$nbTestcases = 0">
      <td class="table_data_subheader"></td>
    </xsl:if>
  </xsl:template>


  <xsl:template name="generateFolderMetrics">
    <xsl:variable name="nbTests"            select="count(descendant-or-self::test[count(testcase[@devCompleted='0'])>0])"/>
    <xsl:variable name="nbTestcases"        select="count(descendant-or-self::testcase[@devCompleted='0'])"/>

    <xsl:if test="$nbTests != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTests"/></td>
    </xsl:if>
    <xsl:if test="$nbTests = 0">
      <td class="table_data_content"></td>
    </xsl:if>

    <xsl:if test="$nbTestcases != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTestcases"/></td>
    </xsl:if>
    <xsl:if test="$nbTestcases = 0">
      <td class="table_data_content">&#160;</td>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbTests"            select="count(descendant-or-self::test[count(testcase[@devCompleted='0'])>0])"/>
    <xsl:variable name="nbTestcases"        select="count(descendant-or-self::testcase[@devCompleted='0'])"/>

    <xsl:if test="$nbTests != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTests"/></td>
    </xsl:if>
    <xsl:if test="$nbTests = 0">
      <td class="table_data_content"></td>
    </xsl:if>

    <xsl:if test="$nbTestcases != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTestcases"/></td>
    </xsl:if>
    <xsl:if test="$nbTestcases = 0">
      <td class="table_data_content">&#160;</td>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>